@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -16,25 +16,6 @@
 
 // Modified :   22/03/04 ; SAN : OCC4895 High-level interface for controlling polygon offsets 
 
-#define BUC60577        //GG_101099     Enable to compute correctly
-//                      transparency with more than one object in the view.
-
-#define GER61351	//GG_171199     Enable to set an object RGB color
-//			instead a restricted object NameOfColor. 
-//			Add SetCurrentFacingModel() method
-
-#define IMP020200	//GG Add SetTransformation() method
-
-#define IMP140200	//GG Add HasPresentation() and Presentation() methods
-//			     Add SetAspect() method.
-
-#define BUC60632	//GG 15/03/00 Add protection on SetDisplayMode()
-//			method, compute only authorized presentation.
-
-#define IMP220501	//GG CADPAK_V2 Update selection properly
-
-#define OCC708          //SAV unsetting transformation correctly
-
 #include <AIS_InteractiveObject.ixx>
 
 #include <Aspect_PolygonOffsetMode.hxx>
@@ -52,6 +33,8 @@
 #include <Graphic3d_AspectLine3d.hxx>
 #include <Graphic3d_AspectMarker3d.hxx>
 #include <Graphic3d_AspectText3d.hxx>
+#include <Graphic3d_BndBox4f.hxx>
+#include <Graphic3d_CStructure.hxx>
 #include <Graphic3d_Group.hxx>
 #include <Graphic3d_Structure.hxx>
 
@@ -64,7 +47,6 @@
 AIS_InteractiveObject::
 AIS_InteractiveObject(const PrsMgr_TypeOfPresentation3d aTypeOfPresentation3d):
 SelectMgr_SelectableObject(aTypeOfPresentation3d),
-myDrawer(new AIS_Drawer()),
 myTransparency(0.),
 myOwnColor(Quantity_NOC_WHITE),
 myOwnMaterial(Graphic3d_NOM_DEFAULT),
@@ -79,25 +61,23 @@ myCTXPtr(NULL),
 mySelPriority(-1),
 myDisplayMode (-1),
 mySelectionMode(0),
-mystate(0),
-myHasTransformation(Standard_False)
+mystate(0)
 {
   Handle (AIS_InteractiveContext) Bid;
   myCTXPtr = Bid.operator->();
-#ifdef GER61351
   SetCurrentFacingModel();
-#endif
 }
 
 //=======================================================================
 //function : Redisplay
-//purpose  : 
+//purpose  :
 //=======================================================================
-
-void AIS_InteractiveObject::Redisplay(const Standard_Boolean AllModes)
+void AIS_InteractiveObject::Redisplay (const Standard_Boolean AllModes)
 {
-  Update(AllModes);
-  UpdateSelection();
+  if (myCTXPtr == NULL)
+    return;
+
+  myCTXPtr->Redisplay (this, Standard_False, AllModes);
 }
 
 //=======================================================================
@@ -152,12 +132,6 @@ void AIS_InteractiveObject::SetContext(const Handle(AIS_InteractiveContext)& aCt
   myCTXPtr = aCtx.operator->();
   if( aCtx.IsNull())
     return;
-  if (myDrawer.IsNull()) {
-    myDrawer = new AIS_Drawer;
-#ifdef DEB
-    cout << "AIS_InteractiveObject::SetContext DRAWER NUL!" << endl;
-#endif
-  }
   myDrawer->Link(aCtx->DefaultDrawer());
 }
 
@@ -216,9 +190,7 @@ void AIS_InteractiveObject::ClearUsers()
 //=======================================================================
 void AIS_InteractiveObject::SetDisplayMode(const Standard_Integer aMode)
 {
-#ifdef BUC60632
   if( AcceptDisplayMode(aMode) )
-#endif
     myDisplayMode = aMode;
 }
   
@@ -238,7 +210,6 @@ void AIS_InteractiveObject::SetSelectionMode(const Standard_Integer aMode)
 //function : 
 //purpose  : 
 //=======================================================================
-#ifdef GER61351
 void AIS_InteractiveObject::SetCurrentFacingModel(const Aspect_TypeOfFacingModel aModel) {
   myCurrentFacingModel = aModel;
 }
@@ -251,7 +222,6 @@ void AIS_InteractiveObject::SetCurrentFacingModel(const Aspect_TypeOfFacingModel
 Aspect_TypeOfFacingModel AIS_InteractiveObject::CurrentFacingModel() const {
   return myCurrentFacingModel;
 }
-#endif
 
 //=======================================================================
 //function : SetColor
@@ -259,7 +229,6 @@ Aspect_TypeOfFacingModel AIS_InteractiveObject::CurrentFacingModel() const {
 //=======================================================================
 
 void AIS_InteractiveObject::SetColor(const Quantity_NameOfColor aColor)
-#ifdef GER61351
 {
   SetColor(Quantity_Color(aColor));
 }
@@ -270,7 +239,6 @@ void AIS_InteractiveObject::SetColor(const Quantity_NameOfColor aColor)
 //=======================================================================
 
 void AIS_InteractiveObject::SetColor(const Quantity_Color &aColor)
-#endif
 {
   myOwnColor = aColor;
   hasOwnColor = Standard_True;
@@ -313,18 +281,14 @@ void AIS_InteractiveObject::SetMaterial(const Graphic3d_NameOfMaterial aName)
 //void AIS_InteractiveObject::SetMaterial(const Graphic3d_NameOfPhysicalMaterial aName)
 {
   if( HasColor() || IsTransparent() || HasMaterial() )
-    {
-      myDrawer->ShadingAspect()->SetMaterial(aName);
-    }
-  else 
-    {
-      myDrawer->SetShadingAspect(new Prs3d_ShadingAspect());
-      
-      myDrawer->ShadingAspect()->SetMaterial(aName);
-#ifndef BUC60577	//???
-      myDrawer->ShadingAspect()->SetColor(AIS_GraphicTool::GetInteriorColor(myDrawer->Link()));
-#endif
-    }
+  {
+    myDrawer->ShadingAspect()->SetMaterial(aName);
+  }
+  else
+  {
+    myDrawer->SetShadingAspect(new Prs3d_ShadingAspect());
+    myDrawer->ShadingAspect()->SetMaterial(aName);
+  }
   myOwnMaterial  = aName;
   hasOwnMaterial = Standard_True;
 }
@@ -335,21 +299,16 @@ void AIS_InteractiveObject::SetMaterial(const Graphic3d_NameOfMaterial aName)
 
 void AIS_InteractiveObject::SetMaterial(const Graphic3d_MaterialAspect& aMat)
 {
-#ifdef BUC60577
-  if( HasColor() || IsTransparent() || HasMaterial() )
-#else
-  if(hasOwnColor ||(myTransparency==0.0) || hasOwnMaterial )
-#endif
-    {
-      myDrawer->ShadingAspect()->SetMaterial(aMat);
-    }
-  else 
-    {
-      myDrawer->SetShadingAspect(new Prs3d_ShadingAspect());
-      myDrawer->ShadingAspect()->SetMaterial(aMat);
-    }
+  if (HasColor() || IsTransparent() || HasMaterial())
+  {
+    myDrawer->ShadingAspect()->SetMaterial(aMat);
+  }
+  else
+  {
+    myDrawer->SetShadingAspect(new Prs3d_ShadingAspect());
+    myDrawer->ShadingAspect()->SetMaterial(aMat);
+  }
   hasOwnMaterial = Standard_True;
-  
 }
 //=======================================================================
 //function : 
@@ -357,21 +316,16 @@ void AIS_InteractiveObject::SetMaterial(const Graphic3d_MaterialAspect& aMat)
 //=======================================================================
 void AIS_InteractiveObject::UnsetMaterial()
 {
-#ifdef BUC60577
   if( !HasMaterial() ) return;
-  if( HasColor() || IsTransparent()) {
-    myDrawer->ShadingAspect()->SetMaterial(
-		AIS_GraphicTool::GetMaterial(myDrawer->Link()));
-    if( HasColor() ) SetColor(myOwnColor);
-    if( IsTransparent() ) SetTransparency(myTransparency);
-  }
-#else
-  if(!hasOwnMaterial) return;
-  if(hasOwnColor ||(myTransparency==0.0))
+  if (HasColor() || IsTransparent())
+  {
+    if(myDrawer->HasLink())
     {
-      myDrawer->ShadingAspect()->SetMaterial(AIS_GraphicTool::GetMaterial(myDrawer->Link()));
+      myDrawer->ShadingAspect()->SetMaterial (AIS_GraphicTool::GetMaterial (myDrawer->Link()));
     }
-#endif
+    if (HasColor()) SetColor (myOwnColor);
+    if (IsTransparent()) SetTransparency (myTransparency);
+  }
   else{
     Handle(Prs3d_ShadingAspect) SA;
     myDrawer->SetShadingAspect(SA);
@@ -385,47 +339,17 @@ void AIS_InteractiveObject::UnsetMaterial()
 //=======================================================================
 void AIS_InteractiveObject::SetTransparency(const Standard_Real aValue)
 {
-
-#ifdef BUC60577                     // Back & Front material can be different !
-
-  if(!HasColor() && !IsTransparent() && !HasMaterial() ) {
-        myDrawer->SetShadingAspect(new Prs3d_ShadingAspect());
-      if(!myDrawer->Link().IsNull())
-        myDrawer->ShadingAspect()->SetMaterial(AIS_GraphicTool::GetMaterial(myDrawer->Link()));
+  if(!HasColor() && !IsTransparent() && !HasMaterial())
+  {
+    myDrawer->SetShadingAspect(new Prs3d_ShadingAspect());
+    if(myDrawer->HasLink())
+      myDrawer->ShadingAspect()->SetMaterial(AIS_GraphicTool::GetMaterial(myDrawer->Link()));
   }
   Graphic3d_MaterialAspect FMat = myDrawer->ShadingAspect()->Aspect()->FrontMaterial();
   Graphic3d_MaterialAspect BMat = myDrawer->ShadingAspect()->Aspect()->BackMaterial();
   FMat.SetTransparency(aValue); BMat.SetTransparency(aValue);
   myDrawer->ShadingAspect()->Aspect()->SetFrontMaterial(FMat);
   myDrawer->ShadingAspect()->Aspect()->SetBackMaterial(BMat);
-#else
-  if(aValue<0.0 || aValue>1.0) return;
-  
-  if(aValue<=0.05) 
-    {
-      UnsetTransparency();
-      return;
-    }
-  
-
-  if(hasOwnColor || hasOwnMaterial || myTransparency> 0.0)
-    {
-      Graphic3d_MaterialAspect Mat = myDrawer->ShadingAspect()->Aspect()->FrontMaterial();
-      Mat.SetTransparency(aValue);
-      myDrawer->ShadingAspect()->Aspect()->SetFrontMaterial(Mat);
-      myDrawer->ShadingAspect()->Aspect()->SetBackMaterial(Mat);
-    }
-  else
-    {
-      myDrawer->SetShadingAspect(new Prs3d_ShadingAspect());
-      if(!myDrawer->Link().IsNull())
-	myDrawer->ShadingAspect()->SetMaterial(AIS_GraphicTool::GetMaterial(myDrawer->Link()));
-      Graphic3d_MaterialAspect Mat = myDrawer->ShadingAspect()->Aspect()->FrontMaterial();
-      Mat.SetTransparency(aValue);
-      myDrawer->ShadingAspect()->Aspect()->SetFrontMaterial(Mat);
-      myDrawer->ShadingAspect()->Aspect()->SetBackMaterial(Mat);
-    }
-#endif
   myTransparency = aValue;
 }
 
@@ -435,25 +359,14 @@ void AIS_InteractiveObject::SetTransparency(const Standard_Real aValue)
 //=======================================================================
 void AIS_InteractiveObject::UnsetTransparency()
 {
-#ifdef BUC60577                     // Back & Front material can be different !
-    if(HasColor() || HasMaterial() )
-    {
-      Graphic3d_MaterialAspect FMat = myDrawer->ShadingAspect()->Aspect()->FrontMaterial();
-      Graphic3d_MaterialAspect BMat = myDrawer->ShadingAspect()->Aspect()->BackMaterial();
-      FMat.SetTransparency(0.); BMat.SetTransparency(0.);
-      myDrawer->ShadingAspect()->Aspect()->SetFrontMaterial(FMat);
-      myDrawer->ShadingAspect()->Aspect()->SetBackMaterial(BMat);
-    }
-#else
-    if(hasOwnColor || hasOwnMaterial )
-    {
-      Graphic3d_MaterialAspect Mat = myDrawer->ShadingAspect()->Aspect()->FrontMaterial();
-      Mat.SetTransparency(0.0);
-//      myDrawer->ShadingAspect()->Aspect()->SetFrontMaterial(Mat);
-//      myDrawer->ShadingAspect()->Aspect()->SetBackMaterial(Mat);
-       myDrawer->ShadingAspect()->SetMaterial(Mat);
-    }
-#endif
+  if(HasColor() || HasMaterial() )
+  {
+    Graphic3d_MaterialAspect FMat = myDrawer->ShadingAspect()->Aspect()->FrontMaterial();
+    Graphic3d_MaterialAspect BMat = myDrawer->ShadingAspect()->Aspect()->BackMaterial();
+    FMat.SetTransparency(0.); BMat.SetTransparency(0.);
+    myDrawer->ShadingAspect()->Aspect()->SetFrontMaterial(FMat);
+    myDrawer->ShadingAspect()->Aspect()->SetBackMaterial(BMat);
+  }
   else{
     Handle (Prs3d_ShadingAspect) SA;
     myDrawer->SetShadingAspect(SA);
@@ -471,25 +384,14 @@ Standard_Real AIS_InteractiveObject::Transparency() const
 // return Mat.Transparency();
 }
 
-//=======================================================================
-//function : SetAttributes
-//purpose  : 
-//=======================================================================
-
-void AIS_InteractiveObject::SetAttributes(const Handle(AIS_Drawer)& aDrawer)
-{myDrawer = aDrawer;}
-
-
 //=======================================================================
 //function : UnsetAttributes
 //purpose  : 
 //=======================================================================
 void AIS_InteractiveObject::UnsetAttributes()
 {
-  Handle(AIS_Drawer) dr = new AIS_Drawer();
-  if(myDrawer->HasLink())
-    dr->Link(myDrawer->Link());
-  myDrawer       = dr;
+  SelectMgr_SelectableObject::UnsetAttributes();
+
   hasOwnColor    = Standard_False;
   hasOwnMaterial = Standard_False;
   myOwnWidth     = 0.0;
@@ -544,115 +446,33 @@ void AIS_InteractiveObject::SetInfiniteState(const Standard_Boolean aFlag)
   myInfiniteState = aFlag;
   Handle(Prs3d_Presentation) P;
 
-  for(Standard_Integer i =1; i<=myPresentations.Length();i++){
-    P = Handle(Prs3d_Presentation)::DownCast(myPresentations(i).Presentation());
+  for(Standard_Integer i =1; i<=myPresentations.Length();i++)
+  {
+    P = myPresentations(i).Presentation()->Presentation();
     if(!P.IsNull())
-      P->SetInfiniteState(myInfiniteState);}
-}
-
-#ifdef IMP020200
-//=======================================================================
-//function : SetTransformation
-//purpose  : 
-//=======================================================================
-void AIS_InteractiveObject::SetTransformation(const Handle(Geom_Transformation)& aTrsf, const Standard_Boolean postConcatenate, const Standard_Boolean updateSelection) {
-
-  if(!GetContext().IsNull()){
-    const PrsMgr_Presentations& prs = Presentations(); 
-    Handle(Prs3d_Presentation) P;
-    Standard_Integer mode;
-    myHasTransformation = Standard_True;
-    for( Standard_Integer i=1 ; i<=prs.Length() ; i++ ) {
-      mode = prs(i).Mode();
-      P = GetContext()->MainPrsMgr()->CastPresentation(this,mode)->Presentation();
-      if( postConcatenate ) P->Multiply(aTrsf);
-      else     	            P->Transform(aTrsf);
-      if( updateSelection ) {
-#ifdef IMP220501
-        myCTXPtr->ClearSelected(Standard_True);
-	myCTXPtr->RecomputeSelectionOnly(this);
-#else
-        if( HasSelection(mode) ) {
-          UpdateSelection(mode);      
-        }
-#endif
-      }
-    }
+      P->SetInfiniteState(myInfiniteState);
   }
 }
 
-//=======================================================================
-//function : SetTransformation
-//purpose  : 
-//=======================================================================
-void AIS_InteractiveObject::UnsetTransformation() {
-#ifdef OCC708
-  static Handle(Geom_Transformation) trsf = new Geom_Transformation( gp_Trsf() );
-#else
-Handle(Geom_Transformation) trsf;
-#endif
-
-    SetTransformation(trsf);	// Set identity transformation
-    myHasTransformation = Standard_False;
-}
-
-//=======================================================================
-//function : Transformation
-//purpose  : 
-//=======================================================================
-Handle(Geom_Transformation) AIS_InteractiveObject::Transformation() {
-Handle(Geom_Transformation) trsf; 
-
-  if(!GetContext().IsNull() ) {
-    const PrsMgr_Presentations& prs = Presentations(); 
-    if( prs.Length() > 0 ) {
-      Handle(Prs3d_Presentation) P = 
-	  GetContext()->MainPrsMgr()->CastPresentation(this,1)->Presentation();
-      trsf = P->Transformation();
-    }
-  }
-
-  return trsf;
-}
-
-//=======================================================================
-//function : HasTransformation
-//purpose  : 
-//=======================================================================
-Standard_Boolean AIS_InteractiveObject::HasTransformation() const {
-
-  return myHasTransformation;
-}
-#endif
-
-#ifdef IMP140200
 //=======================================================================
 //function : HasPresentation
-//purpose  : 
+//purpose  :
 //=======================================================================
-Standard_Boolean AIS_InteractiveObject::HasPresentation() const {
-
-  if( !GetContext().IsNull() && 
-	GetContext()->MainPrsMgr()->HasPresentation(this,myDisplayMode) ) {
-    return Standard_True;
-  }
-
-  return Standard_False;
+Standard_Boolean AIS_InteractiveObject::HasPresentation() const
+{
+  return !GetContext().IsNull()
+       && GetContext()->MainPrsMgr()->HasPresentation (this, myDisplayMode);
 }
 
 //=======================================================================
 //function : Presentation
-//purpose  : 
+//purpose  :
 //=======================================================================
-Handle(Prs3d_Presentation) AIS_InteractiveObject::Presentation() const {
-Handle(Prs3d_Presentation) prs;
-
-  if( HasPresentation() ) {
-    prs = GetContext()->MainPrsMgr()->
-		CastPresentation(this,myDisplayMode)->Presentation();
-  }
-
-  return prs;
+Handle(Prs3d_Presentation) AIS_InteractiveObject::Presentation() const
+{
+  return HasPresentation()
+       ? GetContext()->MainPrsMgr()->Presentation (this, myDisplayMode)->Presentation()
+       : Handle(Prs3d_Presentation)();
 }
 
 //=======================================================================
@@ -698,9 +518,6 @@ void AIS_InteractiveObject::SetAspect(const Handle(Prs3d_BasicAspect)& anAspect,
     }
   }
 }
-#endif
-
-// OCC4895 SAN 22/03/04 High-level interface for controlling polygon offsets
 
 //=======================================================================
 //function : SetPolygonOffsets 
@@ -716,38 +533,39 @@ void AIS_InteractiveObject::SetPolygonOffsets(const Standard_Integer    aMode,
   myDrawer->ShadingAspect()->Aspect()->SetPolygonOffsets( aMode, aFactor, aUnits );
 
   // Modify existing presentations 
-  Handle(Graphic3d_Structure) aStruct;
-  for( Standard_Integer i = 1, n = myPresentations.Length(); i <= n; i++ ) {
-    Handle(PrsMgr_Presentation3d) aPrs3d =
-      Handle(PrsMgr_Presentation3d)::DownCast( myPresentations(i).Presentation() );
+  for (Standard_Integer aPrsIter = 1, n = myPresentations.Length(); aPrsIter <= n; ++aPrsIter)
+  {
+    const Handle(PrsMgr_Presentation)& aPrs3d = myPresentations (aPrsIter).Presentation();
     if ( !aPrs3d.IsNull() ) {
-      aStruct = Handle(Graphic3d_Structure)::DownCast( aPrs3d->Presentation() );
+      const Handle(Graphic3d_Structure)& aStruct = aPrs3d->Presentation();
       if( !aStruct.IsNull() ) {
         aStruct->SetPrimitivesAspect( myDrawer->ShadingAspect()->Aspect() );
         // Workaround for issue 23115: Need to update also groups, because their
         // face aspect ALWAYS overrides the structure's.
         const Graphic3d_SequenceOfGroup& aGroups = aStruct->Groups();
-        Standard_Integer aGroupIndex = 1, aGroupNb = aGroups.Length();
-        for ( ; aGroupIndex <= aGroupNb; aGroupIndex++ ) {
-          Handle(Graphic3d_Group) aGrp = aGroups.Value(aGroupIndex);
-          if ( !aGrp.IsNull() && aGrp->IsGroupPrimitivesAspectSet(Graphic3d_ASPECT_FILL_AREA) ) {
-            Handle(Graphic3d_AspectFillArea3d) aFaceAsp = new Graphic3d_AspectFillArea3d();
-            Handle(Graphic3d_AspectLine3d) aLineAsp = new Graphic3d_AspectLine3d();
-            Handle(Graphic3d_AspectMarker3d) aPntAsp = new Graphic3d_AspectMarker3d();
-            Handle(Graphic3d_AspectText3d) aTextAsp = new Graphic3d_AspectText3d();
-            // TODO: Add methods for retrieving individual aspects from Graphic3d_Group
-            aGrp->GroupPrimitivesAspect(aLineAsp, aTextAsp, aPntAsp, aFaceAsp);
-            aFaceAsp->SetPolygonOffsets(aMode, aFactor, aUnits);
-            // TODO: Issue 23118 - This line kills texture data in the group...
-            aGrp->SetGroupPrimitivesAspect(aFaceAsp);
+        for (Graphic3d_SequenceOfGroup::Iterator aGroupIter (aGroups); aGroupIter.More(); aGroupIter.Next())
+        {
+          Handle(Graphic3d_Group)& aGrp = aGroupIter.ChangeValue();
+          if (aGrp.IsNull()
+          || !aGrp->IsGroupPrimitivesAspectSet (Graphic3d_ASPECT_FILL_AREA))
+          {
+            continue;
           }
+
+          Handle(Graphic3d_AspectFillArea3d) aFaceAsp = new Graphic3d_AspectFillArea3d();
+          Handle(Graphic3d_AspectLine3d)     aLineAsp = new Graphic3d_AspectLine3d();
+          Handle(Graphic3d_AspectMarker3d)   aPntAsp  = new Graphic3d_AspectMarker3d();
+          Handle(Graphic3d_AspectText3d)     aTextAsp = new Graphic3d_AspectText3d();
+          // TODO: Add methods for retrieving individual aspects from Graphic3d_Group
+          aGrp->GroupPrimitivesAspect(aLineAsp, aTextAsp, aPntAsp, aFaceAsp);
+          aFaceAsp->SetPolygonOffsets(aMode, aFactor, aUnits);
+          aGrp->SetGroupPrimitivesAspect(aFaceAsp);
         }
       }
     }
   }
 }
 
-
 //=======================================================================
 //function : HasPolygonOffsets 
 //purpose  : 
@@ -755,7 +573,7 @@ void AIS_InteractiveObject::SetPolygonOffsets(const Standard_Integer    aMode,
 Standard_Boolean AIS_InteractiveObject::HasPolygonOffsets() const
 {
   return !( myDrawer->ShadingAspect().IsNull() || 
-          ( !myDrawer->Link().IsNull() && 
+          ( myDrawer->HasLink() &&
           myDrawer->ShadingAspect() == myDrawer->Link()->ShadingAspect() ) );
 }
 
@@ -770,4 +588,76 @@ void AIS_InteractiveObject::PolygonOffsets(Standard_Integer&    aMode,
   if( HasPolygonOffsets() )
     myDrawer->ShadingAspect()->Aspect()->PolygonOffsets( aMode, aFactor, aUnits );
 }
-// OCC4895 SAN 22/03/04 High-level interface for controlling polygon offsets 
+
+//=======================================================================
+//function : BoundingBox
+//purpose  : Returns bounding box of object correspondingly to its
+//           current display mode
+//=======================================================================
+void AIS_InteractiveObject::BoundingBox (Bnd_Box& theBndBox)
+{
+  if (myDisplayMode == -1)
+  {
+    if (!myPresentations.IsEmpty())
+    {
+      const Handle(PrsMgr_Presentation)& aPrs3d = myPresentations.First().Presentation();
+      const Handle(Graphic3d_Structure)& aStruct = aPrs3d->Presentation();
+      const Graphic3d_BndBox4f& aBndBox = aStruct->CStructure()->BoundingBox();
+
+      if (!aBndBox.IsValid())
+      {
+        theBndBox.SetVoid();
+        return;
+      }
+
+      theBndBox.Update (static_cast<Standard_Real> (aBndBox.CornerMin().x()),
+                        static_cast<Standard_Real> (aBndBox.CornerMin().y()),
+                        static_cast<Standard_Real> (aBndBox.CornerMin().z()),
+                        static_cast<Standard_Real> (aBndBox.CornerMax().x()),
+                        static_cast<Standard_Real> (aBndBox.CornerMax().y()),
+                        static_cast<Standard_Real> (aBndBox.CornerMax().z()));
+      return;
+    }
+    else
+    {
+      for (PrsMgr_ListOfPresentableObjectsIter aPrsIter (Children()); aPrsIter.More(); aPrsIter.Next())
+      {
+        const Handle(AIS_InteractiveObject)& aChild = Handle(AIS_InteractiveObject)::DownCast (aPrsIter.Value());
+        if (aChild.IsNull())
+        {
+          continue;
+        }
+        Bnd_Box aBox;
+        aChild->BoundingBox (aBox);
+        theBndBox.Add (aBox);
+      }
+      return;
+    }
+  }
+  else
+  {
+    for (Standard_Integer aPrsIter = 1; aPrsIter <= myPresentations.Length(); ++aPrsIter)
+    {
+      if (myPresentations (aPrsIter).Mode() == myDisplayMode)
+      {
+        const Handle(PrsMgr_Presentation)& aPrs3d = myPresentations (aPrsIter).Presentation();
+        const Handle(Graphic3d_Structure)& aStruct = aPrs3d->Presentation();
+        const Graphic3d_BndBox4f& aBndBox = aStruct->CStructure()->BoundingBox();
+
+        if (!aBndBox.IsValid())
+        {
+          theBndBox.SetVoid();
+          return;
+        }
+
+        theBndBox.Update (static_cast<Standard_Real> (aBndBox.CornerMin().x()),
+                          static_cast<Standard_Real> (aBndBox.CornerMin().y()),
+                          static_cast<Standard_Real> (aBndBox.CornerMin().z()),
+                          static_cast<Standard_Real> (aBndBox.CornerMax().x()),
+                          static_cast<Standard_Real> (aBndBox.CornerMax().y()),
+                          static_cast<Standard_Real> (aBndBox.CornerMax().z()));
+        return;
+      }
+    }
+  }
+}
