@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -48,54 +48,57 @@
 //purpose  : 
 //=======================================================================
 
-AdvApp2Var_ApproxAFunc2Var::
-AdvApp2Var_ApproxAFunc2Var(const Standard_Integer Num1DSS,
-			   const Standard_Integer Num2DSS,
-			   const Standard_Integer Num3DSS,
-			   const Handle(TColStd_HArray1OfReal)& OneDTol,
-			   const Handle(TColStd_HArray1OfReal)& TwoDTol,
-			   const Handle(TColStd_HArray1OfReal)& ThreeDTol,
-			   const Handle(TColStd_HArray2OfReal)& OneDTolFr,
-			   const Handle(TColStd_HArray2OfReal)& TwoDTolFr,
-			   const Handle(TColStd_HArray2OfReal)& ThreeDTolFr,
-			   const Standard_Real FirstInU,
-			   const Standard_Real LastInU,
-			   const Standard_Real FirstInV,
-			   const Standard_Real LastInV,
-			   const GeomAbs_IsoType FavorIso,
-			   const GeomAbs_Shape ContInU,
-			   const GeomAbs_Shape ContInV,
-			   const Standard_Integer PrecisCode,
-			   const Standard_Integer MaxDegInU,
-			   const Standard_Integer MaxDegInV,
-			   const Standard_Integer MaxPatch,
-			   const AdvApp2Var_EvaluatorFunc2Var& Func,
-			   AdvApprox_Cutting& UChoice,
-			   AdvApprox_Cutting& VChoice) :
-my1DTolerances(OneDTol),
-my2DTolerances(TwoDTol),
-my3DTolerances(ThreeDTol),
-my1DTolOnFront(OneDTolFr),
-my2DTolOnFront(TwoDTolFr),
-my3DTolOnFront(ThreeDTolFr),
-myFirstParInU(FirstInU),
-myLastParInU(LastInU),
-myFirstParInV(FirstInV),
-myLastParInV(LastInV),
-myFavoriteIso(FavorIso),
-myContInU(ContInU),
-myContInV(ContInV),
-myPrecisionCode(PrecisCode),
-myMaxDegInU(MaxDegInU),
-myMaxDegInV(MaxDegInV),
-myMaxPatches(MaxPatch),
-myDone(Standard_False),
-myHasResult(Standard_False),
-myCriterionError(0.)
+AdvApp2Var_ApproxAFunc2Var::AdvApp2Var_ApproxAFunc2Var(
+                           const Standard_Integer Num1DSS,
+                           const Standard_Integer Num2DSS,
+                           const Standard_Integer Num3DSS,
+                           const Handle(TColStd_HArray1OfReal)& OneDTol,
+                           const Handle(TColStd_HArray1OfReal)& TwoDTol,
+                           const Handle(TColStd_HArray1OfReal)& ThreeDTol,
+                           const Handle(TColStd_HArray2OfReal)& OneDTolFr,
+                           const Handle(TColStd_HArray2OfReal)& TwoDTolFr,
+                           const Handle(TColStd_HArray2OfReal)& ThreeDTolFr,
+                           const Standard_Real FirstInU,
+                           const Standard_Real LastInU,
+                           const Standard_Real FirstInV,
+                           const Standard_Real LastInV,
+                           const GeomAbs_IsoType FavorIso,
+                           const GeomAbs_Shape ContInU,
+                           const GeomAbs_Shape ContInV,
+                           const Standard_Integer PrecisCode,
+                           const Standard_Integer MaxDegInU,
+                           const Standard_Integer MaxDegInV,
+                           const Standard_Integer MaxPatch,
+                           const AdvApp2Var_EvaluatorFunc2Var& Func,
+                           AdvApprox_Cutting& UChoice,
+                           AdvApprox_Cutting& VChoice)
+: my1DTolerances  (OneDTol),
+  my2DTolerances  (TwoDTol),
+  my3DTolerances  (ThreeDTol),
+  my1DTolOnFront  (OneDTolFr),
+  my2DTolOnFront  (TwoDTolFr),
+  my3DTolOnFront  (ThreeDTolFr),
+  myFirstParInU   (FirstInU),
+  myLastParInU    (LastInU),
+  myFirstParInV   (FirstInV),
+  myLastParInV    (LastInV),
+  myFavoriteIso   (FavorIso),
+  myContInU       (ContInU),
+  myContInV       (ContInV),
+  myPrecisionCode (PrecisCode),
+  myMaxDegInU     (MaxDegInU),
+  myMaxDegInV     (MaxDegInV),
+  myMaxPatches    (MaxPatch),
+  myDone          (Standard_False),
+  myHasResult     (Standard_False),
+  myDegreeInU     (0),
+  myDegreeInV     (0),
+  myCriterionError(0.0)
 {
   myNumSubSpaces[0] = Num1DSS;
   myNumSubSpaces[1] = Num2DSS;
   myNumSubSpaces[2] = Num3DSS;
+
   Init();
   Perform(UChoice, VChoice, Func);
   ConvertBS();
@@ -106,54 +109,58 @@ myCriterionError(0.)
 //purpose  : 
 //=======================================================================
 
- AdvApp2Var_ApproxAFunc2Var::
-AdvApp2Var_ApproxAFunc2Var(const Standard_Integer Num1DSS,
-			   const Standard_Integer Num2DSS,
-			   const Standard_Integer Num3DSS,
-			   const Handle(TColStd_HArray1OfReal)& OneDTol,
-			   const Handle(TColStd_HArray1OfReal)& TwoDTol,
-			   const Handle(TColStd_HArray1OfReal)& ThreeDTol,
-			   const Handle(TColStd_HArray2OfReal)& OneDTolFr,
-			   const Handle(TColStd_HArray2OfReal)& TwoDTolFr,
-			   const Handle(TColStd_HArray2OfReal)& ThreeDTolFr,
-			   const Standard_Real FirstInU,
-			   const Standard_Real LastInU,
-			   const Standard_Real FirstInV,
-			   const Standard_Real LastInV,
-			   const GeomAbs_IsoType FavorIso,
-			   const GeomAbs_Shape ContInU,
-			   const GeomAbs_Shape ContInV,
-			   const Standard_Integer PrecisCode,
-			   const Standard_Integer MaxDegInU,
-			   const Standard_Integer MaxDegInV,
-			   const Standard_Integer MaxPatch,
-			   const AdvApp2Var_EvaluatorFunc2Var& Func,
-			   const AdvApp2Var_Criterion& Crit,
-			   AdvApprox_Cutting& UChoice,
-			   AdvApprox_Cutting& VChoice) :
-my1DTolerances(OneDTol),
-my2DTolerances(TwoDTol),
-my3DTolerances(ThreeDTol),
-my1DTolOnFront(OneDTolFr),
-my2DTolOnFront(TwoDTolFr),
-my3DTolOnFront(ThreeDTolFr),
-myFirstParInU(FirstInU),
-myLastParInU(LastInU),
-myFirstParInV(FirstInV),
-myLastParInV(LastInV),
-myFavoriteIso(FavorIso),
-myContInU(ContInU),
-myContInV(ContInV),
-myPrecisionCode(PrecisCode),
-myMaxDegInU(MaxDegInU),
-myMaxDegInV(MaxDegInV),
-myMaxPatches(MaxPatch),
-myDone(Standard_False),
-myHasResult(Standard_False)
+ AdvApp2Var_ApproxAFunc2Var::AdvApp2Var_ApproxAFunc2Var(
+                      const Standard_Integer Num1DSS,
+                      const Standard_Integer Num2DSS,
+                      const Standard_Integer Num3DSS,
+                      const Handle(TColStd_HArray1OfReal)& OneDTol,
+                      const Handle(TColStd_HArray1OfReal)& TwoDTol,
+                      const Handle(TColStd_HArray1OfReal)& ThreeDTol,
+                      const Handle(TColStd_HArray2OfReal)& OneDTolFr,
+                      const Handle(TColStd_HArray2OfReal)& TwoDTolFr,
+                      const Handle(TColStd_HArray2OfReal)& ThreeDTolFr,
+                      const Standard_Real FirstInU,
+                      const Standard_Real LastInU,
+                      const Standard_Real FirstInV,
+                      const Standard_Real LastInV,
+                      const GeomAbs_IsoType FavorIso,
+                      const GeomAbs_Shape ContInU,
+                      const GeomAbs_Shape ContInV,
+                      const Standard_Integer PrecisCode,
+                      const Standard_Integer MaxDegInU,
+                      const Standard_Integer MaxDegInV,
+                      const Standard_Integer MaxPatch,
+                      const AdvApp2Var_EvaluatorFunc2Var& Func,
+                      const AdvApp2Var_Criterion& Crit,
+                      AdvApprox_Cutting& UChoice,
+                      AdvApprox_Cutting& VChoice)
+: my1DTolerances  (OneDTol),
+  my2DTolerances  (TwoDTol),
+  my3DTolerances  (ThreeDTol),
+  my1DTolOnFront  (OneDTolFr),
+  my2DTolOnFront  (TwoDTolFr),
+  my3DTolOnFront  (ThreeDTolFr),
+  myFirstParInU   (FirstInU),
+  myLastParInU    (LastInU),
+  myFirstParInV   (FirstInV),
+  myLastParInV    (LastInV),
+  myFavoriteIso   (FavorIso),
+  myContInU       (ContInU),
+  myContInV       (ContInV),
+  myPrecisionCode (PrecisCode),
+  myMaxDegInU     (MaxDegInU),
+  myMaxDegInV     (MaxDegInV),
+  myMaxPatches    (MaxPatch),
+  myDone          (Standard_False),
+  myHasResult     (Standard_False),
+  myDegreeInU     (0),
+  myDegreeInV     (0),
+  myCriterionError(0.0)
 {
   myNumSubSpaces[0] = Num1DSS;
   myNumSubSpaces[1] = Num2DSS;
   myNumSubSpaces[2] = Num3DSS;
+
   Init();
   Perform(UChoice, VChoice, Func, Crit);
   ConvertBS();
@@ -293,10 +300,12 @@ void AdvApp2Var_ApproxAFunc2Var::InitGrid(const Standard_Integer NbInt)
   Standard_Real deltu = (myLastParInU-myFirstParInU)/NbInt,
                 deltv = (myLastParInV-myFirstParInV)/NbInt;
   for (iint=1;iint<=NbInt-1;iint++) {
-    Result.UpdateInU(myFirstParInU+iint*deltu);
-    Constraints.UpdateInU(myFirstParInU+iint*deltu);
-    Result.UpdateInV(myFirstParInV+iint*deltv);
-    Constraints.UpdateInV(myFirstParInV+iint*deltv);
+    Standard_Real u = myFirstParInU + iint * deltu;
+    Standard_Real v = myFirstParInV + iint * deltv;
+    Result.UpdateInU(u);
+    Constraints.UpdateInU(u);
+    Result.UpdateInV(v);
+    Constraints.UpdateInV(v);
   }
   myResult = Result;
   myConstraints = Constraints;
