@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -24,10 +24,10 @@
 #include <TColgp_HArray1OfVec2d.hxx>
 
 
-#define tabTang (*(Handle_TColgp_HArray1OfVec*)&ttabTang)
-#define tabCurv (*(Handle_TColgp_HArray1OfVec*)&ttabCurv)
-#define tabTang2d (*(Handle_TColgp_HArray1OfVec2d*)&ttabTang2d)
-#define tabCurv2d (*(Handle_TColgp_HArray1OfVec2d*)&ttabCurv2d)
+#define tabTang (*(Handle(TColgp_HArray1OfVec)*)&ttabTang)
+#define tabCurv (*(Handle(TColgp_HArray1OfVec)*)&ttabCurv)
+#define tabTang2d (*(Handle(TColgp_HArray1OfVec2d)*)&ttabTang2d)
+#define tabCurv2d (*(Handle(TColgp_HArray1OfVec2d)*)&ttabCurv2d)
 
 
 
