@@ -46,33 +46,29 @@
 
 #include <BRep_Builder.hxx>
 #include <BRep_Tool.hxx>
-//
-#include <TopExp.hxx>
-#include <TopExp_Explorer.hxx>
-//
-#include <BRepBndLib.hxx>
-#include <BRepClass3d_SolidClassifier.hxx>
-//
-#include <BOPCol_IndexedDataMapOfShapeListOfShape.hxx>
-#include <BOPCol_ListOfShape.hxx>
-#include <BOPCol_MapOfOrientedShape.hxx>
-#include <BOPCol_DataMapOfShapeShape.hxx>
-#include <BOPCol_DataMapOfShapeListOfShape.hxx>
-#include <BOPCol_MapOfShape.hxx>
+#include <Precision.hxx>
+#include <IntTools_Context.hxx>
+#include <NCollection_IncAllocator.hxx>
+#include <NCollection_UBTreeFiller.hxx>
+
+#include <BOPAlgo_ShellSplitter.hxx>
 #include <BOPCol_BoxBndTree.hxx>
+#include <BOPCol_MapOfOrientedShape.hxx>
+#include <BOPCol_IndexedMapOfShape.hxx>
+#include <BOPCol_IndexedDataMapOfShapeShape.hxx>
+#include <BOPCol_IndexedDataMapOfShapeListOfShape.hxx>
 #include <BOPCol_ListOfInteger.hxx>
 #include <BOPCol_NCVector.hxx>
-#include <BOPCol_TBB.hxx>
-//
-#include <BOPTools.hxx>
-#include <BOPTools_CoupleOfShape.hxx>
-#include <BOPTools_AlgoTools.hxx>
+#include <BOPCol_Parallel.hxx>
 #include <BOPTools_AlgoTools3D.hxx>
-//
-#include <IntTools_Context.hxx>
-//
-#include <BOPAlgo_ShellSplitter.hxx>
+#include <BOPTools_AlgoTools.hxx>
+#include <BOPTools.hxx>
+#include <BRepBndLib.hxx>
+#include <Bnd_Box.hxx>
+#include <BRepClass3d_SolidClassifier.hxx>
+#include <TopExp_Explorer.hxx>
 
+//
 static
   Standard_Boolean IsGrowthShell(const TopoDS_Shape& ,
                                  const BOPCol_IndexedMapOfShape& );
@@ -84,7 +80,7 @@ static
                             const TopoDS_Shape& ,
                             Handle(IntTools_Context)& );
 static
-  void MakeInternalShells(const BOPCol_MapOfShape& ,
+  void MakeInternalShells(const BOPCol_IndexedMapOfShape& ,
                           BOPCol_ListOfShape& );
 
 //=======================================================================
@@ -247,26 +243,19 @@ class BOPAlgo_FaceSolid : public BOPAlgo_Algo {
 typedef BOPCol_NCVector
   <BOPAlgo_FaceSolid> BOPAlgo_VectorOfFaceSolid; 
 //
-typedef BOPCol_TBBContextFunctor 
+typedef BOPCol_ContextFunctor 
   <BOPAlgo_FaceSolid,
   BOPAlgo_VectorOfFaceSolid,
   Handle(IntTools_Context), 
   IntTools_Context> BOPAlgo_FaceSolidFunctor;
 //
-typedef BOPCol_TBBContextCnt 
+typedef BOPCol_ContextCnt 
   <BOPAlgo_FaceSolidFunctor,
   BOPAlgo_VectorOfFaceSolid,
   Handle(IntTools_Context)> BOPAlgo_FaceSolidCnt;
 //
 //=======================================================================
-typedef NCollection_DataMap
-  <TopoDS_Shape, 
-  gp_Pnt, 
-  TopTools_ShapeMapHasher> BOPAlgo_DataMapOfShapePnt; 
 
-typedef BOPAlgo_DataMapOfShapePnt::Iterator 
-  BOPAlgo_DataMapIteratorOfDataMapOfShapePnt; 
-//
 //=======================================================================
 //function : 
 //purpose  : 
@@ -446,19 +435,32 @@ void BOPAlgo_BuilderSolid::PerformShapesToAvoid()
 //=======================================================================
 void BOPAlgo_BuilderSolid::PerformLoops()
 {
-  Standard_Integer iErr;
+  Standard_Integer iErr, i, aNbSh;
   BOPCol_ListIteratorOfListOfShape aIt;
   TopoDS_Iterator aItS;
-  BOPCol_MapIteratorOfMapOfOrientedShape aItM;
-  BOPAlgo_ShellSplitter aSSp;
+  Handle(NCollection_BaseAllocator) aAlr;
   // 
   myErrorStatus=0;
   myLoops.Clear();
   //
+  aAlr=
+    NCollection_BaseAllocator::CommonBaseAllocator();
+  BOPAlgo_ShellSplitter aSSp(aAlr);
+  //
   // 1. Shells Usual
   aIt.Initialize (myShapes);
   for (; aIt.More(); aIt.Next()) {
-    const TopoDS_Shape& aF=aIt.Value();
+    const TopoDS_Face& aF=*((TopoDS_Face*)&aIt.Value());
+    if (myContext->IsInfiniteFace(aF)) {
+      TopoDS_Shell aSh;
+      BRep_Builder aBB;
+      //
+      aBB.MakeShell(aSh);
+      aBB.Add(aSh, aF);
+      myLoops.Append(aSh);
+      continue;
+    }
+    //
     if (!myShapesToAvoid.Contains(aF)) {
       aSSp.AddStartElement(aF);
     }
@@ -480,7 +482,6 @@ void BOPAlgo_BuilderSolid::PerformLoops()
   //=================================================
   //
   // 2. Post Treatment
-  Standard_Integer aNbFA;
   BRep_Builder aBB;
   BOPCol_MapOfOrientedShape AddedFacesMap;
   BOPCol_IndexedDataMapOfShapeListOfShape aEFMap;
@@ -498,18 +499,20 @@ void BOPAlgo_BuilderSolid::PerformLoops()
   }
   // 
   // b. collect all edges that are to avoid
-  aItM.Initialize(myShapesToAvoid);
-  for (; aItM.More(); aItM.Next()) {
-    const TopoDS_Shape& aF=aItM.Key();
+  aNbSh = myShapesToAvoid.Extent();
+  for (i = 1; i <= aNbSh; ++i) {
+    const TopoDS_Shape& aF = myShapesToAvoid(i);
     aMP.Add(aF);
   }
   //
   // c. add all edges that are not processed to myShapesToAvoid
   aIt.Initialize (myShapes);
   for (; aIt.More(); aIt.Next()) {
-    const TopoDS_Shape& aF=aIt.Value();
-    if (!aMP.Contains(aF)) {
-      myShapesToAvoid.Add(aF);
+    const TopoDS_Face& aF=*((TopoDS_Face*)&aIt.Value());
+    if (!myContext->IsInfiniteFace(aF)) {
+      if (!aMP.Contains(aF)) {
+        myShapesToAvoid.Add(aF);
+      }
     }
   }
   //=================================================
@@ -520,35 +523,33 @@ void BOPAlgo_BuilderSolid::PerformLoops()
   aEFMap.Clear();
   AddedFacesMap.Clear();
   //
-  aNbFA=myShapesToAvoid.Extent();
-  //
-  aItM.Initialize(myShapesToAvoid);
-  for (; aItM.More(); aItM.Next()) {
-    const TopoDS_Shape& aFF=aItM.Key();
+  aNbSh = myShapesToAvoid.Extent();
+  for (i = 1; i <= aNbSh; ++i) {
+    const TopoDS_Shape& aFF = myShapesToAvoid(i);
     BOPTools::MapShapesAndAncestors(aFF, 
         TopAbs_EDGE, TopAbs_FACE, 
         aEFMap);
   }
   //
-  aItM.Initialize(myShapesToAvoid);
-  for (; aItM.More(); aItM.Next()) {
-    const TopoDS_Shape& aFF=aItM.Key();
+  for (i = 1; i <= aNbSh; ++i) {
+    const TopoDS_Shape& aFF = myShapesToAvoid(i);
     if (!AddedFacesMap.Add(aFF)) {
       continue;
     }
     //
     // make a new shell
+    TopExp_Explorer aExp;
     TopoDS_Shell aShell;
     aBB.MakeShell(aShell);
     aBB.Add(aShell, aFF);
     //
-    TopoDS_Iterator aItAddedF (aShell);
-    for (; aItAddedF.More(); aItAddedF.Next()) {
-      const TopoDS_Face& aF = (*(TopoDS_Face*)(&aItAddedF.Value()));
+    aItS.Initialize(aShell);
+    for (; aItS.More(); aItS.Next()) {
+      const TopoDS_Face& aF = (*(TopoDS_Face*)(&aItS.Value()));
       //
-      TopExp_Explorer aEdgeExp(aF, TopAbs_EDGE);
-      for (; aEdgeExp.More(); aEdgeExp.Next()) {
-        const TopoDS_Edge& aE = (*(TopoDS_Edge*)(&aEdgeExp.Current()));
+      aExp.Init(aF, TopAbs_EDGE);
+      for (; aExp.More(); aExp.Next()) {
+        const TopoDS_Edge& aE = (*(TopoDS_Edge*)(&aExp.Current()));
         const BOPCol_ListOfShape& aLF=aEFMap.FindFromKey(aE);
         aIt.Initialize(aLF);
         for (; aIt.More(); aIt.Next()) { 
@@ -570,11 +571,11 @@ void BOPAlgo_BuilderSolid::PerformLoops()
 void BOPAlgo_BuilderSolid::PerformAreas()
 {
   Standard_Boolean bIsGrowth, bIsHole;
-  Standard_Integer k,aNbHoles;
+  Standard_Integer i, k, aNbInOut, aNbMSH;
   BRep_Builder aBB; 
   BOPCol_ListIteratorOfListOfShape aItLS;
   BOPCol_ListOfShape aNewSolids, aHoleShells; 
-  BOPCol_DataMapOfShapeShape aInOutMap;
+  BOPCol_IndexedDataMapOfShapeShape aInOutMap;
   BOPCol_IndexedMapOfShape aMHF;
   BOPCol_ListIteratorOfListOfInteger aItLI;
   BOPCol_BoxBndTreeSelector aSelector;
@@ -582,10 +583,8 @@ void BOPAlgo_BuilderSolid::PerformAreas()
   NCollection_UBTreeFiller 
     <Standard_Integer, Bnd_Box> aTreeFiller(aBBTree);
   BOPAlgo_DataMapOfIntegerBSSB aDMISB(100);
+  BOPCol_IndexedDataMapOfShapeListOfShape aMSH;
   BOPAlgo_DataMapIteratorOfDataMapOfIntegerBSSB aItDMISB;
-  BOPCol_DataMapOfShapeListOfShape aMSH;
-  BOPCol_DataMapIteratorOfDataMapOfShapeShape aItDMSS;
-  BOPCol_DataMapIteratorOfDataMapOfShapeListOfShape aItMSH;
   //
   myErrorStatus=0;
   //
@@ -669,7 +668,7 @@ void BOPAlgo_BuilderSolid::PerformAreas()
     aSelector.Clear();
     aSelector.SetBox(aBoxSolid);
     //
-    aNbHoles=aBBTree.Select(aSelector);
+    aBBTree.Select(aSelector);
     //
     const BOPCol_ListOfInteger& aLI=aSelector.Indices();
     //
@@ -683,42 +682,41 @@ void BOPAlgo_BuilderSolid::PerformAreas()
         continue;
       }
       //
-      if (aInOutMap.IsBound (aHole)){
-        const TopoDS_Shape& aHole2=aInOutMap(aHole);
-        if (IsInside(aHole, aHole2, myContext)) {
-          aInOutMap.UnBind(aHole);
-          aInOutMap.Bind (aHole, aSolid);
+      if (aInOutMap.Contains (aHole)){
+        const TopoDS_Shape& aSolidWas = aInOutMap.FindFromKey(aHole);
+        if (IsInside(aSolid, aSolidWas, myContext)) {
+          aInOutMap.ChangeFromKey(aHole) = aSolid;
         }
       }
       else{
-        aInOutMap.Bind(aHole, aSolid);
+        aInOutMap.Add(aHole, aSolid);
       }
     }
-  }//for (; aItDMISB.More(); aItDMISB.Next()) {
+  }//for (i = 1; i <= aNbDMISB; ++i) {
   //
   // 5. Map [Solid/Holes] -> aMSH 
-  aItDMSS.Initialize(aInOutMap);
-  for (; aItDMSS.More(); aItDMSS.Next()) {
-    const TopoDS_Shape& aHole=aItDMSS.Key();
-    const TopoDS_Shape& aSolid=aItDMSS.Value();
+  aNbInOut = aInOutMap.Extent();
+  for (i = 1; i <= aNbInOut; ++i) {
+    const TopoDS_Shape& aHole = aInOutMap.FindKey(i);
+    const TopoDS_Shape& aSolid = aInOutMap(i);
     //
-    if (aMSH.IsBound(aSolid)) {
-      BOPCol_ListOfShape& aLH=aMSH.ChangeFind(aSolid);
+    if (aMSH.Contains(aSolid)) {
+      BOPCol_ListOfShape& aLH = aMSH.ChangeFromKey(aSolid);
       aLH.Append(aHole);
     }
     else {
       BOPCol_ListOfShape aLH;
       aLH.Append(aHole);
-      aMSH.Bind(aSolid, aLH);
+      aMSH.Add(aSolid, aLH);
     }
   }
   //
   // 6. Add aHoles to Solids
-  aItMSH.Initialize(aMSH);
-  for (; aItMSH.More(); aItMSH.Next()) {
-    TopoDS_Solid aSolid=(*(TopoDS_Solid*)(&aItMSH.Key()));
+  aNbMSH = aMSH.Extent();
+  for (i = 1; i <= aNbMSH; ++i) {
+    TopoDS_Solid aSolid=(*(TopoDS_Solid*)(&(aMSH.FindKey(i))));
+    const BOPCol_ListOfShape& aLH = aMSH(i);
     //
-    const BOPCol_ListOfShape& aLH=aItMSH.Value();
     aItLS.Initialize(aLH);
     for (; aItLS.More(); aItLS.Next()) {
       const TopoDS_Shape& aHole = aItLS.Value();
@@ -743,7 +741,7 @@ void BOPAlgo_BuilderSolid::PerformAreas()
   aItLS.Initialize(aHoleShells);
   for (; aItLS.More(); aItLS.Next()) {
     const TopoDS_Shape& aHole = aItLS.Value();
-    if (!aInOutMap.IsBound(aHole)){
+    if (!aInOutMap.Contains(aHole)){
       TopoDS_Solid aSolid;
       //
       aBB.MakeSolid(aSolid);
@@ -767,12 +765,12 @@ void BOPAlgo_BuilderSolid::PerformInternalShapes()
   }
   // 
   Standard_Boolean bIsInternalFace;
-  Standard_Integer k, aNbVFS, aNbSLF, aNbVFP, aNbF, aNbA;
+  Standard_Integer k, aNbVFS, aNbSLF, aNbVFP, aNbA;
   BRep_Builder aBB;
   TopoDS_Iterator aIt;
   TopExp_Explorer aExp;
   BOPCol_ListIteratorOfListOfShape  aItLS;
-  BOPCol_MapOfShape aMFs;
+  BOPCol_IndexedMapOfShape aMFs;
   BOPCol_ListOfShape aLSI;
   BOPAlgo_VectorOfFaceSolid aVFS;
   BOPAlgo_VectorOfFacePnt aVFP;
@@ -792,7 +790,9 @@ void BOPAlgo_BuilderSolid::PerformInternalShapes()
     for (; aIt.More(); aIt.Next()) {
       const TopoDS_Face& aF=*((TopoDS_Face*)&aIt.Value());
       //
-      if (aMFs.Add(aF)) {
+      if (!aMFs.Contains(aF)) {
+        aMFs.Add(aF);
+        //
         gp_Pnt aP;
         gp_Pnt2d aP2D;
         //
@@ -856,7 +856,7 @@ void BOPAlgo_BuilderSolid::PerformInternalShapes()
     aSelector.Clear();
     aSelector.SetBox(aBox);
     //
-    aNbF=aBBTree.Select(aSelector);
+    aBBTree.Select(aSelector);
     //
     const BOPCol_ListOfInteger& aLI=aSelector.Indices();
     aItLI.Initialize(aLI);
@@ -970,27 +970,25 @@ void BOPAlgo_BuilderSolid::PerformInternalShapes()
 //function : MakeInternalShells
 //purpose  : 
 //=======================================================================
-void MakeInternalShells(const BOPCol_MapOfShape& theMF,
+void MakeInternalShells(const BOPCol_IndexedMapOfShape& theMF,
                         BOPCol_ListOfShape& theShells)
 {
-  BOPCol_ListIteratorOfListOfShape aItF;
+  Standard_Integer i, aNbF;
   BRep_Builder aBB;
-  //
+  BOPCol_ListIteratorOfListOfShape aItF;
   BOPCol_IndexedDataMapOfShapeListOfShape aMEF;
-  BOPCol_MapIteratorOfMapOfShape aItM;
   BOPCol_MapOfShape aAddedFacesMap;
   //
-  aItM.Initialize(theMF);
-  for (; aItM.More(); aItM.Next()) {
-    const TopoDS_Shape& aF=aItM.Key();
+  aNbF = theMF.Extent();
+  for (i = 1; i <= aNbF; ++i) {
+    TopoDS_Shape aF = theMF(i);
     BOPTools::MapShapesAndAncestors(aF, 
         TopAbs_EDGE, TopAbs_FACE, 
         aMEF);
   }
   //
-  aItM.Initialize(theMF);
-  for (; aItM.More(); aItM.Next()) {
-    TopoDS_Shape aFF=aItM.Key();
+  for (i = 1; i <= aNbF; ++i) {
+    TopoDS_Shape aFF = theMF(i);
     if (!aAddedFacesMap.Add(aFF)) {
       continue;
     }
