@@ -16,7 +16,6 @@
 //
 #include <Standard_Assert.hxx>
 //
-#include <NCollection_IncAllocator.hxx>
 #include <NCollection_BaseAllocator.hxx>
 
 #include <gp_Pnt.hxx>
@@ -27,6 +26,10 @@
 #include <TopoDS_Vertex.hxx>
 #include <TopoDS_Edge.hxx>
 #include <TopoDS_Face.hxx>
+//
+#include <BRep_TVertex.hxx>
+#include <BRep_TEdge.hxx>
+#include <BRep_TFace.hxx>
 #include <BRep_Tool.hxx>
 //
 #include <BRepBndLib.hxx>
@@ -34,6 +37,7 @@
 #include <BOPCol_MapOfInteger.hxx>
 #include <BOPCol_ListOfInteger.hxx>
 #include <BOPCol_DataMapOfShapeInteger.hxx>
+#include <BOPCol_DataMapOfIntegerMapOfInteger.hxx>
 //
 #include <BOPDS_IndexRange.hxx>
 #include <BOPDS_ShapeInfo.hxx>
@@ -68,6 +72,16 @@ static
   Standard_Real ComputeParameter(const TopoDS_Vertex& aV,
                                  const TopoDS_Edge& aE);
 
+static 
+  void AddShapeAndSubShapes(const Standard_Integer nS,
+                            const BOPDS_ShapeInfo& theSI,
+                            BOPCol_MapOfInteger& theMI);
+
+static 
+  void CollectEdges(const BOPDS_DS& theDS,
+                    const Standard_Integer nF,
+                    BOPCol_MapOfInteger& theMI);
+
 //=======================================================================
 //function : 
 //purpose  : 
@@ -76,24 +90,26 @@ BOPDS_DS::BOPDS_DS()
 :
   myAllocator(NCollection_BaseAllocator::CommonBaseAllocator()),
   myArguments(myAllocator),
-  myRanges(myAllocator),
-  myLines(myAllocator),
+  myRanges(0,myAllocator),
+  myLines(0, myAllocator), 
   myMapShapeIndex(100, myAllocator),
-  myPaveBlocksPool(myAllocator),
+  myPaveBlocksPool(0,myAllocator),
   myMapPBCB(100, myAllocator),
-  myFaceInfoPool(myAllocator),
+  myFaceInfoPool(0, myAllocator),
   myShapesSD(100, myAllocator),
   myInterfTB(100, myAllocator),
-  myInterfVV(myAllocator),
-  myInterfVE(myAllocator),
-  myInterfVF(myAllocator),
-  myInterfEE(myAllocator),
-  myInterfEF(myAllocator),
-  myInterfFF(myAllocator),
-  myInterfVZ(myAllocator),
-  myInterfEZ(myAllocator),
-  myInterfFZ(myAllocator),
-  myInterfZZ(myAllocator)
+  myInterfVV(0, myAllocator),
+  myInterfVE(0, myAllocator),
+  myInterfVF(0, myAllocator),
+  myInterfEE(0, myAllocator),
+  myInterfEF(0, myAllocator),
+  myInterfFF(0, myAllocator),
+  myInterfVZ(0, myAllocator),
+  myInterfEZ(0, myAllocator),
+  myInterfFZ(0, myAllocator),
+  myInterfZZ(0, myAllocator),
+  myFuzzyValue(0.),
+  myToleranceMap(100, myAllocator)
 {
   myNbShapes=0;
   myNbSourceShapes=0;
@@ -106,24 +122,26 @@ BOPDS_DS::BOPDS_DS(const Handle(NCollection_BaseAllocator)& theAllocator)
 :
   myAllocator(theAllocator),
   myArguments(myAllocator),
-  myRanges(myAllocator),
-  myLines(myAllocator),
+  myRanges(0, myAllocator),
+  myLines(0, myAllocator),
   myMapShapeIndex(100, myAllocator),
-  myPaveBlocksPool(myAllocator),
+  myPaveBlocksPool(0, myAllocator),
   myMapPBCB(100, myAllocator),
-  myFaceInfoPool(myAllocator),
+  myFaceInfoPool(0, myAllocator),
   myShapesSD(100, myAllocator),
   myInterfTB(100, myAllocator),
-  myInterfVV(myAllocator),
-  myInterfVE(myAllocator),
-  myInterfVF(myAllocator),
-  myInterfEE(myAllocator),
-  myInterfEF(myAllocator),
-  myInterfFF(myAllocator),
-  myInterfVZ(myAllocator),
-  myInterfEZ(myAllocator),
-  myInterfFZ(myAllocator),
-  myInterfZZ(myAllocator)
+  myInterfVV(0, myAllocator),
+  myInterfVE(0, myAllocator),
+  myInterfVF(0, myAllocator),
+  myInterfEE(0, myAllocator),
+  myInterfEF(0, myAllocator),
+  myInterfFF(0, myAllocator),
+  myInterfVZ(0, myAllocator),
+  myInterfEZ(0, myAllocator),
+  myInterfFZ(0, myAllocator),
+  myInterfZZ(0, myAllocator),
+  myFuzzyValue(0.),
+  myToleranceMap(100, myAllocator)
 {
   myNbShapes=0;
   myNbSourceShapes=0;
@@ -144,6 +162,7 @@ void BOPDS_DS::Clear()
 {
   myNbShapes=0;
   myNbSourceShapes=0;
+  myFuzzyValue=0.;
   //
   myArguments.Clear();
   myRanges.Clear();
@@ -164,6 +183,7 @@ void BOPDS_DS::Clear()
   myInterfEZ.Clear();
   myInterfFZ.Clear();
   myInterfZZ.Clear();
+  myToleranceMap.Clear();
 }
 //=======================================================================
 //function : SetArguments
@@ -256,8 +276,9 @@ Standard_Integer BOPDS_DS::Append(const BOPDS_ShapeInfo& theSI)
 {
   Standard_Integer iX;
   //
-  iX=myLines.Append()-1;
-  myLines(iX)=theSI;
+  myLines.Append1()=theSI;
+  iX=myLines.Extent()-1;
+  //
   return iX;
 }
 //=======================================================================
@@ -268,8 +289,8 @@ Standard_Integer BOPDS_DS::Append(const TopoDS_Shape& theS)
 {
   Standard_Integer iX;
   //
-  iX=myLines.Append()-1;
-  myLines(iX).SetShape(theS);
+  myLines.Append1().SetShape(theS);
+  iX=myLines.Extent()-1;
   return iX;
 }
 //=======================================================================
@@ -299,6 +320,7 @@ BOPDS_ShapeInfo& BOPDS_DS::ChangeShapeInfo(const Standard_Integer theI)
 //=======================================================================
 const TopoDS_Shape& BOPDS_DS::Shape(const Standard_Integer theI)const
 {
+  
   const TopoDS_Shape& aS=ShapeInfo(theI).Shape();
   return aS;
 }
@@ -325,13 +347,13 @@ void BOPDS_DS::Init()
 {
   Standard_Integer i1, i2, j, aI, aNb, aNbS, aNbE, aNbSx;
   Standard_Integer n1, n2, n3, nV, nW, nE, aNbF;
-  Standard_Real aTol;
+  Standard_Real aTol, aFuzz;
   TopAbs_ShapeEnum aTS;
   TopoDS_Iterator aItS;
   BOPCol_ListIteratorOfListOfInteger aIt1, aIt2, aIt3;
   BOPCol_ListIteratorOfListOfShape aIt;
   BOPDS_IndexRange aR;
-  Handle(NCollection_IncAllocator) aAllocator;
+  Handle(NCollection_BaseAllocator) aAllocator;
   //
   // 1 Append Source Shapes
   aNb=myArguments.Extent();
@@ -339,8 +361,7 @@ void BOPDS_DS::Init()
     return;
   }
   //
-  myRanges.SetStartSize(aNb);
-  myRanges.Init();
+  myRanges.SetIncrement(aNb);
   //
   aIt.Initialize(myArguments);
   for (; aIt.More(); aIt.Next()) {
@@ -358,12 +379,10 @@ void BOPDS_DS::Init()
     aNbS=aNbS+aNbSx;
   }
   //
-  myLines.SetStartSize(2*aNbS);
-  myLines.SetIncrement(aNbS);
-  myLines.Init();
-  //
+  myLines.SetIncrement(2*aNbS);
   //-----------------------------------------------------scope_1 f
-  aAllocator=new NCollection_IncAllocator();
+  aAllocator=
+    NCollection_BaseAllocator::CommonBaseAllocator();
   //
   BOPCol_DataMapOfShapeInteger& aMSI=myMapShapeIndex;
   //
@@ -386,6 +405,7 @@ void BOPDS_DS::Init()
     i1=i2+1;
   }
   //
+  aFuzz = myFuzzyValue / 2.;
   myNbSourceShapes=NbShapes();
   //
   // 2 Bounding Boxes
@@ -403,7 +423,15 @@ void BOPDS_DS::Init()
       Bnd_Box& aBox=aSI.ChangeBox();
       const TopoDS_Vertex& aV=*((TopoDS_Vertex*)&aS);
       const gp_Pnt& aP=BRep_Tool::Pnt(aV);
-      aTol=BRep_Tool::Tolerance(aV);
+      //
+      const Handle(BRep_TVertex)& TV = 
+        *((Handle(BRep_TVertex)*)&aV.TShape());
+      aTol = TV->Tolerance();
+      //
+      myToleranceMap.Bind(j, aTol);
+      aTol += aFuzz;
+      TV->Tolerance(aTol);
+      //
       aBox.SetGap(aTol);
       aBox.Add(aP);
     }
@@ -417,7 +445,14 @@ void BOPDS_DS::Init()
     if (aTS==TopAbs_EDGE) {
       const TopoDS_Shape& aS=aSI.Shape();
       const TopoDS_Edge& aE=*((TopoDS_Edge*)&aS);
-      aTol=BRep_Tool::Tolerance(aE);
+      //
+      const Handle(BRep_TEdge)& TE = 
+        *((Handle(BRep_TEdge)*)&aE.TShape());
+      aTol = TE->Tolerance();
+      //
+      myToleranceMap.Bind(j, aTol);
+      aTol += aFuzz;
+      TE->Tolerance(aTol);
       //
       if (!BRep_Tool::Degenerated(aE)) {
         Standard_Boolean bInf1, bInf2;
@@ -494,7 +529,14 @@ void BOPDS_DS::Init()
     if (aTS==TopAbs_FACE) {
       const TopoDS_Shape& aS=aSI.Shape();
       const TopoDS_Face& aF=*((TopoDS_Face*)&aS);
-      aTol=BRep_Tool::Tolerance(aF);
+      //
+      const Handle(BRep_TFace)& TF = 
+        *((Handle(BRep_TFace)*)&aF.TShape());
+      aTol = TF->Tolerance();
+      //
+      myToleranceMap.Bind(j, aTol);
+      aTol += aFuzz;
+      TF->Tolerance(aTol);
       //
       Bnd_Box& aBox=aSI.ChangeBox();
       BRepBndLib::Add(aS, aBox);
@@ -605,19 +647,11 @@ void BOPDS_DS::Init()
   }//for (j=0; j<myNbSourceShapes; ++j) {
   //
   aMI.Clear();
-  aAllocator.Nullify();
   //-----------------------------------------------------scope_1 t
-  //
   // 3 myPaveBlocksPool
-  myPaveBlocksPool.SetStartSize(aNbE);
-  myPaveBlocksPool.SetIncrement(aNbE);
-  myPaveBlocksPool.Init();
-  //
   // 4. myFaceInfoPool
-  myFaceInfoPool.SetStartSize(aNbF);
+  myPaveBlocksPool.SetIncrement(aNbE);
   myFaceInfoPool.SetIncrement(aNbF);
-  myFaceInfoPool.Init();
-  //
 }
 //=======================================================================
 //function : InitShape
@@ -709,12 +743,12 @@ Standard_Boolean BOPDS_DS::HasInterfShapeSubShapes
     bRet=HasInterf(theI1, n2);
     if (theFlag) {
       if(bRet) {
- break;
+        break;
       }
     }
     else {
       if(!bRet) {
- break;
+        break;
       }
     }
   }
@@ -890,8 +924,8 @@ void BOPDS_DS::InitPaveBlocks(const Standard_Integer theI)
     }
   }
   //
-  iRef = myPaveBlocksPool.Append() - 1;
-  BOPDS_ListOfPaveBlock &aLPB=myPaveBlocksPool(iRef);
+  BOPDS_ListOfPaveBlock &aLPB=myPaveBlocksPool.Append1();
+  iRef=myPaveBlocksPool.Extent()-1;
   //
   aPB->Update(aLPB, Standard_False);
   aSI.SetReference(iRef);
@@ -1221,8 +1255,8 @@ void BOPDS_DS::InitFaceInfo(const Standard_Integer theI)
   Standard_Integer iRef;
   //
   BOPDS_ShapeInfo& aSI=ChangeShapeInfo(theI);
-  iRef=myFaceInfoPool.Append()-1;
-  BOPDS_FaceInfo &aFI=myFaceInfoPool(iRef);
+  BOPDS_FaceInfo &aFI=myFaceInfoPool.Append1();
+  iRef=myFaceInfoPool.Extent()-1;
   aSI.SetReference(iRef);
   //
   aFI.SetIndex(theI);
@@ -1328,7 +1362,7 @@ void BOPDS_DS::FaceInfoIn(const Standard_Integer theF,
     if (aSx.ShapeType()==TopAbs_VERTEX){
       nV=Index(aSx);
       if (HasShapeSD(nV, nVSD)) {
- nV=nVSD;
+        nV=nVSD;
       }
       theMI.Add(nV);
     }
@@ -1411,20 +1445,19 @@ void BOPDS_DS::AloneVertices(const Standard_Integer theI,
 {
   if (HasFaceInfo(theI)) {
     //
-    Standard_Integer i, nV1, nV2, nV;
-    BOPDS_MapIteratorOfMapOfPaveBlock aItMPB;
+    Standard_Integer i, j, nV1, nV2, nV, aNbPB;
     BOPCol_MapIteratorOfMapOfInteger aItMI;
     //
     BOPCol_MapOfInteger aMI(100, myAllocator);
     //
     const BOPDS_FaceInfo& aFI=FaceInfo(theI);
     //
-    for (i=0; i<2; ++i) {
+    for (i = 0; i < 2; ++i) {
       const BOPDS_IndexedMapOfPaveBlock& aMPB=
         (!i) ? aFI.PaveBlocksIn() : aFI.PaveBlocksSc();
-      aItMPB.Initialize(aMPB);
-      for (; aItMPB.More(); aItMPB.Next()) {
-        const Handle(BOPDS_PaveBlock)& aPB=aItMPB.Value();
+      aNbPB = aMPB.Extent();
+      for (j = 1; j <= aNbPB; ++j) {
+        const Handle(BOPDS_PaveBlock)& aPB = aMPB(j);
         aPB->Indices(nV1, nV2);
         aMI.Add(nV1);
         aMI.Add(nV2);
@@ -2017,3 +2050,236 @@ void BOPDS_DS::BuildBndBoxSolid(const Standard_Integer theIndex,
     }
   }
 }
+
+//=======================================================================
+//function : DefaultTolerances
+//purpose  : 
+//=======================================================================
+void BOPDS_DS::SetDefaultTolerances()
+{
+  if (myFuzzyValue == 0.) {
+    return;
+  }
+  //
+  Standard_Boolean bAdd;
+  Standard_Integer i, j, n1, n2, nS, nSOp, nSs;
+  Standard_Integer anIntType, aNbFF, aNbFIn;
+  Standard_Real aTolDef;
+  TopAbs_ShapeEnum aTS1, aTS2;
+  BOPCol_MapOfInteger aMICh;
+  BOPCol_DataMapOfIntegerMapOfInteger aDMI;
+  BOPCol_ListIteratorOfListOfInteger aItLI;
+  BOPDS_MapIteratorMapOfPassKey aItPK;
+  BOPDS_ListIteratorOfListOfPaveBlock aItPB;
+  BOPCol_MapIteratorOfMapOfInteger aItMI;
+  BOPCol_DataMapIteratorOfDataMapOfIntegerReal aItDMIR;
+  //
+  // 1. Collect interfered shapes
+  // 1.1. Interferences V/V, V/E, V/F, E/E and E/F
+  aItPK.Initialize(myInterfTB);
+  for (; aItPK.More(); aItPK.Next()) {
+    const BOPDS_PassKey& aPK = aItPK.Value();
+    aPK.Ids(n1, n2);
+    //
+    const BOPDS_ShapeInfo& aSI1 = ShapeInfo(n1);
+    const BOPDS_ShapeInfo& aSI2 = ShapeInfo(n2);
+    //
+    aTS1 = aSI1.ShapeType();
+    aTS2 = aSI2.ShapeType();
+    //
+    anIntType = BOPDS_Tools::TypeToInteger(aTS1, aTS2);
+    if (anIntType < 5) {
+      AddShapeAndSubShapes(n1, aSI1, aMICh);
+      AddShapeAndSubShapes(n2, aSI2, aMICh);
+    } // if (anIntType < 5) {
+  } // for (; aIt.More(); aIt.Next()) {
+  //
+  // 1.2 FaceInfo information
+  aNbFF = myFaceInfoPool.Extent();
+  for (i = 0; i < aNbFF; ++i) {
+    const BOPDS_FaceInfo& aFI = myFaceInfoPool(i);
+    nS = aFI.Index();
+    if (aMICh.Contains(nS)) {
+      continue;
+    }
+    //
+    aNbFIn = (aFI.PaveBlocksIn().Extent() + 
+              aFI.VerticesIn().Extent() +
+              aFI.PaveBlocksSc().Extent() +
+              aFI.VerticesSc().Extent());
+    if (aNbFIn > 0) {
+      AddShapeAndSubShapes(nS, ShapeInfo(nS), aMICh);
+    } // if (aNbFIn > 0) {
+  } // for (i = 0; i < aNbFF; ++i) {
+  //
+  // 1.3. Empty F/F interferences
+  aNbFF = myInterfFF.Extent();
+  for (i = 0; i < aNbFF; ++i) {
+    BOPDS_InterfFF& aFF = myInterfFF(i);
+    if ((aFF.Curves().Extent() == 0) &&
+        (aFF.Points().Extent() == 0)) {
+      aFF.Indices(n1, n2);
+      for (j = 0; j < 2; ++j) {
+        nS = !j ? n1 : n2;
+        if (aMICh.Contains(nS)) {
+          continue;
+        }
+        nSOp = !j ? n2 : n1;
+        //
+        BOPCol_MapOfInteger aME, aMEOp;
+        //
+        if (aDMI.IsBound(nS)) {
+          aME = aDMI.Find(nS);
+        } else {
+          CollectEdges(*this, nS, aME);
+          aDMI.Bind(nS, aME);
+        }
+        //
+        if (aDMI.IsBound(nSOp)) {
+          aMEOp = aDMI.Find(nSOp);
+        } else {
+          CollectEdges(*this, nSOp, aMEOp);
+          aDMI.Bind(nSOp, aMEOp);
+        }
+        //
+        bAdd = Standard_True;
+        aItMI.Initialize(aME);
+        for (; aItMI.More(); aItMI.Next()) {
+          nSs = aItMI.Value();
+          if (!aMEOp.Contains(nSs)) {
+            bAdd = Standard_False;
+            break;
+          }
+        }
+        //
+        if (bAdd) {
+          AddShapeAndSubShapes(nS, ShapeInfo(nS), aMICh);
+          if (j == 0) {
+            AddShapeAndSubShapes(nSOp, ShapeInfo(nSOp), aMICh);
+          }
+        } // if (bAdd) {
+      } // for (j = 0; j < 2; ++j) {
+    } //if ((aFF.Curves().Extent() == 0) &&
+  } // for (i = 0; i < aNbFF; ++i) {
+  //
+  // 2. Back to default tolerance values
+  aItDMIR.Initialize(myToleranceMap);
+  for (; aItDMIR.More(); aItDMIR.Next()) {
+    i = aItDMIR.Key();
+    //
+    if (aMICh.Contains(i)) {
+      continue;
+    }
+    //
+    const BOPDS_ShapeInfo& aSI = ShapeInfo(i);
+    aTolDef = aItDMIR.Value();
+    aTS1 = aSI.ShapeType();
+    switch (aTS1) {
+      case TopAbs_VERTEX: {
+        const TopoDS_Vertex& aV = *(TopoDS_Vertex*)&aSI.Shape();
+        const Handle(BRep_TVertex)& aTV = 
+          *((Handle(BRep_TVertex)*)&aV.TShape());
+        aTV->Tolerance(aTolDef);
+        break;
+      }
+      case TopAbs_EDGE: {
+        const TopoDS_Edge& aE = *(TopoDS_Edge*)&aSI.Shape();
+        const Handle(BRep_TEdge)& aTE = 
+          *((Handle(BRep_TEdge)*)&aE.TShape());
+        aTE->Tolerance(aTolDef);
+        //
+        const BOPDS_ListOfPaveBlock& aLPB = PaveBlocks(i);
+        aItPB.Initialize(aLPB);
+        for (; aItPB.More(); aItPB.Next()) {
+          const Handle(BOPDS_PaveBlock)& aPB = aItPB.Value();
+          nS = aPB->Edge();
+          const TopoDS_Edge& aEIm = *(TopoDS_Edge*)&Shape(nS);
+          const Handle(BRep_TEdge)& aTEIm = 
+          *((Handle(BRep_TEdge)*)&aEIm.TShape());
+          aTEIm->Tolerance(aTolDef);
+        }
+        break;
+      }
+      case TopAbs_FACE: {
+        const TopoDS_Face& aF = *(TopoDS_Face*)&aSI.Shape();
+        const Handle(BRep_TFace)& aTF = 
+          *((Handle(BRep_TFace)*)&aF.TShape());
+        aTF->Tolerance(aTolDef);
+        break;
+      }
+      default:
+        break;
+    } // switch (aTS1) {
+  } // for (; aItDMIR.More(); aItDMIR.Next()) {
+}
+
+//=======================================================================
+//function : AddShapeAndSubShapes
+//purpose  : 
+//=======================================================================
+void AddShapeAndSubShapes(const Standard_Integer nS,
+                          const BOPDS_ShapeInfo& theSI,
+                          BOPCol_MapOfInteger& theMI)
+{
+  Standard_Integer nSs;
+  if (theMI.Add(nS)) {
+    const BOPCol_ListOfInteger& aLI = theSI.SubShapes();
+    BOPCol_ListIteratorOfListOfInteger aItLI(aLI);
+    for (; aItLI.More(); aItLI.Next()) {
+      nSs = aItLI.Value();
+      theMI.Add(nSs);
+    }
+  }
+}
+
+//=======================================================================
+//function : CollectEdges
+//purpose  : 
+//=======================================================================
+void CollectEdges(const BOPDS_DS& theDS,
+                  const Standard_Integer nF,
+                  BOPCol_MapOfInteger& theMI)
+{
+  Standard_Integer i, j, aNbPB, nE, nEIm;
+  BOPCol_ListIteratorOfListOfInteger aItLI;
+  BOPDS_ListIteratorOfListOfPaveBlock aItLPB;
+  //
+  // ON edges
+  const BOPDS_ShapeInfo& aSI = theDS.ShapeInfo(nF);
+  const BOPCol_ListOfInteger& aLI = aSI.SubShapes();
+  aItLI.Initialize(aLI);
+  for (; aItLI.More(); aItLI.Next()) {
+    nE = aItLI.Value();
+    const BOPDS_ShapeInfo& aSIE = theDS.ShapeInfo(nE);
+    if (aSIE.ShapeType() != TopAbs_EDGE) {
+      continue;
+    }
+    //
+    if (!aSIE.HasReference()) {
+      theMI.Add(nE);
+      continue;
+    }
+    //
+    const BOPDS_ListOfPaveBlock& aLPB = theDS.PaveBlocks(nE);
+    aItLPB.Initialize(aLPB);
+    for (; aItLPB.More(); aItLPB.Next()) {
+      const Handle(BOPDS_PaveBlock)& aPB = aItLPB.Value();
+      nEIm = aPB->Edge();
+      theMI.Add(nEIm);
+    }
+  }
+  // IN and SC edges
+  const BOPDS_FaceInfo& aFI = theDS.FaceInfo(nF);
+  const BOPDS_IndexedMapOfPaveBlock& aMPBIn = aFI.PaveBlocksIn();
+  const BOPDS_IndexedMapOfPaveBlock& aMPBSc = aFI.PaveBlocksSc();
+  //
+  for (i = 0; i < 2; ++i) {
+    const BOPDS_IndexedMapOfPaveBlock& aMPB = !i ? aMPBIn : aMPBSc;
+    aNbPB = aMPB.Extent();
+    for (j = 1; j <= aNbPB; ++j) {
+      const Handle(BOPDS_PaveBlock)& aPB = aMPB(j);
+      nE = aPB->Edge();
+      theMI.Add(nE);
+    }
+  }
+}
