@@ -19,13 +19,12 @@
 //
 #include <Bnd_Box.hxx>
 //
-#include <NCollection_IncAllocator.hxx>
 #include <NCollection_UBTreeFiller.hxx>
 //
 #include <TopoDS_Shape.hxx>
 //
 #include <BOPCol_NCVector.hxx>
-#include <BOPCol_TBB.hxx>
+#include <BOPCol_Parallel.hxx>
 #include <BOPCol_BoxBndTree.hxx>
 //
 #include <BOPDS_IndexRange.hxx>
@@ -70,8 +69,8 @@ class BOPDS_TSR : public BOPCol_BoxBndTreeSelector{
 //
 //=======================================================================
 typedef BOPCol_NCVector <BOPDS_TSR> BOPDS_VectorOfTSR; 
-typedef BOPCol_TBBFunctor <BOPDS_TSR,BOPDS_VectorOfTSR> BOPDS_TSRFunctor;
-typedef BOPCol_TBBCnt <BOPDS_TSRFunctor, BOPDS_VectorOfTSR> BOPDS_TSRCnt;
+typedef BOPCol_Functor <BOPDS_TSR,BOPDS_VectorOfTSR> BOPDS_TSRFunctor;
+typedef BOPCol_Cnt <BOPDS_TSRFunctor, BOPDS_VectorOfTSR> BOPDS_TSRCnt;
 /////////////////////////////////////////////////////////////////////////
 
 
@@ -84,11 +83,16 @@ BOPDS_Iterator::BOPDS_Iterator()
   myAllocator(NCollection_BaseAllocator::CommonBaseAllocator()),
   myRunParallel(Standard_False)
 {
+  Standard_Integer i, aNb;
+  //
   myDS=NULL; 
   myLength=0;
   //
-  myLists.SetStartSize(BOPDS_DS::NbInterfTypes());
-  myLists.Init();
+  aNb=BOPDS_DS::NbInterfTypes();
+  myLists.SetIncrement(aNb);
+  for (i=0; i<aNb; ++i) {
+    myLists.Append1();
+  }
 }
 //=======================================================================
 //function : 
@@ -98,14 +102,19 @@ BOPDS_Iterator::BOPDS_Iterator
   (const Handle(NCollection_BaseAllocator)& theAllocator)
 :
   myAllocator(theAllocator),
-  myLists(theAllocator),
+  myLists(0, theAllocator),
   myRunParallel(Standard_False)
 {
+  Standard_Integer i, aNb;
+  //
   myDS=NULL; 
   myLength=0;
   //
-  myLists.SetStartSize(BOPDS_DS::NbInterfTypes());
-  myLists.Init();
+  aNb=BOPDS_DS::NbInterfTypes();
+  myLists.SetIncrement(aNb);
+  for (i=0; i<aNb; ++i) {
+    myLists.Append1();
+  }
 }
 //=======================================================================
 //function : ~
@@ -260,11 +269,11 @@ void BOPDS_Iterator::Intersect()
   Standard_Integer aNb, i, aNbR, iTi, iTj;
   Standard_Integer i1, i2, aNbSD, iX, j, iR;
   TopAbs_ShapeEnum aTi, aTj;
-  Handle(NCollection_IncAllocator) aAllocator;
+  Handle(NCollection_BaseAllocator) aAllocator;
   BOPCol_ListIteratorOfListOfInteger aIt;
   //
   //-----------------------------------------------------scope_1 f
-  aAllocator=new NCollection_IncAllocator();
+  aAllocator=NCollection_BaseAllocator::CommonBaseAllocator();
   //
   BOPDS_MapOfPassKeyBoolean aMPKXB(100, aAllocator);
   BOPDS_PassKeyBoolean aPKXB; 
@@ -363,6 +372,5 @@ void BOPDS_Iterator::Intersect()
   //
   aMPKXB.Clear();
   aVTSR.Clear();
-  aAllocator.Nullify();
   //-----------------------------------------------------scope_1 t
 }
