@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -112,7 +112,7 @@
 #include <BRepLib_MakeWire.hxx>
 //#include <DbgTools.hxx>
 
-#ifdef DEB
+#ifdef OCCT_DEBUG
 extern Standard_Boolean BRepFeat_GettraceFEAT();
 extern Standard_Boolean BRepFeat_GettraceFEATRIB();
 #endif
@@ -140,7 +140,7 @@ void BRepFeat_MakeLinearForm::Init(const TopoDS_Shape& Sbase,
 				   const Standard_Integer Mode,
 				   const Standard_Boolean Modify)
 {
-#ifdef DEB
+#ifdef OCCT_DEBUG
   Standard_Boolean trc = BRepFeat_GettraceFEAT();
   if (trc) cout << "BRepFeat_MakeLinearForm::Init" << endl;
 #endif
@@ -177,7 +177,7 @@ void BRepFeat_MakeLinearForm::Init(const TopoDS_Shape& Sbase,
     myFuse   = Standard_False;
   else // if(Mode == 1) 
     myFuse   = Standard_True;
-#ifdef DEB
+#ifdef OCCT_DEBUG
   if (trc) {
     if (myFuse)  cout << " Fuse" << endl;
     if (!myFuse)  cout << " Cut" << endl;
@@ -209,7 +209,7 @@ void BRepFeat_MakeLinearForm::Init(const TopoDS_Shape& Sbase,
   if(!myDir1.IsEqual(nulldir, myTol, myTol)) {
     Standard_Real ang = myDir1.Angle(myDir);
     if(ang != M_PI) {
-#ifdef DEB
+#ifdef OCCT_DEBUG
       if (trc) cout << " Directions must be opposite" << endl;
 #endif
       myStatusError = BRepFeat_BadDirect;
@@ -220,7 +220,7 @@ void BRepFeat_MakeLinearForm::Init(const TopoDS_Shape& Sbase,
   else {
 
 // Rib is centre in the middle of translation
-#ifdef DEB
+#ifdef OCCT_DEBUG
     if (trc)  cout << " Rib is centre" << endl;
 #endif
     const gp_Vec& DirTranslation = (Direc + Direc1) * 0.5;
@@ -286,7 +286,7 @@ void BRepFeat_MakeLinearForm::Init(const TopoDS_Shape& Sbase,
 				       OnFirstEdge, OnLastEdge);
  
   if(!Data) {
-#ifdef DEB
+#ifdef OCCT_DEBUG
     if (trc) cout << " No Extreme faces" << endl;
 #endif
     myStatusError = BRepFeat_NoExtFace;
@@ -312,10 +312,10 @@ void BRepFeat_MakeLinearForm::Init(const TopoDS_Shape& Sbase,
   SliList.Append(FirstFace);
 
   if(Sliding) {    // sliding
-#ifdef DEB
+#ifdef OCCT_DEBUG
     if (trc) cout << " Sliding" << endl;
 #endif
-    Standard_Boolean Sliding = Standard_False;
+    Sliding = Standard_False;
     Handle(Geom_Surface) s = BRep_Tool::Surface(FirstFace);
     if (s->DynamicType() == 
 	STANDARD_TYPE(Geom_RectangularTrimmedSurface)) {
@@ -388,7 +388,7 @@ void BRepFeat_MakeLinearForm::Init(const TopoDS_Shape& Sbase,
 
 // ---case of sliding : construction of the profile face 
   if(Sliding) {
-#ifdef DEB
+#ifdef OCCT_DEBUG
     if (trc) cout << " still Sliding" << endl;
 #endif
     TopoDS_Face Prof;
@@ -398,9 +398,12 @@ void BRepFeat_MakeLinearForm::Init(const TopoDS_Shape& Sbase,
 			       FirstEdge,LastEdge);
     
     if (!ProfileOK) {
-#ifdef DEB
-      cout << "Not computable" << endl;
-      if (trc) cout << "Face profile not computable" << endl;
+#ifdef OCCT_DEBUG
+      if (trc)
+      {
+        cout << "Not computable" << endl;
+        cout << "Face profile not computable" << endl;
+      }
 #endif
       myStatusError = BRepFeat_NoFaceProf;
       NotDone();
@@ -414,7 +417,7 @@ void BRepFeat_MakeLinearForm::Init(const TopoDS_Shape& Sbase,
     Sliding = Propagate(SliList, Prof, myFirstPnt, myLastPnt, falseside);
 // Control if there is everything required to have the material at the proper side
     if(falseside == Standard_False) {
-#ifdef DEB
+#ifdef OCCT_DEBUG
       cout << "Verify plane and wire orientation" << endl;
 #endif
       myStatusError = BRepFeat_FalseSide;
@@ -707,6 +710,7 @@ void BRepFeat_MakeLinearForm::Init(const TopoDS_Shape& Sbase,
   if(Sliding) {
     TopoDS_Face F;
     BB.MakeFace(F, myPln, myTol);
+    w.Closed (BRep_Tool::IsClosed (w));
     BB.Add(F, w);
 //    BRepLib_MakeFace F(myPln->Pln(),w, Standard_True);
     mySkface = F;
@@ -717,7 +721,7 @@ void BRepFeat_MakeLinearForm::Init(const TopoDS_Shape& Sbase,
 
 // ---Case without sliding : construction of the profile face   
   if(!Sliding) {
-#ifdef DEB
+#ifdef OCCT_DEBUG
     if (trc) {
       if (Modify) cout << " Sliding failure" << endl;
       cout << " no Sliding" << endl;
@@ -731,9 +735,12 @@ void BRepFeat_MakeLinearForm::Init(const TopoDS_Shape& Sbase,
 				 FirstEdge,LastEdge,OnFirstFace,OnLastFace);
     
     if (!ProfileOK) {
-#ifdef DEB
-      cout << "Not computable" << endl;
-      if (trc) cout << " Face profile not computable" << endl;
+#ifdef OCCT_DEBUG
+      if (trc)
+      {
+        cout << "Not computable" << endl;
+        cout << " Face profile not computable" << endl;
+      }
 #endif
       myStatusError = BRepFeat_NoFaceProf;
       NotDone();
@@ -747,7 +754,7 @@ void BRepFeat_MakeLinearForm::Init(const TopoDS_Shape& Sbase,
     Propagate(SliList, Prof, myFirstPnt, myLastPnt, falseside);
 // Control if there is everything required to have the material at the proper side
     if(falseside == Standard_False) {
-#ifdef DEB
+#ifdef OCCT_DEBUG
       cout << "Verify plane and wire orientation" << endl;
 #endif
       myStatusError = BRepFeat_FalseSide;
@@ -768,6 +775,7 @@ void BRepFeat_MakeLinearForm::Init(const TopoDS_Shape& Sbase,
     for(; it.More(); it.Next()) {
       BB.Add(comp, it.Value());
     }
+    comp.Closed (BRep_Tool::IsClosed (comp));
     
     mySUntil = comp;
 
@@ -794,7 +802,7 @@ void BRepFeat_MakeLinearForm::Init(const TopoDS_Shape& Sbase,
 void BRepFeat_MakeLinearForm::Add(const TopoDS_Edge& E,
 				  const TopoDS_Face& F)
 {
-#ifdef DEB
+#ifdef OCCT_DEBUG
   Standard_Boolean trc = BRepFeat_GettraceFEAT();
   if (trc) cout << "BRepFeat_MakeLinearForm::Add" << endl;
 #endif
@@ -834,12 +842,12 @@ void BRepFeat_MakeLinearForm::Add(const TopoDS_Edge& E,
 
 void BRepFeat_MakeLinearForm::Perform()
 {
-#ifdef DEB
+#ifdef OCCT_DEBUG
   Standard_Boolean trc = BRepFeat_GettraceFEAT();
   if (trc) cout << "BRepFeat_MakeLinearForm::Perform()" << endl;
 #endif
   if(mySbase.IsNull() || mySkface.IsNull() || myPbase.IsNull()) {
-#ifdef DEB
+#ifdef OCCT_DEBUG
     if (trc) cout << " Fields not initialized" << endl;
 #endif
     myStatusError = BRepFeat_NotInitialized;
@@ -878,7 +886,7 @@ void BRepFeat_MakeLinearForm::Perform()
   for(; exx.More(); exx.Next()) {
     const TopoDS_Edge& e = TopoDS::Edge(exx.Current());
     if(!myMap.IsBound(e)) {
-#ifdef DEB
+#ifdef OCCT_DEBUG
       if (trc) cout << " Sliding face not in Base shape" << endl;
 #endif
       myStatusError = BRepFeat_IncSlidFace;
@@ -891,9 +899,12 @@ void BRepFeat_MakeLinearForm::Perform()
   SetGluedFaces(mySlface, theForm, myGluedF);  // management of sliding faces  
 
   if(!myGluedF.IsEmpty() && !mySUntil.IsNull()) {
-#ifdef DEB
-    cout << "The case is not computable" << endl;
-    if (trc) cout << " Glued faces not empty and Until shape not null" << endl;
+#ifdef OCCT_DEBUG
+    if (trc)
+    {
+      cout << "The case is not computable" << endl;
+      cout << " Glued faces not empty and Until shape not null" << endl;
+    }
 #endif
     myStatusError = BRepFeat_InvShape;
     NotDone();
@@ -950,7 +961,7 @@ void BRepFeat_MakeLinearForm::Perform()
 						      const gp_Pnt& Lastpnt, 
 						      Standard_Boolean& falseside)
 {
-#ifdef DEB
+#ifdef OCCT_DEBUG
   Standard_Boolean trc = BRepFeat_GettraceFEATRIB();
   if (trc) cout << "BRepFeat_MakeLinearForm::Propagate" << endl;
 #endif
@@ -1216,7 +1227,7 @@ static void SetGluedFaces(const TopTools_DataMapOfShapeListOfShape& theSlmap,
       for (it.Initialize(ledg); it.More(); it.Next()) {
 	const TopTools_ListOfShape& gfac = thePrism.Shapes(it.Value());
 	if (gfac.Extent() != 1) {
-#ifdef DEB
+#ifdef OCCT_DEBUG
 	  cout << "Pb SetGluedFace" << endl;
 #endif
 	}
