@@ -72,7 +72,7 @@
 //Number of BRepCheck_Statuses in BRepCheck_Status.hxx file
 //(BRepCheck_NoError is not considered, i.e. general status 
 //is smaller by one specified in file)
-static const Standard_Integer NumberOfStatus = 34;
+static const Standard_Integer NumberOfStatus = 36;
 
 static char* checkfaultyname = NULL;
 Standard_EXPORT void BRepTest_CheckCommands_SetFaultyName(const char* name)
@@ -754,10 +754,20 @@ void StructuralDump(Draw_Interpretor& theCommands,
   if(NbProblems->Value(aProblemID)>0)
     theCommands<<"  Invalid polygon on triangulation.......... "<<NbProblems->Value(aProblemID)<<"\n";
 
+  aProblemID = static_cast<Standard_Integer>(BRepCheck_InvalidImbricationOfShells);
+  if(NbProblems->Value(aProblemID)>0)
+    theCommands<<"  Invalid Imbrication of Shells............. "<<NbProblems->Value(aProblemID)<<"\n";
+ 
+ aProblemID = static_cast<Standard_Integer>(BRepCheck_EnclosedRegion);
+  if(NbProblems->Value(aProblemID)>0)
+    theCommands<<"  Enclosed Region........................... "<<NbProblems->Value(aProblemID)<<"\n";
+
   aProblemID = static_cast<Standard_Integer>(BRepCheck_CheckFail);
   if(NbProblems->Value(aProblemID)>0)
     theCommands<<"  checkshape failure........................ "<<NbProblems->Value(aProblemID)<<"\n";
 
+
+
   theCommands<<" ------------------------------------------------"<<"\n";
   theCommands<<"*** Shapes with problems : "<<sl->Length()<<"\n";
 
