@@ -283,6 +283,20 @@ Standard_Boolean BRepTools_Modifier::Rebuild
 	B.NaturalRestriction(TopoDS::Face(result),
 			     BRep_Tool::NaturalRestriction(TopoDS::Face(S)));
       }
+
+      // update triangulation on the copied face
+      Handle(Poly_Triangulation) aTriangulation;
+      if (M->NewTriangulation(TopoDS::Face(S), aTriangulation))
+      {
+        if (rebuild) // the copied face already exists => update it
+          B.UpdateFace(TopoDS::Face(result), aTriangulation);
+        else
+        { // create new face with bare triangulation
+          B.MakeFace(TopoDS::Face(result), aTriangulation);
+          result.Location(S.Location());
+        }
+        rebuild = Standard_True;
+      }
     }
     break;
 
@@ -544,7 +558,6 @@ Standard_Boolean BRepTools_Modifier::Rebuild
   // Set flag of the shape.
   result.Orientation(ResOr);
 
-  result.Free      (S.Free());
   result.Modified  (S.Modified());
   result.Checked   (S.Checked());
   result.Orientable(S.Orientable());
