@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -30,6 +30,7 @@
 
 #include <TopoDS.hxx>
 #include <Precision.hxx>
+#include <GeomAdaptor_Surface.hxx>
 
 //=======================================================================
 //function : BRepTools_TrsfModification
@@ -147,6 +148,9 @@ Standard_Boolean BRepTools_TrsfModification::NewCurve2d
   Standard_Real scale = myTrsf.ScaleFactor();
   Tol *= Abs(scale);
   const Handle(Geom_Surface)& S = BRep_Tool::Surface(F,loc);
+  GeomAdaptor_Surface GAsurf(S);
+  if (GAsurf.GetType() == GeomAbs_Plane)
+    return Standard_False;
 
   Standard_Real f,l;
   Handle(Geom2d_Curve) NewC = BRep_Tool::CurveOnSurface(E,F,f,l);
