@@ -70,7 +70,7 @@ void  BSplCLib::BuildEval(const Standard_Integer         Degree,
   Standard_Integer i;
   Standard_Integer ip = PLower + Index - 1;
   Standard_Real w, *pole = &LP;
-  if (&Weights == NULL) {
+  if (IS_NULL_REF(Weights)) {
     
     for (i = 0; i <= Degree; i++) {
       ip++;
@@ -115,13 +115,13 @@ static void PrepareEval
   
   // make the knots
   BSplCLib::BuildKnots(Degree,index,Periodic,Knots,Mults,*dc.knots);
-  if (&Mults == NULL)
+  if (IS_NULL_REF(Mults))
     index -= Knots.Lower() + Degree;
   else
     index = BSplCLib::PoleIndex(Degree,index,Periodic,Mults);
   
   // check truly rational
-  rational = (&Weights != NULL);
+  rational = (!IS_NULL_REF(Weights));
   if (rational) {
     Standard_Integer WLower = Weights.Lower() + index;
     rational = BSplCLib::IsRational(Weights, WLower, WLower + Degree);
@@ -438,7 +438,8 @@ BSplCLib::EvalBsplineBasis
  const  TColStd_Array1OfReal&         FlatKnots,
  const  Standard_Real                 Parameter,
  Standard_Integer&             FirstNonZeroBsplineIndex,
- math_Matrix&                  BsplineBasis)
+ math_Matrix&                  BsplineBasis,
+ Standard_Boolean              isPeriodic)
 {
   // the matrix must have at least DerivativeRequest + 1
   //   row and Order columns
@@ -497,7 +498,7 @@ BSplCLib::EvalBsplineBasis
   BSplCLib::LocateParameter(Order - 1, 
 			    FlatKnots,
 			    Parameter,
-			    Standard_False, 
+			    isPeriodic, 
 			    Order, 
 			    NumPoles+1, 
 			    ii,
