@@ -4,8 +4,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -235,14 +235,11 @@ Standard_Boolean BinMNaming_NamingDriver::Paste
 	WriteMessage (aMsg);
 	  }
 
-#ifdef DEB
-      //cout << "CurDocVersion = " << BinMNaming::DocumentVersion() <<endl;
-#endif
     if(BinMNaming::DocumentVersion() > 3) {
 	TCollection_AsciiString entry;
 	ok = theSource >> entry;
 	if(ok) {
-#ifdef DEB
+#ifdef OCCT_DEBUG
 	  cout << "NamingDriver:: Retrieved Context Label = " << entry << " Ok = " << theSource.IsOK()  <<endl;
 #endif
 	 
@@ -280,7 +277,7 @@ Standard_Boolean BinMNaming_NamingDriver::Paste
       if(ok) {
         OrientationToApply = (TopAbs_Orientation)anIndx;
 		aName.Orientation(OrientationToApply);
-#ifdef DEB
+#ifdef OCCT_DEBUG
 	    cout << "NamingDriver:: Retrieved Orientation = " << OrientationToApply << " Ok = " << theSource.IsOK()  <<endl;
 #endif
 	  } else {
@@ -290,7 +287,7 @@ Standard_Boolean BinMNaming_NamingDriver::Paste
 	  }
 	}
 	}
-#ifdef DEB
+#ifdef OCCT_DEBUG
       else if(BinMNaming::DocumentVersion() == -1)
 	cout << "Current DocVersion field is not initialized. "  <<endl;
       else 
