@@ -4,8 +4,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -34,7 +34,9 @@ Handle(Standard_Transient) BinTObjDrivers::Factory(const Standard_GUID& aGUID)
 {
   if(aGUID == BinStorageDriver)
   {
+#ifdef OCCT_DEBUG
     cout << "BinTObjDrivers : Storage Plugin" << endl;
+#endif
     static Handle(BinTObjDrivers_DocumentStorageDriver) model_sd
       = new BinTObjDrivers_DocumentStorageDriver;
     return model_sd;
@@ -42,7 +44,9 @@ Handle(Standard_Transient) BinTObjDrivers::Factory(const Standard_GUID& aGUID)
 
   if(aGUID == BinRetrievalDriver)
   {  
+#ifdef OCCT_DEBUG
     cout << "BinTObjDrivers : Retrieval Plugin" << endl;
+#endif
     static Handle (BinTObjDrivers_DocumentRetrievalDriver) model_rd
       = new BinTObjDrivers_DocumentRetrievalDriver;
     return model_rd;
