@@ -4,8 +4,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -699,15 +699,12 @@ Standard_IStream& BinTools_Curve2dSet::ReadCurve2d(Standard_IStream& IS,
 void  BinTools_Curve2dSet::Read(Standard_IStream& IS)
 {
   char buffer[255];
-#ifdef DEB
-//    const Standard_Integer aPos = IS.tellg();
-//    cout << "\tPosition of Curves2d section = " << aPos << endl;
-#endif 
+
   IS >> buffer;
   if (IS.fail() || strcmp(buffer,"Curve2ds")) {
     Standard_SStream aMsg;
     aMsg << "BinTools_Curve2dSet::Read:  Not a Curve2d table"<<endl;
-#ifdef DEB
+#ifdef OCCT_DEBUG
     cout <<"Curve2dSet buffer: " << buffer << endl;
 #endif
     Standard_Failure::Raise(aMsg);
