@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -73,10 +73,12 @@ Standard_Real Bisector_BisecAna::Distance (
    const Handle(GccInt_Bisec)& abisector,
    const gp_Vec2d&             afirstvector ,
    const gp_Vec2d&             asecondvector,
+   const gp_Vec2d&             VecRef,
    const Standard_Real         adirection,
    Standard_Real&              aparameter,
    Standard_Boolean&           asense,
-   Standard_Boolean&           astatus)
+   Standard_Boolean&           astatus,
+   Standard_Boolean            IsBisecOfTwoLines)
 {
   astatus = Standard_True;
 
@@ -153,30 +155,44 @@ Standard_Real Bisector_BisecAna::Distance (
   else {
     asense = Standard_True;
 
-//  Modified by Sergey KHROMOV - Tue Oct 22 16:35:51 2002 Begin
-// Replacement of -1.E-8 for a tolerance 1.e-4
-    Standard_Real aTol = 1.e-4;
-
-    if ((afirstdir^secdirrev)*adirection < -0.1) {   // input
-      if((afirstdir^tangdir)*adirection < aTol &&
-	 (secdirrev^tangdir)*adirection < aTol) asense = Standard_False;
-    }
-    else if((afirstdir^secdirrev)*adirection > 0.1) { // output
-      if((afirstdir^tangdir)*adirection < aTol ||
-	 (secdirrev^tangdir)*adirection < aTol) asense = Standard_False;
-    }
-    else  {                                                // flat
-      if (afirstdir.Dot(secdirrev) > 0.) {                // tangent 
-	if ((afirstdir^tangdir)*adirection < 0.) asense = Standard_False;
+    if (!IsBisecOfTwoLines)
+    {
+      //  Modified by Sergey KHROMOV - Tue Oct 22 16:35:51 2002 Begin
+      // Replacement of -1.E-8 for a tolerance 1.e-4
+      Standard_Real aTol = 1.e-4;
+      
+      if ((afirstdir^secdirrev)*adirection < -0.1) {   // input
+        if((afirstdir^tangdir)*adirection < aTol &&
+           (secdirrev^tangdir)*adirection < aTol)
+          asense = Standard_False;
       }
-      else{                                                // turn back
-//  Modified by Sergey KHROMOV - Thu Oct 31 14:16:53 2002
-// 	if ((afirstdir.Dot(tangdir))*adirection > 0.) asense = Standard_False;
-	if (afirstdir.Dot(tangdir) < 0.) asense = Standard_False;
-//  Modified by Sergey KHROMOV - Thu Oct 31 14:16:54 2002
+      else if((afirstdir^secdirrev)*adirection > 0.1) { // output
+        if((afirstdir^tangdir)*adirection < aTol ||
+           (secdirrev^tangdir)*adirection < aTol)
+          asense = Standard_False;
       }
+      else  {                                                // flat
+        if (afirstdir.Dot(secdirrev) > 0.) {                // tangent 
+          if ((afirstdir^tangdir)*adirection < 0.)
+            asense = Standard_False;
+        }
+        else{                                                // turn back
+          //  Modified by Sergey KHROMOV - Thu Oct 31 14:16:53 2002
+          // 	if ((afirstdir.Dot(tangdir))*adirection > 0.) asense = Standard_False;
+          if (afirstdir.Dot(tangdir) < 0.) asense = Standard_False;
+          //  Modified by Sergey KHROMOV - Thu Oct 31 14:16:54 2002
+        }
+      }
+      //jgv: for OCC26185
+      if (VecRef.SquareMagnitude() != 0)
+      {
+        gp_Dir2d DirRef = VecRef;
+        if (tangdir * DirRef < 0.)
+          asense = Standard_False;
+      }
+      ///////////////////
+      //  Modified by Sergey KHROMOV - Tue Oct 22 16:35:51 2002 End
     }
-//  Modified by Sergey KHROMOV - Tue Oct 22 16:35:51 2002 End
   }
   return distance;
 }
@@ -198,6 +214,7 @@ void Bisector_BisecAna::Perform(const Handle(Geom2d_Curve)& afirstcurve   ,
 				const gp_Vec2d&             afirstvector  ,
 				const gp_Vec2d&             asecondvector ,
 				const Standard_Real         adirection    ,
+                                const GeomAbs_JoinType      ajointype     ,
 				const Standard_Real         tolerance     ,
 				const Standard_Boolean      oncurve       )
 {
@@ -215,8 +232,19 @@ void Bisector_BisecAna::Perform(const Handle(Geom2d_Curve)& afirstcurve   ,
   Handle(Geom2d_Curve)  CurveE;
   Handle(GccInt_Bisec)  TheSol;
 
-  gp_Vec2d tan1 = afirstcurve->DN(afirstcurve->LastParameter (),1);
-  gp_Vec2d tan2 = asecondcurve->DN(asecondcurve->FirstParameter(),1);
+  //jgv: for OCC26296
+  gp_Vec2d LineBisVec(0.,0.);
+  gp_Vec2d tan1, tan2;
+  gp_Pnt2d Pnt1, Pnt2;
+  afirstcurve->D1(afirstcurve->LastParameter(),  Pnt1, tan1);
+  asecondcurve->D1(asecondcurve->FirstParameter(), Pnt2, tan2);
+  if (!oncurve)
+  {
+    LineBisVec = gp_Vec2d(Pnt1, Pnt2);
+    LineBisVec.Rotate(M_PI/2.);
+  }
+  ///////////////////
+  
   tan1.Reverse();
 
   if (type1 == STANDARD_TYPE(Geom2d_TrimmedCurve))
@@ -329,11 +357,11 @@ void Bisector_BisecAna::Perform(const Handle(Geom2d_Curve)& afirstcurve   ,
 // 			       adirection,parameter,sense,ok);
       if (oncurve)
 	distanceptsol = Distance(apoint,solution,
-				 tan2,tan1,
+				 tan2,tan1,LineBisVec,
 				 adirection,parameter,sense,ok);
       else
 	distanceptsol = Distance(apoint,solution,
-				 afirstvector,asecondvector,
+				 afirstvector,asecondvector,LineBisVec,
 				 adirection,parameter,sense,ok);
 //  Modified by skv - Tue Feb 15 17:51:29 2005 Integration End
       Handle(Geom2d_Curve) bisectorcurve = new Geom2d_Line(line);
@@ -402,7 +430,7 @@ void Bisector_BisecAna::Perform(const Handle(Geom2d_Curve)& afirstcurve   ,
 	sense = Standard_True;
 	if (oncurve) {
 	  distanceptsol = Distance(apoint,solution,
-				   tan1,tan2,
+				   tan1,tan2,LineBisVec,
 				   adirection,parameter,sense,ok);
 	}
 	else {ok = Standard_True;}
@@ -415,11 +443,11 @@ void Bisector_BisecAna::Perform(const Handle(Geom2d_Curve)& afirstcurve   ,
 // 			       adirection,parameter,sense,ok);
 	  if (oncurve)
 	    distanceptsol = Distance(apoint,solution,
-				     tan2,tan1,
+				     tan2,tan1,LineBisVec,
 				     adirection,parameter,sense,ok);
 	  else
 	    distanceptsol = Distance(apoint,solution,
-				     afirstvector,asecondvector,
+				     afirstvector,asecondvector,LineBisVec,
 				     adirection,parameter,sense,ok);
 //  Modified by skv - Tue Feb 15 17:51:29 2005 Integration End
 	  if (distanceptsol <= distancemini) {
@@ -557,7 +585,7 @@ void Bisector_BisecAna::Perform(const Handle(Geom2d_Curve)& afirstcurve   ,
 	Handle(GccInt_Bisec) solution = Bisector.ThisSolution(i);
 	Degenerate(solution,tolerance);
 	sense = Standard_True;
-	distanceptsol = Distance(apoint,solution,tan1,tan2,
+	distanceptsol = Distance(apoint,solution,tan1,tan2,LineBisVec,
 				 adirection,parameter,sense,ok);
 	if (ok || !oncurve) {
 	  sense = Standard_False;
@@ -567,11 +595,11 @@ void Bisector_BisecAna::Perform(const Handle(Geom2d_Curve)& afirstcurve   ,
 // 			       adirection,parameter,sense,ok);
 	  if (oncurve)
 	    distanceptsol = Distance(apoint,solution,
-				     tan2,tan1,
+				     tan2,tan1,LineBisVec,
 				     adirection,parameter,sense,ok);
 	  else
 	    distanceptsol = Distance(apoint,solution,
-				     afirstvector,asecondvector,
+				     afirstvector,asecondvector,LineBisVec,
 				     adirection,parameter,sense,ok);
 //  Modified by skv - Tue Feb 15 17:51:29 2005 Integration End
 	  if (distanceptsol <= distancemini) {
@@ -625,14 +653,31 @@ void Bisector_BisecAna::Perform(const Handle(Geom2d_Curve)& afirstcurve   ,
 	}
 	else if (type == GccInt_Par) {
 	  bisectorcurve = new Geom2d_Parabola(TheSol->Parabola());
+          gp_Pnt2d apex = bisectorcurve->Value(0.);
+          gp_Pnt2d firstpnt = bisectorcurve->Value(firstparameter);
+          Standard_Real ChordLen = apex.Distance(firstpnt);
+          const Standard_Real TolPar = 1.e-5;
+          Standard_Real secondparameter = Precision::Infinite();
 	  if (!thesense)
+          {
+            if (ajointype == GeomAbs_Intersection &&
+                TolPar < firstparameter &&
+                ChordLen >= circle1.Radius()) //first parameter is too far from peak of parabola
+              secondparameter = 0.;
 	    thebisector = new Geom2d_TrimmedCurve(bisectorcurve,
 						  firstparameter,
-						  - Precision::Infinite());
+						  -secondparameter);
+          }
 	  else
+          {
+            if (ajointype == GeomAbs_Intersection &&
+                firstparameter < -TolPar &&
+                ChordLen >= circle1.Radius()) //first parameter is too far from peak of parabola
+              secondparameter = 0.;
 	    thebisector = new Geom2d_TrimmedCurve(bisectorcurve,
 						  firstparameter,
-						  Precision::Infinite());
+						  secondparameter);
+          }
 	}
       }
     }
@@ -675,11 +720,11 @@ void Bisector_BisecAna::Perform(const Handle(Geom2d_Curve)& afirstcurve   ,
 // 			       adirection,parameter,sense,ok);
       if (oncurve)
 	distanceptsol = Distance(apoint,solution,
-				 tan2,tan1,
+				 tan2,tan1,LineBisVec,
 				 adirection,parameter,sense,ok);
       else
 	distanceptsol = Distance(apoint,solution,
-				 afirstvector,asecondvector,
+				 afirstvector,asecondvector,LineBisVec,
 				 adirection,parameter,sense,ok);
 //  Modified by skv - Tue Feb 15 17:51:29 2005 Integration End
 // 	if (distanceptsol <= distancemini) {
@@ -709,12 +754,12 @@ void Bisector_BisecAna::Perform(const Handle(Geom2d_Curve)& afirstcurve   ,
 // 			       adirection,parameter,sense,ok);
       if (oncurve)
 	distanceptsol = Distance(apoint,solution,
-				 tan2,tan1,
+				 tan2,tan1,LineBisVec,
 				 adirection,parameter,sense,ok);
       else
 	distanceptsol = Distance(apoint,solution,
-				 afirstvector,asecondvector,
-				 adirection,parameter,sense,ok);
+				 afirstvector,asecondvector,LineBisVec,
+				 adirection,parameter,sense,ok, Standard_True);
 //  Modified by skv - Tue Feb 15 17:51:29 2005 Integration End
       if (ok || !oncurve) {
 	thesense = sense;
@@ -764,6 +809,7 @@ void Bisector_BisecAna::Perform(const Handle(Geom2d_Curve)& afirstcurve  ,
   Standard_Boolean ok;
   Standard_Boolean thesense = Standard_False,sense;
   Standard_Real    distanceptsol,parameter,firstparameter =0.,secondparameter;
+  gp_Vec2d VecRef(0.,0.);
   Handle(Geom2d_Curve) curve;
   Handle(GccInt_Bisec) TheSol;
 
@@ -776,14 +822,14 @@ void Bisector_BisecAna::Perform(const Handle(Geom2d_Curve)& afirstcurve  ,
   Handle(Standard_Type) type = afirstcurve->DynamicType();
 
   if (type == STANDARD_TYPE(Geom2d_TrimmedCurve)) {
-    curve = (*(Handle_Geom2d_TrimmedCurve*)&afirstcurve)->BasisCurve();
+    curve = (*(Handle(Geom2d_TrimmedCurve)*)&afirstcurve)->BasisCurve();
   }
   else {
     curve = afirstcurve;
   }
 
   type = curve->DynamicType();
-#ifdef DEB
+#ifdef OCCT_DEBUG
   gp_Pnt2d Point(asecondpoint->Pnt2d());
 #else
   asecondpoint->Pnt2d();
@@ -808,7 +854,7 @@ void Bisector_BisecAna::Perform(const Handle(Geom2d_Curve)& afirstcurve  ,
 //                       Bissectrice point - circle.                          +
 //=============================================================================
     case 1 : {
-      GccAna_CircPnt2dBisec Bisector(circle,asecondpoint->Pnt2d());
+      GccAna_CircPnt2dBisec Bisector(circle, asecondpoint->Pnt2d(), tolerance);
       Standard_Real distancemini = Precision::Infinite();
       if (Bisector.IsDone()) {
 	Standard_Integer nbsolution = Bisector.NbSolutions();
@@ -817,7 +863,7 @@ void Bisector_BisecAna::Perform(const Handle(Geom2d_Curve)& afirstcurve  ,
 	  Degenerate(solution,tolerance);
 	  sense = Standard_False;
 	  distanceptsol = Distance(apoint,solution,
-				   afirstvector,asecondvector,
+				   afirstvector,asecondvector,VecRef,
 				   adirection,parameter,sense,ok);
 
 	  if (distanceptsol <= distancemini) {
@@ -915,7 +961,7 @@ void Bisector_BisecAna::Perform(const Handle(Geom2d_Curve)& afirstcurve  ,
     case 2 : {
       GccAna_LinPnt2dBisec Bisector(line,asecondpoint->Pnt2d());
       
-#ifdef DEB
+#ifdef OCCT_DEBUG
       gp_Vec2d V(line.Direction());
 #else
       line.Direction();
@@ -933,7 +979,7 @@ void Bisector_BisecAna::Perform(const Handle(Geom2d_Curve)& afirstcurve  ,
       }
       sense = Standard_False;
       distanceptsol = Distance(apoint,solution,
-			       afirstvector,asecondvector,
+			       afirstvector,asecondvector,VecRef,
 			       adirection,parameter,sense,ok);
 
       if (ok || !oncurve) {
@@ -1020,6 +1066,7 @@ void Bisector_BisecAna::Perform(const Handle(Geom2d_Point)& afirstpoint  ,
 {
   Standard_Boolean sense,ok;
   Standard_Real parameter;
+  gp_Vec2d VecRef(0.,0.);
 
   GccAna_Pnt2dBisec bisector(afirstpoint->Pnt2d(),asecondpoint->Pnt2d());
   gp_Lin2d line = bisector.ThisSolution();
@@ -1027,8 +1074,8 @@ void Bisector_BisecAna::Perform(const Handle(Geom2d_Point)& afirstpoint  ,
 
   sense = Standard_False;
   Distance(apoint,solution,
-			   afirstvector,asecondvector,
-			   adirection,parameter,sense,ok);
+           afirstvector,asecondvector,VecRef,
+           adirection,parameter,sense,ok);
   if (ok || !oncurve) {
     Handle(Geom2d_Curve) bisectorcurve = new Geom2d_Line(line);
     if (!sense)
