@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -101,7 +101,7 @@ Handle(CDM_Document)  CDF_Application::Retrieve(const TCollection_ExtendedString
 				     const TCollection_ExtendedString& aName,
 				     const TCollection_ExtendedString& aVersion,
 				     const Standard_Boolean UseStorageConfiguration) {
-#ifdef DEB
+#ifdef OCCT_DEBUG
   CDF_Timer theTimer;
 #endif
 
@@ -112,21 +112,21 @@ Handle(CDM_Document)  CDF_Application::Retrieve(const TCollection_ExtendedString
   else 
     theMetaData=theMetaDataDriver->MetaData(aFolder,aName,aVersion);
 
-#ifdef DEB  
+#ifdef OCCT_DEBUG
   theTimer.ShowAndRestart("Getting MetaData: ");
 #endif
 
   CDF_TypeOfActivation theTypeOfActivation=TypeOfActivation(theMetaData);
   Handle(CDM_Document) theDocument=Retrieve(theMetaData,UseStorageConfiguration,Standard_False);
 
-#ifdef DEB
+#ifdef OCCT_DEBUG
   theTimer.ShowAndRestart("Creating Transient: ");
 #endif
 
   CDF_Session::CurrentSession()->Directory()->Add(theDocument);
   Activate(theDocument,theTypeOfActivation);
 
-#ifdef DEB
+#ifdef OCCT_DEBUG
   theTimer.ShowAndStop("Activate: ");
 #endif
 
@@ -151,7 +151,7 @@ PCDM_ReaderStatus CDF_Application::CanRetrieve(const TCollection_ExtendedString&
 //=======================================================================
 PCDM_ReaderStatus CDF_Application::CanRetrieve(const TCollection_ExtendedString&  aFolder, const TCollection_ExtendedString&  aName, const TCollection_ExtendedString&  aVersion) {
   
-#ifdef DEB
+#ifdef OCCT_DEBUG
   CDF_Timer theTimer;
 #endif
 
@@ -160,13 +160,13 @@ PCDM_ReaderStatus CDF_Application::CanRetrieve(const TCollection_ExtendedString&
   else if (!theMetaDataDriver->HasReadPermission(aFolder,aName,aVersion))
     return PCDM_RS_PermissionDenied;
   else {
-#ifdef DEB
+#ifdef OCCT_DEBUG
     theTimer.ShowAndRestart("theMetaDataDriver->Find: ");
 #endif
 
     Handle(CDM_MetaData) theMetaData = theMetaDataDriver->MetaData(aFolder,aName,aVersion);
 
-#ifdef DEB
+#ifdef OCCT_DEBUG
     theTimer.ShowAndStop("Getting MetaData: ");
 #endif
 
@@ -481,7 +481,15 @@ Standard_Boolean CDF_Application::FindReaderFromFormat(const TCollection_Extende
   ResourceName+=".RetrievalPlugin";
   
   if(UTL::Find(Resources(),ResourceName))  {
-    thePluginId=UTL::GUID(UTL::Value(Resources(),ResourceName));
+    // Get GUID as a string.
+    TCollection_ExtendedString strPluginId = UTL::Value(Resources(),ResourceName);
+    
+    // If the GUID (as a string) contains blanks, remove them.
+    if (strPluginId.Search(' ') != -1)
+      strPluginId.RemoveAll(' ');
+    
+    // Convert to GUID.
+    thePluginId=UTL::GUID(strPluginId);
     return Standard_True;
   }
   return Standard_False;
