@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -87,14 +87,19 @@ Handle(ChFiDS_HElSpine) ChFiDS_Spine::ElSpine(const Standard_Integer IE) const
 
 Handle(ChFiDS_HElSpine) ChFiDS_Spine::ElSpine(const Standard_Real W) const 
 {
-  ChFiDS_ListIteratorOfListOfHElSpine It(elspines);
-  for (; It.More(); It.Next()) {
-    Handle(ChFiDS_HElSpine) cur = It.Value();
-    Standard_Real uf = cur->FirstParameter();
-    Standard_Real ul = cur->LastParameter();
-    if(uf <= W && W <= ul) return cur;
-  }  
-  return Handle(ChFiDS_HElSpine)();
+  if (elspines.Extent() == 1)
+    return elspines.First();
+  else
+  {
+    ChFiDS_ListIteratorOfListOfHElSpine It(elspines);
+    for (; It.More(); It.Next()) {
+      Handle(ChFiDS_HElSpine) cur = It.Value();
+      Standard_Real uf = cur->FirstParameter();
+      Standard_Real ul = cur->LastParameter();
+      if(uf <= W && W <= ul) return cur;
+    }  
+    return Handle(ChFiDS_HElSpine)();
+  }
 }
 
 //=======================================================================
@@ -174,7 +179,7 @@ Standard_Real  ChFiDS_Spine::LastParameter() const
 
 void ChFiDS_Spine::SetFirstParameter(const Standard_Real Par) 
 {
-#ifdef DEB
+#ifdef OCCT_DEBUG
   if(Par >= Precision::Confusion()) 
     cout<<"Interior extension at the start of guideline"<<endl;
   if(IsPeriodic())
@@ -192,7 +197,7 @@ void ChFiDS_Spine::SetFirstParameter(const Standard_Real Par)
 
 void ChFiDS_Spine::SetLastParameter(const Standard_Real Par) 
 {
-#ifdef DEB
+#ifdef OCCT_DEBUG
   Standard_Real lll = abscissa->Value(abscissa->Upper());
   if((Par - lll) <= -Precision::Confusion()) 
     cout<<"Interior extension at the end of guideline"<<endl;
@@ -347,7 +352,7 @@ void  ChFiDS_Spine::SetFirstTgt(const Standard_Real W)
 {
   if(IsPeriodic()) Standard_Failure::Raise
     ("No extension by tangent on periodic contours"); 
-#ifdef DEB
+#ifdef OCCT_DEBUG
   if(W >= Precision::Confusion()) 
     cout<<"Interior extension at start of the guideline"<<endl;
 #endif
@@ -371,7 +376,7 @@ void  ChFiDS_Spine::SetLastTgt(const Standard_Real W)
   if(IsPeriodic()) Standard_Failure::Raise
     ("No extension by tangent periodic contours"); 
 
-#ifdef DEB
+#ifdef OCCT_DEBUG
   Standard_Real L = W - abscissa->Value(abscissa->Upper());
   if(L <= -Precision::Confusion()) 
     cout<<"Interior extension at the end of guideline"<<endl;
@@ -491,7 +496,7 @@ void  ChFiDS_Spine::UnsetReference()
 void  ChFiDS_Spine::Load()
 {
   if(!abscissa.IsNull()){
-#ifdef DEB
+#ifdef OCCT_DEBUG
     cout<<"new load of CE"<<endl;
 #endif
   }
