@@ -3,8 +3,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -503,11 +503,22 @@ void Convert_ConicToBSplineCurve::BuildCosAndSin(
       alpha_2 = alpha * 0.5e0 ;
       p_param = - 1.0e0 / (alpha_2 * alpha_2) ;
      
-      if (alpha_2 <  M_PI * 0.5e0) {
-	tan_alpha_2 = Tan(alpha_2) ;
-	value1 = 3.0e0 * (tan_alpha_2 - alpha_2) ;
-        value1 = alpha_2 / value1 ;
-        p_param += value1 ;
+      if (alpha_2 <  M_PI * 0.5e0) 
+      {
+        if (alpha_2 < 1.0e-7)
+        {
+          // Fixed degenerate case, when obtain 0 / 0 uncertainty.
+          // According to Taylor aprroximation:
+          // b (gamma) = -6.0 / 15.0 + o(gamma^2)
+          p_param = -6.0 / 15.0;
+        }
+        else
+        {
+          tan_alpha_2 = Tan(alpha_2) ;
+          value1 = 3.0e0 * (tan_alpha_2 - alpha_2) ;
+          value1 = alpha_2 / value1 ;
+          p_param += value1 ;
+        }
       }
       q_param = (1.0e0 / 3.0e0)  + p_param ;
       
