@@ -4,8 +4,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -79,7 +79,7 @@ Standard_Integer DNaming_SphereDriver::Execute(TFunction_Logbook& theLog) const
   Handle(TDataStd_UAttribute) anObject = DNaming::GetObjectArg(aFunction,SPHERE_CENTER);
   Handle(TNaming_NamedShape) aNSCnt = DNaming::GetObjectValue(anObject);
   if (aNSCnt.IsNull() || aNSCnt->IsEmpty()) {
-#ifdef DEB
+#ifdef OCCT_DEBUG
     cout<<"SphereDriver:: Center point is null or empty"<<endl;
 #endif
     aFunction->SetFailure(WRONG_ARGUMENT);
@@ -96,7 +96,7 @@ Standard_Integer DNaming_SphereDriver::Execute(TFunction_Logbook& theLog) const
   
   TopoDS_Shape aCntShape = aNSCnt->Get();
   if(aCntShape.IsNull()) {
-#ifdef DEB
+#ifdef OCCT_DEBUG
     cout<<"SphereDriver:: Center point is null"<<endl;
 #endif
     aFunction->SetFailure(WRONG_ARGUMENT);
