@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -142,7 +142,7 @@ void DPrsStd::Factory(Draw_Interpretor& theDI)
   DDataStd::AllCommands(theDI);  
   DPrsStd::AllCommands(theDI);
   DDocStd::AllCommands(theDI);
-#ifdef DEB
+#ifdef OCCT_DEBUG
   cout << "Draw Plugin : All DF commands are loaded" << endl;
 #endif
 }
