@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -38,9 +38,7 @@
 #include <ViewerTest.hxx>
 #include <AIS_InteractiveContext.hxx> 
 #include <AIS_InteractiveObject.hxx>
-#include <AIS_Drawer.hxx> 
 #include <ViewerTest.hxx>
-#include <ViewerTest_Tool.hxx>
 #include <V3d_View.hxx>
 #include <TCollection_ExtendedString.hxx>
 #include <Quantity_NameOfColor.hxx>
@@ -175,7 +173,7 @@ static Standard_Integer DPrsStd_AISSet (Draw_Interpretor& di,
     if (!DDF::FindLabel(D->GetData(),arg[2],L)) return 1; 
     Standard_GUID guid;
     TCollection_ExtendedString str = arg[3];
-#ifdef DEB
+#ifdef OCCT_DEBUG
     cout << "Inputed parameter > " << str   << endl;
 #endif
     if ( str == "A" )  //axis
@@ -196,7 +194,7 @@ static Standard_Integer DPrsStd_AISSet (Draw_Interpretor& di,
 //      guid = TSketchStd_Edge::GetID();           //"b3aac90a-5b78-11d1-8940-080009dc3333"
 
     Handle(TPrsStd_AISPresentation) prs= TPrsStd_AISPresentation::Set(L, guid);
-#ifdef DEB
+#ifdef OCCT_DEBUG
     cout << "Driver GUID = ";
     prs->GetDriverGUID().ShallowDump(cout);
     cout << "\n";
@@ -241,7 +239,7 @@ static Standard_Integer DPrsStd_AISDriver (Draw_Interpretor& di,
       }
       else {
 	TCollection_ExtendedString str = arg[3];
-#ifdef DEB
+#ifdef OCCT_DEBUG
 	cout << "Inputed parameter > " << str   << endl;
 #endif
 	if ( str == "A" )  //axis
