@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -18,10 +18,6 @@
 
 
 // Modif : DFO 05/11/96
-#ifdef HAVE_CONFIG_H
-# include <oce-config.h>
-#endif
-
 #include <Draw.ixx>
 #include <Draw_Appli.hxx>
 
@@ -34,13 +30,10 @@
 #include <Standard_Stream.hxx>
 
 #include <stdio.h>
-#ifdef WNT
+#ifdef _WIN32
 extern Draw_Viewer dout;
 extern Standard_Boolean Draw_Batch;
 #endif
-#ifdef HAVE_STRINGS_H
-# include <strings.h>
-#endif
 
 extern Standard_Boolean Draw_BlackBackGround;
 
