@@ -1,9 +1,9 @@
-// Copyright (c) 2014 OPEN CASCADE SAS
+// Copyright (c) 2013-2014 OPEN CASCADE SAS
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -585,7 +585,6 @@ void GetNextEvent (Standard_Boolean  theWait,
   theWindowNumber   = [aWindow windowNumber];
 
   NSPoint aMouseLoc = [aView convertPoint: [anEvent locationInWindow] fromView: nil];
-  NSRect  aBounds   = [aView bounds];
 
   theX = Standard_Integer (aMouseLoc.x);
   theY = Standard_Integer (aMouseLoc.y);
