@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -78,8 +78,9 @@ void DrawDim_Radius::DrawOn(Draw_Display& dis) const
 
 //void AIS_RadiusDimension::ComputeOneFaceRadius(const Handle(Prs3d_Presentation)& aPresentation)
 //{
-
+#ifdef OCCT_DEBUG
   cout << "entree dans computeonefaceradius"<< endl;
+#endif
   BRepAdaptor_Surface surfAlgo (TopoDS::Face(myFShape));
   Standard_Real uFirst, uLast, vFirst, vLast;
   uFirst = surfAlgo.FirstUParameter();
