@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -14,20 +14,6 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-#ifdef HAVE_CONFIG_H
-# include <oce-config.h>
-#endif
-
-#ifdef HAVE_IOS
-# include <ios>
-#elif defined(HAVE_IOS_H)
-# include <ios.h>
-#endif
-
-#ifdef HAVE_STRINGS_H
-# include <strings.h>
-#endif
-
 #include <Standard_Stream.hxx>
 
 #include <Draw_Color.hxx>
@@ -1741,7 +1727,7 @@ static void pntsave(const Handle(Draw_Drawable3D)&d, ostream& OS)
 {
   Handle(DrawTrSurf_Point) 
     N = Handle(DrawTrSurf_Point)::DownCast(d);
-#if defined(HAVE_IOS) && !defined(__sgi) && !defined(IRIX)
+#if !defined(_WIN32) && !defined(__sgi) && !defined(IRIX)
   ios::fmtflags F = OS.flags();
   OS.setf(ios::scientific,ios::floatfield);
   OS.precision(15);
@@ -1758,7 +1744,7 @@ static void pntsave(const Handle(Draw_Drawable3D)&d, ostream& OS)
     OS << "0 ";
     OS << P.X() << " " << P.Y() << "\n";
   }
-#if defined(HAVE_IOS) && !defined(__sgi) && !defined(IRIX)
+#if !defined(_WIN32) && !defined(__sgi) && !defined(IRIX)
   OS.setf(F);
 #else
   OS.setf(form);
@@ -1803,7 +1789,7 @@ static void triasave(const Handle(Draw_Drawable3D)&d, ostream& OS)
 {
   Handle(DrawTrSurf_Triangulation) 
     T = Handle(DrawTrSurf_Triangulation)::DownCast(d);
-#if defined(HAVE_IOS) && !defined(__sgi) && !defined(IRIX)
+#if !defined(_WIN32) && !defined(__sgi) && !defined(IRIX)
   ios::fmtflags F = OS.flags();
   OS.setf(ios::scientific,ios::floatfield);
   OS.precision(15);
@@ -1812,7 +1798,7 @@ static void triasave(const Handle(Draw_Drawable3D)&d, ostream& OS)
   std::streamsize prec = OS.precision(15);
 #endif
   Poly::Write(T->Triangulation(),OS);
-#if defined(HAVE_IOS) && !defined(__sgi) && !defined(IRIX)
+#if !defined(_WIN32) && !defined(__sgi) && !defined(IRIX)
   OS.setf(F);
 #else
   OS.setf(form);
@@ -1844,7 +1830,7 @@ static void poly3dsave(const Handle(Draw_Drawable3D)&d, ostream& OS)
 {
   Handle(DrawTrSurf_Polygon3D) 
     T = Handle(DrawTrSurf_Polygon3D)::DownCast(d);
-#if defined(HAVE_IOS) && !defined(__sgi) && !defined(IRIX)
+#if !defined(_WIN32) && !defined(__sgi) && !defined(IRIX)
   ios::fmtflags F = OS.flags();
   OS.setf(ios::scientific,ios::floatfield);
   OS.precision(15);
@@ -1853,7 +1839,7 @@ static void poly3dsave(const Handle(Draw_Drawable3D)&d, ostream& OS)
   std::streamsize prec = OS.precision(15);
 #endif
   Poly::Write(T->Polygon3D(),OS);
-#if defined(HAVE_IOS) && !defined(__sgi) && !defined(IRIX)
+#if !defined(_WIN32) && !defined(__sgi) && !defined(IRIX)
   OS.setf(F);
 #else
   OS.setf(form);
@@ -1884,7 +1870,7 @@ static void poly2dsave(const Handle(Draw_Drawable3D)&d, ostream& OS)
 {
   Handle(DrawTrSurf_Polygon2D) 
     T = Handle(DrawTrSurf_Polygon2D)::DownCast(d);
-#if defined(HAVE_IOS) && !defined(__sgi) && !defined(IRIX)
+#if !defined(_WIN32) && !defined(__sgi) && !defined(IRIX)
   ios::fmtflags F = OS.flags();
   OS.setf(ios::scientific, ios::floatfield);
   OS.precision(15);
@@ -1893,7 +1879,7 @@ static void poly2dsave(const Handle(Draw_Drawable3D)&d, ostream& OS)
   std::streamsize prec = OS.precision(15);
 #endif
   Poly::Write(T->Polygon2D(),OS);
-#if defined(HAVE_IOS) && !defined(__sgi) && !defined(IRIX)
+#if !defined(_WIN32) && !defined(__sgi) && !defined(IRIX)
   OS.setf(F);
 #else
   OS.setf(form);
