@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -74,9 +74,7 @@ const Handle(Expr_GeneralExpression)& Expr_BinaryExpression::SubExpression (cons
       Standard_OutOfRange::Raise();
     }
   }
-#if defined (WNT) || !defined (DEB)
- return *(  ( Handle_Expr_GeneralExpression* )NULL  );
-#endif  // WNT || !DEB
+ return *(  ( Handle(Expr_GeneralExpression)* )NULL  );
 }
 
 Standard_Boolean Expr_BinaryExpression::ContainsUnknowns () const
