@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -20,13 +20,11 @@
 #include <Standard_ErrorHandler.hxx>
 #include <ExprIntrp_SyntaxError.hxx>
 
-TCollection_AsciiString ExprIntrp_thestring;
-Standard_Integer ExprIntrp_thecurchar=0;
+static TCollection_AsciiString ExprIntrp_thestring;
 
 Standard_Boolean ExprIntrp::Parse(const Handle(ExprIntrp_Generator)& gen, const TCollection_AsciiString& str)
 {
   ExprIntrp_Recept.SetMaster(gen);
-  ExprIntrp_thecurchar = 0;
   if (str.Length() == 0) return Standard_False;
   ExprIntrp_thestring = str;
   ExprIntrp_start_string(ExprIntrp_thestring.ToCString());
