@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -16,11 +16,11 @@
 
 #include <FWOSDriver_DriverFactory.ixx>
 
-#include <FWOSDriver_Driver.hxx>
+#include <CDF_FWOSDriver.hxx>
 FWOSDriver_DriverFactory::FWOSDriver_DriverFactory(){}
 
 
 Handle(CDF_MetaDataDriver) FWOSDriver_DriverFactory::Build() const {
-  static Handle(FWOSDriver_Driver) d =  new FWOSDriver_Driver();
+  static Handle(CDF_FWOSDriver) d =  new CDF_FWOSDriver();
   return d;
 }
