@@ -35,7 +35,7 @@ struct Font_FontMgr_FontAliasMapNode
 static const Font_FontMgr_FontAliasMapNode Font_FontMgr_MapOfFontsAliases[] =
 {
 
-#ifdef WNT
+#if defined(_WIN32) || defined(__APPLE__)
 
   { "Courier"                  , "Courier New"    , Font_FA_Regular },
   { "Times-Roman"              , "Times New Roman", Font_FA_Regular  },
@@ -48,6 +48,15 @@ static const Font_FontMgr_FontAliasMapNode Font_FontMgr_MapOfFontsAliases[] =
   { "Rock"                     , "Arial"          , Font_FA_Regular  },
   { "Iris"                     , "Lucida Console" , Font_FA_Regular  }
 
+#elif defined(__ANDROID__)
+
+  { "Courier"                  , "Droid Sans Mono", Font_FA_Regular },
+  { "Times-Roman"              , "Droid Serif"    , Font_FA_Regular  },
+  { "Times-Bold"               , "Droid Serif"    , Font_FA_Bold },
+  { "Times-Italic"             , "Droid Serif"    , Font_FA_Italic  },
+  { "Times-BoldItalic"         , "Droid Serif"    , Font_FA_BoldItalic  },
+  { "Arial"                    , "Roboto"         , Font_FA_Regular  },
+
 #else   //X11
 
   { "Courier"                  , "Courier"      , Font_FA_Regular },
@@ -55,7 +64,7 @@ static const Font_FontMgr_FontAliasMapNode Font_FontMgr_MapOfFontsAliases[] =
   { "Times-Bold"               , "Times"        , Font_FA_Bold },
   { "Times-Italic"             , "Times"        , Font_FA_Italic  },
   { "Times-BoldItalic"         , "Times"        , Font_FA_BoldItalic  },
-  { "Arial"                    , "Helvetica"    , Font_FA_Regular  }, 
+  { "Arial"                    , "Helvetica"    , Font_FA_Regular  },
   { "ZapfChancery-MediumItalic", "-adobe-itc zapf chancery-medium-i-normal--*-*-*-*-*-*-iso8859-1"              , Font_FA_Regular  },
   { "Symbol"                   , "-adobe-symbol-medium-r-normal--*-*-*-*-*-*-adobe-fontspecific"                , Font_FA_Regular  },
   { "ZapfDingbats"             , "-adobe-itc zapf dingbats-medium-r-normal--*-*-*-*-*-*-adobe-fontspecific"     , Font_FA_Regular  },
@@ -67,7 +76,7 @@ static const Font_FontMgr_FontAliasMapNode Font_FontMgr_MapOfFontsAliases[] =
 
 #define NUM_FONT_ENTRIES (int)(sizeof(Font_FontMgr_MapOfFontsAliases)/sizeof(Font_FontMgr_FontAliasMapNode))
 
-#if (defined(_WIN32) || defined(__WIN32__))
+#if defined(_WIN32)
 
   #include <windows.h>
   #include <stdlib.h>
@@ -89,6 +98,7 @@ static const Font_FontMgr_FontAliasMapNode Font_FontMgr_MapOfFontsAliases[] =
 #else
 
   #include <OSD_DirectoryIterator.hxx>
+  #include <OSD_FileIterator.hxx>
   #include <OSD_Path.hxx>
   #include <OSD_File.hxx>
   #include <OSD_OpenMode.hxx>
@@ -105,9 +115,14 @@ static const Font_FontMgr_FontAliasMapNode Font_FontMgr_MapOfFontsAliases[] =
       "ttc",
       "pfa",
       "pfb",
+    #ifdef __APPLE__
+      // Datafork TrueType (OS X), obsolete
+      //"dfont",
+    #endif
       NULL
     };
 
+  #if !defined(__ANDROID__) && !defined(__APPLE__)
     // X11 configuration file in plain text format (obsolete - doesn't exists in modern distributives)
     static Standard_CString myFontServiceConf[] = {"/etc/X11/fs/config",
                                                    "/usr/X11R6/lib/X11/fs/config",
@@ -115,6 +130,7 @@ static const Font_FontMgr_FontAliasMapNode Font_FontMgr_MapOfFontsAliases[] =
                                                    NULL
                                                   };
 
+  #endif                                          
   #ifdef __APPLE__
     // default fonts paths in Mac OS X
     static Standard_CString myDefaultFontsDirs[] = {"/System/Library/Fonts",
@@ -123,7 +139,8 @@ static const Font_FontMgr_FontAliasMapNode Font_FontMgr_MapOfFontsAliases[] =
                                                    };
   #else
     // default fonts paths in most Unix systems (Linux and others)
-    static Standard_CString myDefaultFontsDirs[] = {"/usr/share/fonts",
+    static Standard_CString myDefaultFontsDirs[] = {"/system/fonts",         // Android
+                                                    "/usr/share/fonts",
                                                     "/usr/local/share/fonts",
                                                     NULL
                                                    };
@@ -187,9 +204,14 @@ static Handle(Font_SystemFont) checkFont (const Handle(Font_FTLibrary)& theFTLib
     anAspect = Font_FA_Bold;
   }
 
-  Handle(TCollection_HAsciiString) aFontName = new TCollection_HAsciiString (aFontFace->family_name);
-  Handle(TCollection_HAsciiString) aFontPath = new TCollection_HAsciiString (theFontPath);
-  Handle(Font_SystemFont) aResult = new Font_SystemFont (aFontName, anAspect, aFontPath);
+  Handle(Font_SystemFont) aResult;
+  if (aFontFace->family_name != NULL                           // skip broken fonts (error in FreeType?)
+   && FT_Select_Charmap (aFontFace, ft_encoding_unicode) == 0) // Font_FTFont supports only UNICODE fonts
+  {
+    Handle(TCollection_HAsciiString) aFontName = new TCollection_HAsciiString (aFontFace->family_name);
+    Handle(TCollection_HAsciiString) aFontPath = new TCollection_HAsciiString (theFontPath);
+    aResult = new Font_SystemFont (aFontName, anAspect, aFontPath);
+  }
 
   FT_Done_Face (aFontFace);
 
@@ -361,6 +383,7 @@ void Font_FontMgr::InitFontDataBase()
 #else
 
   NCollection_Map<TCollection_AsciiString> aMapOfFontsDirs;
+#if !defined(__ANDROID__) && !defined(__APPLE__)
   const OSD_Protection aProtectRead (OSD_R, OSD_R, OSD_R, OSD_R);
 
   // read fonts directories from font service config file (obsolete)
@@ -418,6 +441,7 @@ void Font_FontMgr::InitFontDataBase()
     aFile.Close();
   }
 
+#endif
   // append default directories
   for (Standard_Integer anIter = 0; myDefaultFontsDirs[anIter] != NULL; ++anIter)
   {
@@ -438,6 +462,24 @@ void Font_FontMgr::InitFontDataBase()
   for (NCollection_Map<TCollection_AsciiString>::Iterator anIter (aMapOfFontsDirs);
        anIter.More(); anIter.Next())
   {
+  #if defined(__ANDROID__) || defined(__APPLE__)
+    OSD_Path aFolderPath (anIter.Value());
+    for (OSD_FileIterator aFileIter (aFolderPath, "*"); aFileIter.More(); aFileIter.Next())
+    {
+      OSD_Path aFontFilePath;
+      aFileIter.Values().Path (aFontFilePath);
+
+      TCollection_AsciiString aFontFileName;
+      aFontFilePath.SystemName (aFontFileName);
+      aFontFileName = anIter.Value() + "/" + aFontFileName;
+
+      Handle(Font_SystemFont) aNewFont = checkFont (aFtLibrary, aFontFileName.ToCString());
+      if (!aNewFont.IsNull())
+      {
+        myListOfFonts.Append (aNewFont);
+      }
+    }
+  #else
     OSD_File aReadFile (anIter.Value() + "/fonts.dir");
     if (!aReadFile.Exists())
     {
@@ -513,10 +555,10 @@ void Font_FontMgr::InitFontDataBase()
         {
           myListOfFonts.Append (aNewFontFromXLFD);
         }
-
       }
     }
     aReadFile.Close();
+  #endif
   }
 #endif
 }
@@ -553,7 +595,7 @@ Handle(Font_SystemFont) Font_FontMgr::GetFont (const Handle(TCollection_HAsciiSt
 {
   if ( (theFontSize < 2 && theFontSize != -1) || theFontName.IsNull())
   {
-    return NULL; 
+    return NULL;
   }
 
   for (Font_NListOfSystemFont::Iterator aFontsIterator (myListOfFonts);
