@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -21,6 +21,7 @@
 #include <gp_Vec2d.hxx>
 #include <gp_XYZ.hxx>
 #include <Precision.hxx>
+#include <TColStd_Array1OfReal.hxx>
 
 inline static void D0 (const Adaptor3d_Curve& C, const Standard_Real U, gp_Pnt& P)
 {
@@ -58,6 +59,23 @@ static void D2 (const Adaptor2d_Curve2d& C, const Standard_Real U,
   VV2.SetCoord (X, Y, 0.0);
 }
 
+// Return number of interval of continuity on which theParam is located.
+// Last parameter is used to increase search speed.
+static Standard_Integer getIntervalIdx(const Standard_Real theParam, 
+                                       TColStd_Array1OfReal& theIntervs,
+                                       const Standard_Integer thePreviousIdx)
+{
+  Standard_Integer anIdx;
+  for(anIdx = thePreviousIdx; anIdx < theIntervs.Upper(); anIdx++)
+  {
+    if (theParam >= theIntervs(anIdx) && 
+        theParam <= theIntervs(anIdx + 1)) // Inside of anIdx interval.
+    {
+      break;
+    }
+  }
+  return anIdx;
+}
 
 //=======================================================================
 //function : CPnts_TangentialDeflection
@@ -107,6 +125,33 @@ Standard_Integer GCPnts_TangentialDeflection::AddPoint
   return index;
 }
 
+//=======================================================================
+//function : ArcAngularStep
+//purpose  : 
+//=======================================================================
+Standard_Real GCPnts_TangentialDeflection::ArcAngularStep(
+  const Standard_Real theRadius,
+  const Standard_Real theLinearDeflection,
+  const Standard_Real theAngularDeflection,
+  const Standard_Real theMinLength)
+{
+  Standard_ConstructionError_Raise_if(theRadius < 0.0, "Negative radius");
+
+  const Standard_Real aPrecision = Precision::Confusion();
+
+  Standard_Real Du = 0.0, aMinSizeAng = 0.0;
+  if (theRadius > aPrecision)
+  {
+    Du = Max(1.0 - (theLinearDeflection / theRadius), 0.0);
+
+    // It is not suitable to consider min size greater than 1/4 arc len.
+    if (theMinLength > aPrecision)
+      aMinSizeAng = Min(theMinLength / theRadius, M_PI_2);
+  }
+  Du = 2.0 * ACos(Du);
+  Du = Max(Min(Du, theAngularDeflection), aMinSizeAng);
+  return Du;
+}
 
 #include <Geom_BezierCurve.hxx>
 #include <Geom_BSplineCurve.hxx>
@@ -130,7 +175,3 @@ Standard_Integer GCPnts_TangentialDeflection::AddPoint
 #undef Handle_TheBezierCurve
 #undef Handle_TheBSplineCurve
 #undef TheCurve
-
-
-
-
