@@ -3,8 +3,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -86,7 +86,7 @@ GccAna_Circ2d3Tan::
      gp_Lin2d linint1(Bis1.ThisSolution());
      Handle(GccInt_Bisec) Sol2 = Bis2.ThisSolution();
      GccInt_IType typ2 = Sol2->ArcType();
-#ifdef DEB
+#ifdef OCCT_DEBUG
      gp_Lin2d linintb(Bis1.ThisSolution());
 #else
      Bis1.ThisSolution() ;
