@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -17,9 +17,9 @@
 #include <Geom2dGcc_Circ2d2TanOn.ixx>
 #include <Geom2dAdaptor_Curve.hxx>
 #include <GccAna_Circ2d2TanOn.hxx>
-#include <Geom2dGcc_MyCirc2d2TanOn.hxx>
-#include <Geom2dGcc_MyC2d2TanOn.hxx>
-#include <Geom2dGcc_MyQCurve.hxx>
+#include <Geom2dGcc_Circ2d2TanOnGeo.hxx>
+#include <Geom2dGcc_Circ2d2TanOnIter.hxx>
+#include <Geom2dGcc_QCurve.hxx>
 #include <GccEnt_BadQualifier.hxx>
 #include <Geom2d_Circle.hxx>
 #include <Geom2d_Line.hxx>
@@ -210,7 +210,7 @@ Geom2dGcc_Circ2d2TanOn::
 	  gp_Circ2d c2(CCC2->Circ2d());
 	  GccEnt_QualifiedCirc Qc2 =
 	    GccEnt_QualifiedCirc(c2,Qualified2.Qualifier());
-	  Geom2dGcc_MyCirc2d2TanOn CircGeo(Qc1,Qc2,OnCurve,Tolerance);
+	  Geom2dGcc_Circ2d2TanOnGeo CircGeo(Qc1,Qc2,OnCurve,Tolerance);
 	  WellDone = CircGeo.IsDone();
 	  NbrSol = CircGeo.NbSolutions();
 	  for(Standard_Integer i=1; i<=NbrSol; i++) {
@@ -223,7 +223,7 @@ Geom2dGcc_Circ2d2TanOn::
 	  gp_Lin2d l2(LL2->Lin2d());
 	  GccEnt_QualifiedLin Ql2 =
 	    GccEnt_QualifiedLin(l2,Qualified2.Qualifier());
-	  Geom2dGcc_MyCirc2d2TanOn CircGeo(Qc1,Ql2,OnCurve,Tolerance);
+	  Geom2dGcc_Circ2d2TanOnGeo CircGeo(Qc1,Ql2,OnCurve,Tolerance);
 	  WellDone = CircGeo.IsDone();
 	  NbrSol = CircGeo.NbSolutions();
 	  for(Standard_Integer i=1; i<=NbrSol; i++) {
@@ -242,7 +242,7 @@ Geom2dGcc_Circ2d2TanOn::
 	  gp_Circ2d c2(CCC2->Circ2d());
 	  GccEnt_QualifiedCirc Qc2 =
 	    GccEnt_QualifiedCirc(c2,Qualified2.Qualifier());
-	  Geom2dGcc_MyCirc2d2TanOn CircGeo(Qc2,Ql1,OnCurve,Tolerance);
+	  Geom2dGcc_Circ2d2TanOnGeo CircGeo(Qc2,Ql1,OnCurve,Tolerance);
 	  WellDone = CircGeo.IsDone();
 	  NbrSol = CircGeo.NbSolutions();
 	  for(Standard_Integer i=1; i<=NbrSol; i++) {
@@ -256,7 +256,7 @@ Geom2dGcc_Circ2d2TanOn::
 	  gp_Lin2d l2(LL2->Lin2d());
 	  GccEnt_QualifiedLin Ql2 =
 	    GccEnt_QualifiedLin(l2,Qualified2.Qualifier());
-	  Geom2dGcc_MyCirc2d2TanOn CircGeo(Ql1,Ql2,OnCurve,Tolerance);
+	  Geom2dGcc_Circ2d2TanOnGeo CircGeo(Ql1,Ql2,OnCurve,Tolerance);
 	  WellDone = CircGeo.IsDone();
 	  NbrSol = CircGeo.NbSolutions();
 	  for(Standard_Integer i=1; i<=NbrSol; i++) {
@@ -267,18 +267,13 @@ Geom2dGcc_Circ2d2TanOn::
       }
     }
   }
-
-//=============================================================================
-//                            Appel a GccIter.                                +
-//=============================================================================
-
   else {
-    Geom2dGcc_MyQCurve Qc1(C1,Qualified1.Qualifier());
-    Geom2dGcc_MyQCurve Qc2(C2,Qualified2.Qualifier());
+    Geom2dGcc_QCurve Qc1(C1,Qualified1.Qualifier());
+    Geom2dGcc_QCurve Qc2(C2,Qualified2.Qualifier());
     if ((Type3 == GeomAbs_Circle || Type3 == GeomAbs_Line)) {
       if (Type3 == GeomAbs_Circle) {
 	Handle(Geom2d_Circle) CCon = Handle(Geom2d_Circle)::DownCast(Con);
-	Geom2dGcc_MyC2d2TanOn Circ(Qc1,Qc2,CCon->Circ2d(),
+	Geom2dGcc_Circ2d2TanOnIter Circ(Qc1,Qc2,CCon->Circ2d(),
 				   Param1,Param2,ParamOn,Tolerance);
 	WellDone = Circ.IsDone();
 	NbrSol = 1;
@@ -292,7 +287,7 @@ Geom2dGcc_Circ2d2TanOn::
       }
       else {
 	Handle(Geom2d_Line) LLon = Handle(Geom2d_Line)::DownCast(Con);
-	Geom2dGcc_MyC2d2TanOn Circ(Qc1,Qc2,LLon->Lin2d(),
+	Geom2dGcc_Circ2d2TanOnIter Circ(Qc1,Qc2,LLon->Lin2d(),
 				       Param1,Param2,ParamOn,Tolerance);
 	WellDone = Circ.IsDone();
 	NbrSol = 1;
@@ -306,7 +301,7 @@ Geom2dGcc_Circ2d2TanOn::
 	Circ.Tangency2(par2sol(1),pararg2(1),pnttg2sol(1));
       }
     }
-    Geom2dGcc_MyC2d2TanOn Circ(Qc1,Qc2,OnCurve,
+    Geom2dGcc_Circ2d2TanOnIter Circ(Qc1,Qc2,OnCurve,
 				   Param1,Param2,ParamOn,Tolerance);
     WellDone = Circ.IsDone();
     NbrSol = 1;
@@ -417,7 +412,7 @@ Geom2dGcc_Circ2d2TanOn::
 	Handle(Geom2d_Circle) CCC1 = Handle(Geom2d_Circle)::DownCast(CC1);
 	gp_Circ2d c1(CCC1->Circ2d());
 	GccEnt_QualifiedCirc Qc1(c1,Qualified1.Qualifier());
-	Geom2dGcc_MyCirc2d2TanOn CircGeo(Qc1,Point->Pnt2d(),OnCurve,Tolerance);
+	Geom2dGcc_Circ2d2TanOnGeo CircGeo(Qc1,Point->Pnt2d(),OnCurve,Tolerance);
 	WellDone = CircGeo.IsDone();
 	NbrSol = CircGeo.NbSolutions();
 	for(Standard_Integer i=1; i<=NbrSol; i++) {
@@ -429,7 +424,7 @@ Geom2dGcc_Circ2d2TanOn::
 	Handle(Geom2d_Line) LLL1 = Handle(Geom2d_Line)::DownCast(CC1);
 	gp_Lin2d l1(LLL1->Lin2d());
 	GccEnt_QualifiedLin Ql1(l1,Qualified1.Qualifier());
-	Geom2dGcc_MyCirc2d2TanOn CircGeo(Ql1,Point->Pnt2d(),OnCurve,Tolerance);
+	Geom2dGcc_Circ2d2TanOnGeo CircGeo(Ql1,Point->Pnt2d(),OnCurve,Tolerance);
 	WellDone = CircGeo.IsDone();
 	NbrSol = CircGeo.NbSolutions();
 	for(Standard_Integer i=1; i<=NbrSol; i++) {
@@ -438,18 +433,13 @@ Geom2dGcc_Circ2d2TanOn::
 	Results(CircGeo);
       }
     }
-  }
-
-//=============================================================================
-//                            Appel a GccIter.                                +
-//=============================================================================
-
+  }                                   
   else {
-    Geom2dGcc_MyQCurve Qc1(C1,Qualified1.Qualifier());
+    Geom2dGcc_QCurve Qc1(C1,Qualified1.Qualifier());
     if ((Type3 == GeomAbs_Circle || Type3 == GeomAbs_Line)) {
       if (Type3 == GeomAbs_Circle) {
 	Handle(Geom2d_Circle) CCon = Handle(Geom2d_Circle)::DownCast(Con);
-	Geom2dGcc_MyC2d2TanOn Circ(Qc1,Point->Pnt2d(),CCon->Circ2d(),
+	Geom2dGcc_Circ2d2TanOnIter Circ(Qc1,Point->Pnt2d(),CCon->Circ2d(),
 				   Param1,ParamOn,Tolerance);
 	WellDone = Circ.IsDone();
 	NbrSol = 1;
@@ -462,7 +452,7 @@ Geom2dGcc_Circ2d2TanOn::
       }
       else {
 	Handle(Geom2d_Line) LLon = Handle(Geom2d_Line)::DownCast(Con);
-	Geom2dGcc_MyC2d2TanOn Circ(Qc1,Point->Pnt2d(),LLon->Lin2d(),
+	Geom2dGcc_Circ2d2TanOnIter Circ(Qc1,Point->Pnt2d(),LLon->Lin2d(),
 				       Param1,ParamOn,Tolerance);
 	WellDone = Circ.IsDone();
 	NbrSol = 1;
@@ -475,7 +465,7 @@ Geom2dGcc_Circ2d2TanOn::
       }
     }
     else {
-      Geom2dGcc_MyC2d2TanOn Circ(Qc1,Point->Pnt2d(),OnCurve,
+      Geom2dGcc_Circ2d2TanOnIter Circ(Qc1,Point->Pnt2d(),OnCurve,
 				 Param1,ParamOn,Tolerance);
       WellDone = Circ.IsDone();
       NbrSol = 1;
@@ -550,7 +540,7 @@ Geom2dGcc_Circ2d2TanOn::
 //=============================================================================
 
   else {
-    Geom2dGcc_MyCirc2d2TanOn CircGeo(Point1->Pnt2d(),Point2->Pnt2d(),
+    Geom2dGcc_Circ2d2TanOnGeo CircGeo(Point1->Pnt2d(),Point2->Pnt2d(),
 				     OnCurve,Tolerance);
     WellDone = CircGeo.IsDone();
     NbrSol = CircGeo.NbSolutions();
@@ -576,7 +566,7 @@ void Geom2dGcc_Circ2d2TanOn::Results(const GccAna_Circ2d2TanOn& Circ)
   }
 }
 
-void Geom2dGcc_Circ2d2TanOn::Results(const Geom2dGcc_MyCirc2d2TanOn& Circ)
+void Geom2dGcc_Circ2d2TanOn::Results(const Geom2dGcc_Circ2d2TanOnGeo& Circ)
 {
   for (Standard_Integer j = 1; j <= NbrSol; j++) {
     cirsol(j)   = Circ.ThisSolution(j);
