@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -15,9 +15,9 @@
 // commercial license or contractual agreement.
 
 #include <Geom2dGcc_Lin2d2Tan.ixx>
-#include <Geom2dGcc_MyQCurve.hxx>
+#include <Geom2dGcc_QCurve.hxx>
 #include <GccAna_Lin2d2Tan.hxx>
-#include <Geom2dGcc_MyL2d2Tan.hxx>
+#include <Geom2dGcc_Lin2d2TanIter.hxx>
 #include <Geom2d_Circle.hxx>
 #include <GccEnt_QualifiedCirc.hxx>
 #include <StdFail_NotDone.hxx>
@@ -74,13 +74,13 @@ Geom2dGcc_Lin2d2Tan::
     }
   }
   else {
-    Geom2dGcc_MyQCurve Qc1(C1,Qualified1.Qualifier());
+    Geom2dGcc_QCurve Qc1(C1,Qualified1.Qualifier());
     Standard_Real      a1FPar      = Geom2dGcc_CurveTool::FirstParameter(C1);
     Standard_Real      a1LPar      = Geom2dGcc_CurveTool::LastParameter(C1);
     Standard_Integer   aNbSamples1 = Geom2dGcc_CurveTool::NbSamples(C1);
     Standard_Real      aStep1      = (a1LPar - a1FPar)/aNbSamples1;
     Standard_Real      Param1      = a1FPar;
-    Geom2dGcc_MyQCurve Qc2(C2,Qualified2.Qualifier());
+    Geom2dGcc_QCurve Qc2(C2,Qualified2.Qualifier());
     Standard_Real      a2FPar      = Geom2dGcc_CurveTool::FirstParameter(C2);
     Standard_Real      a2LPar      = Geom2dGcc_CurveTool::LastParameter(C2);
     Standard_Integer   aNbSamples2 = Geom2dGcc_CurveTool::NbSamples(C2);
@@ -93,7 +93,7 @@ Geom2dGcc_Lin2d2Tan::
       Param2 = a2FPar;
 
       for (j = 0; j <= aNbSamples2 && NbrSol < 4; j++) {
-	Geom2dGcc_MyL2d2Tan Lin(Qc1,Qc2,Param1,Param2,Tolang);
+	Geom2dGcc_Lin2d2TanIter Lin(Qc1,Qc2,Param1,Param2,Tolang);
 
 	if (Lin.IsDone()) {
 	  if (Add(NbrSol + 1, Lin, Tolang, C1, C2))
@@ -149,7 +149,7 @@ Geom2dGcc_Lin2d2Tan::
     }
   }
   else {
-    Geom2dGcc_MyQCurve Qc1(C1,Qualified1.Qualifier());
+    Geom2dGcc_QCurve Qc1(C1,Qualified1.Qualifier());
     Standard_Real      aFirstPar  = Geom2dGcc_CurveTool::FirstParameter(C1);
     Standard_Real      aLastPar   = Geom2dGcc_CurveTool::LastParameter(C1);
     Standard_Integer   aNbSamples = Geom2dGcc_CurveTool::NbSamples(C1);
@@ -158,7 +158,7 @@ Geom2dGcc_Lin2d2Tan::
     Standard_Integer   i;
     
     for (i = 0; i <= aNbSamples && NbrSol < 2; i++) {
-      Geom2dGcc_MyL2d2Tan Lin(Qc1,ThePoint,Param1,Tolang);
+      Geom2dGcc_Lin2d2TanIter Lin(Qc1,ThePoint,Param1,Tolang);
 
       if (Lin.IsDone()) {
 	if (Add(NbrSol + 1, Lin, Tolang, C1, Geom2dAdaptor_Curve()))
@@ -224,9 +224,9 @@ Geom2dGcc_Lin2d2Tan::
     }
   }
   else {
-    Geom2dGcc_MyQCurve Qc1(C1,Qualified1.Qualifier());
-    Geom2dGcc_MyQCurve Qc2(C2,Qualified2.Qualifier());
-    Geom2dGcc_MyL2d2Tan Lin(Qc1,Qc2,Param1,Param2,Tolang);
+    Geom2dGcc_QCurve Qc1(C1,Qualified1.Qualifier());
+    Geom2dGcc_QCurve Qc2(C2,Qualified2.Qualifier());
+    Geom2dGcc_Lin2d2TanIter Lin(Qc1,Qc2,Param1,Param2,Tolang);
     WellDone = Lin.IsDone();
 //  Modified by Sergey KHROMOV - Thu Apr  5 17:51:59 2001 Begin
     if (WellDone) {
@@ -283,8 +283,8 @@ Geom2dGcc_Lin2d2Tan::
     }
   }
   else {
-    Geom2dGcc_MyQCurve Qc1(C1,Qualified1.Qualifier());
-    Geom2dGcc_MyL2d2Tan Lin(Qc1,ThePoint,Param1,Tolang);
+    Geom2dGcc_QCurve Qc1(C1,Qualified1.Qualifier());
+    Geom2dGcc_Lin2d2TanIter Lin(Qc1,ThePoint,Param1,Tolang);
     WellDone = Lin.IsDone();
 //  Modified by Sergey KHROMOV - Thu Apr  5 17:53:01 2001 Begin
     if (WellDone) {
@@ -355,7 +355,7 @@ void Geom2dGcc_Lin2d2Tan::
 }
 
 Standard_Boolean Geom2dGcc_Lin2d2Tan::Add(const Standard_Integer     theIndex,
-					  const Geom2dGcc_MyL2d2Tan &theLin,
+					  const Geom2dGcc_Lin2d2TanIter &theLin,
 					  const Standard_Real        theTol,
 					  const Geom2dAdaptor_Curve &theC1,
 					  const Geom2dAdaptor_Curve &theC2)
