@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -31,7 +31,7 @@
 #include <math_Vector.hxx>
 #include <AppParCurves_HArray1OfConstraintCouple.hxx>
 #include <AppParCurves_ConstraintCouple.hxx>
-#include <AppDef_TheVariational.hxx>
+#include <AppDef_Variational.hxx>
 
 
 //=======================================================================
@@ -325,7 +325,7 @@ void GeomAPI_PointsToBSplineSurface::Init(const TColgp_Array2OfPnt& Points,
   }
   
 
-  AppDef_TheVariational Variation(Line, 1, NbPointJ, TABofCC);
+  AppDef_Variational Variation(Line, 1, NbPointJ, TABofCC);
 
 //===================================
   Standard_Integer theMaxSegments = 1000;
@@ -390,7 +390,7 @@ void GeomAPI_PointsToBSplineSurface::Init(const TColgp_Array2OfPnt& Points,
   }
   
 
-  AppDef_TheVariational Variation2(Line2, 1, NbPointI, TABofCC2);
+  AppDef_Variational Variation2(Line2, 1, NbPointI, TABofCC2);
 
   Variation2.SetMaxDegree(DegMax);
   Variation2.SetContinuity(Continuity);
@@ -657,7 +657,7 @@ void GeomAPI_PointsToBSplineSurface::Init(const TColStd_Array2OfReal& ZPoints,
 
 
 //=======================================================================
-//function : Handle_Geom_BSplineSurface&
+//function : Handle(Geom_BSplineSurface)&
 //purpose  : 
 //=======================================================================
 
