@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -84,7 +84,7 @@
 #include <TColgp_Array1OfPnt.hxx>
 #include <TColGeom_SequenceOfCurve.hxx>
 
-#ifdef DEB
+#ifdef OCCT_DEBUG
 static Standard_Boolean Affich = Standard_False;
 static Standard_Integer NbSections = 0;
 #endif
@@ -498,7 +498,7 @@ void GeomFill_Pipe::Init(const Handle(Geom_Curve)& Path,
     }
 
   case GeomFill_IsDarboux :
-#if DEB
+#ifdef OCCT_DEBUG
     {
       cout << "Option Darboux: non realisable" << endl; 
     }
@@ -875,7 +875,7 @@ void GeomFill_Pipe::Perform(const Standard_Real Tol,
 		 myAdpPath->LastParameter(),
 		 Tol, Tol, 0., 0.01,
 		 TheConti, DegMax, NbMaxSegment);
-#if DEB
+#ifdef OCCT_DEBUG
    cout << "Tuyau : ";
    App.Dump(cout);
    cout << endl;
@@ -1064,7 +1064,7 @@ void GeomFill_Pipe::ApproxSurf(const Standard_Boolean WithParameters) {
 
   Section.Perform(myPolynomial);
   
-#ifdef DEB
+#ifdef OCCT_DEBUG
   if ( Affich) {
     Standard_Integer NbPoles,NbKnots,Degree,NbPoles2d;
     Section.GetShape(NbPoles,NbKnots,Degree,NbPoles2d);
@@ -1100,7 +1100,7 @@ void GeomFill_Pipe::ApproxSurf(const Standard_Boolean WithParameters) {
   App.Perform( Line, Section, 30);
 
   if ( !App.IsDone()) {
-#ifdef DEB    
+#ifdef OCCT_DEBUG
     // on affiche les sections sous debug
     Standard_Integer NbPoles,NbKnots,Degree,NbPoles2d;
     Section.GetShape(NbPoles,NbKnots,Degree,NbPoles2d);
