@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -43,7 +43,7 @@ GeomFill_SectionGenerator::GeomFill_SectionGenerator()
 //purpose  : 
 //=======================================================================
 
-void GeomFill_SectionGenerator::SetParam(const Handle_TColStd_HArray1OfReal & Params)
+void GeomFill_SectionGenerator::SetParam(const Handle(TColStd_HArray1OfReal) & Params)
 {
   Standard_Integer ii, L =  Params->Upper()-Params->Lower()+1;
   myParams = Params;
