@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -18,31 +18,31 @@
 #include <Geom_Curve.hxx>
 #include <GeomAbs_Shape.hxx>
 
-void  GeomLProp_CurveTool::Value(const Handle_Geom_Curve& C, 
+void  GeomLProp_CurveTool::Value(const Handle(Geom_Curve)& C, 
 	    const Standard_Real U, gp_Pnt& P)
 {
   P = C->Value(U);
 }
 
-void  GeomLProp_CurveTool::D1(const Handle_Geom_Curve& C, 
+void  GeomLProp_CurveTool::D1(const Handle(Geom_Curve)& C, 
 	 const Standard_Real U, gp_Pnt& P, gp_Vec& V1)
 {
   C->D1(U, P, V1);
 }
 
-void  GeomLProp_CurveTool::D2(const Handle_Geom_Curve& C, 
+void  GeomLProp_CurveTool::D2(const Handle(Geom_Curve)& C, 
 	 const Standard_Real U, gp_Pnt& P, gp_Vec& V1, gp_Vec& V2)
 {
   C->D2(U, P, V1, V2);
 }
 
-void  GeomLProp_CurveTool::D3(const Handle_Geom_Curve& C, 
+void  GeomLProp_CurveTool::D3(const Handle(Geom_Curve)& C, 
 	 const Standard_Real U, gp_Pnt& P, gp_Vec& V1, gp_Vec& V2, gp_Vec& V3)
 {
   C->D3(U, P, V1, V2, V3);
 }
 
-Standard_Integer  GeomLProp_CurveTool::Continuity(const Handle_Geom_Curve& C)
+Standard_Integer  GeomLProp_CurveTool::Continuity(const Handle(Geom_Curve)& C)
 {
   GeomAbs_Shape s = C->Continuity();
   switch (s) {
@@ -64,12 +64,12 @@ Standard_Integer  GeomLProp_CurveTool::Continuity(const Handle_Geom_Curve& C)
   return 0;
 }
 
-Standard_Real  GeomLProp_CurveTool::FirstParameter(const Handle_Geom_Curve& C)
+Standard_Real  GeomLProp_CurveTool::FirstParameter(const Handle(Geom_Curve)& C)
 {
   return C->FirstParameter();
 }
 
-Standard_Real  GeomLProp_CurveTool::LastParameter(const Handle_Geom_Curve& C)
+Standard_Real  GeomLProp_CurveTool::LastParameter(const Handle(Geom_Curve)& C)
 {
   return C->LastParameter();
 }
