@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -88,3 +88,22 @@ Handle(GeomTools_UndefinedTypeHandler) GeomTools::GetUndefinedTypeHandler()
 {
   return theActiveHandler;
 }
+
+//=======================================================================
+//function : GetReal
+//purpose  : 
+//=======================================================================
+
+void GeomTools::GetReal(Standard_IStream& IS,Standard_Real& theValue)
+{
+  theValue = 0.;
+  if (IS.eof()) 
+    return;
+
+  char buffer[256];
+  buffer[0] = '\0';
+  std::streamsize anOldWide = IS.width(256);
+  IS >> buffer;
+  IS.width(anOldWide);
+  theValue = Strtod(buffer, NULL);
+}
