@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -56,11 +56,8 @@
 #include <TColStd_Array1OfReal.hxx>
 #include <TColStd_HArray1OfReal.hxx>
 #include <TColStd_HArray1OfBoolean.hxx>
-#include <Handle_TColStd_HArray1OfReal.hxx>
-#include <Handle_TColStd_HArray1OfBoolean.hxx>
 #include <AppParCurves_MultiBSpCurve.hxx>
 #include <AppDef_MultiLine.hxx>
-#include <AppDef_TheVariational.hxx>
 #include <AppParCurves_HArray1OfConstraintCouple.hxx>
 #include <AppParCurves_ConstraintCouple.hxx>
 #include <GC_MakeSegment.hxx>
@@ -75,7 +72,7 @@ Standard_IMPORT Draw_Color DrawTrSurf_CurveColor(const Draw_Color);
 
 
 static Standard_Integer solutions(Draw_Interpretor& di,
-				  Geom2dGcc_Circ2d2TanRad& ct3, const char* name) 
+                                  Geom2dGcc_Circ2d2TanRad& ct3, const char* name) 
 {
   char solname[200];
 
@@ -99,7 +96,7 @@ static Standard_Integer solutions(Draw_Interpretor& di,
 }
 
 static Standard_Integer solutions(Draw_Interpretor& di,
-				  Geom2dGcc_Circ2d3Tan& ct3, const char* name) 
+                                  Geom2dGcc_Circ2d3Tan& ct3, const char* name) 
 {
   char solname[200];
 
@@ -138,7 +135,7 @@ static Standard_Integer cirtang (Draw_Interpretor& di,Standard_Integer n, const
   Standard_Boolean ip1 = DrawTrSurf::GetPoint2d(a[2],P1);
   Standard_Boolean ip2 = DrawTrSurf::GetPoint2d(a[3],P2);
   Standard_Boolean ip3 = DrawTrSurf::GetPoint2d(a[4],P3);
-  
+
   Standard_Real tol = Precision::Confusion();
   if (n > 5) tol = Draw::Atof(a[5]);
 
@@ -148,84 +145,84 @@ static Standard_Integer cirtang (Draw_Interpretor& di,Standard_Integer n, const
     if (!C2.IsNull()) {
       // C-C-...
       if (!C3.IsNull()) {
-	// C-C-C
-	Geom2dGcc_Circ2d3Tan ct3(Geom2dGcc::Unqualified(C1),
-				 Geom2dGcc::Unqualified(C2),
-				 Geom2dGcc::Unqualified(C3),
-				 tol,0,0,0);
-	return solutions(di,ct3,a[1]);
+        // C-C-C
+        Geom2dGcc_Circ2d3Tan ct3(Geom2dGcc::Unqualified(C1),
+          Geom2dGcc::Unqualified(C2),
+          Geom2dGcc::Unqualified(C3),
+          tol,0,0,0);
+        return solutions(di,ct3,a[1]);
       }
 
       else if (ip3) {
-	// C-C-P
-	Geom2dGcc_Circ2d3Tan ct3(Geom2dGcc::Unqualified(C1),
-				 Geom2dGcc::Unqualified(C2),
-				 new Geom2d_CartesianPoint(P3),
-				 tol,0,0);
-	return solutions(di,ct3,a[1]);
+        // C-C-P
+        Geom2dGcc_Circ2d3Tan ct3(Geom2dGcc::Unqualified(C1),
+          Geom2dGcc::Unqualified(C2),
+          new Geom2d_CartesianPoint(P3),
+          tol,0,0);
+        return solutions(di,ct3,a[1]);
       }
 
       else {
-	// C-C-R
-	Geom2dGcc_Circ2d2TanRad ct3(Geom2dGcc::Unqualified(C1),
-				    Geom2dGcc::Unqualified(C2),
-				    Draw::Atof(a[4]),tol);
-	return solutions(di,ct3,a[1]);
+        // C-C-R
+        Geom2dGcc_Circ2d2TanRad ct3(Geom2dGcc::Unqualified(C1),
+          Geom2dGcc::Unqualified(C2),
+          Draw::Atof(a[4]),tol);
+        return solutions(di,ct3,a[1]);
       }
     }
     else if (ip2) {
       // C-P-..
       if (!C3.IsNull()) {
-	// C-P-C
-	Geom2dGcc_Circ2d3Tan ct3(Geom2dGcc::Unqualified(C1),
-				 Geom2dGcc::Unqualified(C3),
-				 new Geom2d_CartesianPoint(P2),
-				 tol,0,0);
-	return solutions(di,ct3,a[1]);
+        // C-P-C
+        Geom2dGcc_Circ2d3Tan ct3(Geom2dGcc::Unqualified(C1),
+          Geom2dGcc::Unqualified(C3),
+          new Geom2d_CartesianPoint(P2),
+          tol,0,0);
+        return solutions(di,ct3,a[1]);
       }
-      
+
       else if (ip3) {
-	// C-P-P
-	Geom2dGcc_Circ2d3Tan ct3(Geom2dGcc::Unqualified(C1),
-				 new Geom2d_CartesianPoint(P2),
-				 new Geom2d_CartesianPoint(P3),
-				 tol,0);
-	return solutions(di,ct3,a[1]);
+        // C-P-P
+        Geom2dGcc_Circ2d3Tan ct3(Geom2dGcc::Unqualified(C1),
+          new Geom2d_CartesianPoint(P2),
+          new Geom2d_CartesianPoint(P3),
+          tol,0);
+        return solutions(di,ct3,a[1]);
       }
-      
+
       else {
-	// C-P-R
-	Geom2dGcc_Circ2d2TanRad ct3(Geom2dGcc::Unqualified(C1),
-				    new Geom2d_CartesianPoint(P2),
-				    Draw::Atof(a[4]),tol);
-	return solutions(di,ct3,a[1]);
+        // C-P-R
+        Geom2dGcc_Circ2d2TanRad ct3(Geom2dGcc::Unqualified(C1),
+          new Geom2d_CartesianPoint(P2),
+          Draw::Atof(a[4]),tol);
+        return solutions(di,ct3,a[1]);
       }
     }
 
     else {
       // C-R-..
       if (!C3.IsNull()) {
-	// C-R-C
-	Geom2dGcc_Circ2d2TanRad ct3(Geom2dGcc::Unqualified(C1),
-				    Geom2dGcc::Unqualified(C3),
-				    Draw::Atof(a[3]),
-				    tol);
-	return solutions(di,ct3,a[1]);
+        // C-R-C
+        Geom2dGcc_Circ2d2TanRad ct3(Geom2dGcc::Unqualified(C1),
+          Geom2dGcc::Unqualified(C3),
+          Draw::Atof(a[3]),
+          tol);
+        return solutions(di,ct3,a[1]);
       }
-      
+
       else if (ip3) {
-	// C-R-P
-	Geom2dGcc_Circ2d2TanRad ct3(Geom2dGcc::Unqualified(C1),
-				    new Geom2d_CartesianPoint(P3),
-				    Draw::Atof(a[3]),
-				    tol);
-	return solutions(di,ct3,a[1]);
+        // C-R-P
+        Geom2dGcc_Circ2d2TanRad ct3(Geom2dGcc::Unqualified(C1),
+          new Geom2d_CartesianPoint(P3),
+          Draw::Atof(a[3]),
+          tol);
+        return solutions(di,ct3,a[1]);
       }
-      
+
       else {
-	// C-R-R
-	di << "Curve, radius, radius ???"<<"\n";
-	return 1;
+        // C-R-R
+        di << "Curve, radius, radius ???"<<"\n";
+        return 1;
       }
     }
   }
@@ -235,84 +232,84 @@ static Standard_Integer cirtang (Draw_Interpretor& di,Standard_Integer n, const
     if (!C2.IsNull()) {
       // P-C-...
       if (!C3.IsNull()) {
-	// P-C-C
-	Geom2dGcc_Circ2d3Tan ct3(Geom2dGcc::Unqualified(C2),
-				 Geom2dGcc::Unqualified(C3),
-				 new Geom2d_CartesianPoint(P1),
-				 tol,0,0);
-	return solutions(di,ct3,a[1]);
+        // P-C-C
+        Geom2dGcc_Circ2d3Tan ct3(Geom2dGcc::Unqualified(C2),
+          Geom2dGcc::Unqualified(C3),
+          new Geom2d_CartesianPoint(P1),
+          tol,0,0);
+        return solutions(di,ct3,a[1]);
       }
 
       else if (ip3) {
-	// P-C-P
-	Geom2dGcc_Circ2d3Tan ct3(Geom2dGcc::Unqualified(C2),
-				 new Geom2d_CartesianPoint(P1),
-				 new Geom2d_CartesianPoint(P3),
-				 tol,0);
-	return solutions(di,ct3,a[1]);
+        // P-C-P
+        Geom2dGcc_Circ2d3Tan ct3(Geom2dGcc::Unqualified(C2),
+          new Geom2d_CartesianPoint(P1),
+          new Geom2d_CartesianPoint(P3),
+          tol,0);
+        return solutions(di,ct3,a[1]);
       }
 
       else {
-	// P-C-R
-	Geom2dGcc_Circ2d2TanRad ct3(Geom2dGcc::Unqualified(C2),
-				    new Geom2d_CartesianPoint(P1),
-				    Draw::Atof(a[4]),tol);
-	return solutions(di,ct3,a[1]);
+        // P-C-R
+        Geom2dGcc_Circ2d2TanRad ct3(Geom2dGcc::Unqualified(C2),
+          new Geom2d_CartesianPoint(P1),
+          Draw::Atof(a[4]),tol);
+        return solutions(di,ct3,a[1]);
       }
     }
     else if (ip2) {
       // P-P-..
       if (!C3.IsNull()) {
-	// P-P-C
-	Geom2dGcc_Circ2d3Tan ct3(Geom2dGcc::Unqualified(C3),
-				 new Geom2d_CartesianPoint(P1),
-				 new Geom2d_CartesianPoint(P2),
-				 tol,0);
-	return solutions(di,ct3,a[1]);
+        // P-P-C
+        Geom2dGcc_Circ2d3Tan ct3(Geom2dGcc::Unqualified(C3),
+          new Geom2d_CartesianPoint(P1),
+          new Geom2d_CartesianPoint(P2),
+          tol,0);
+        return solutions(di,ct3,a[1]);
       }
-      
+
       else if (ip3) {
-	// P-P-P
-	Geom2dGcc_Circ2d3Tan ct3(new Geom2d_CartesianPoint(P1),
-				 new Geom2d_CartesianPoint(P2),
-				 new Geom2d_CartesianPoint(P3),
-				 tol);
-	return solutions(di,ct3,a[1]);
+        // P-P-P
+        Geom2dGcc_Circ2d3Tan ct3(new Geom2d_CartesianPoint(P1),
+          new Geom2d_CartesianPoint(P2),
+          new Geom2d_CartesianPoint(P3),
+          tol);
+        return solutions(di,ct3,a[1]);
       }
-      
+
       else {
-	// P-P-R
-	Geom2dGcc_Circ2d2TanRad ct3(new Geom2d_CartesianPoint(P1),
-				    new Geom2d_CartesianPoint(P2),
-				    Draw::Atof(a[4]),tol);
-	return solutions(di,ct3,a[1]);
+        // P-P-R
+        Geom2dGcc_Circ2d2TanRad ct3(new Geom2d_CartesianPoint(P1),
+          new Geom2d_CartesianPoint(P2),
+          Draw::Atof(a[4]),tol);
+        return solutions(di,ct3,a[1]);
       }
     }
 
     else {
       // P-R-..
       if (!C3.IsNull()) {
-	// P-R-C
-	Geom2dGcc_Circ2d2TanRad ct3(Geom2dGcc::Unqualified(C3),
-				    new Geom2d_CartesianPoint(P1),
-				    Draw::Atof(a[3]),
-				    tol);
-	return solutions(di,ct3,a[1]);
+        // P-R-C
+        Geom2dGcc_Circ2d2TanRad ct3(Geom2dGcc::Unqualified(C3),
+          new Geom2d_CartesianPoint(P1),
+          Draw::Atof(a[3]),
+          tol);
+        return solutions(di,ct3,a[1]);
       }
-      
+
       else if (ip3) {
-	// P-R-P
-	Geom2dGcc_Circ2d2TanRad ct3(new Geom2d_CartesianPoint(P1),
-				    new Geom2d_CartesianPoint(P3),
-				    Draw::Atof(a[3]),
-				    tol);
-	return solutions(di,ct3,a[1]);
+        // P-R-P
+        Geom2dGcc_Circ2d2TanRad ct3(new Geom2d_CartesianPoint(P1),
+          new Geom2d_CartesianPoint(P3),
+          Draw::Atof(a[3]),
+          tol);
+        return solutions(di,ct3,a[1]);
       }
-      
+
       else {
-	// P-R-R
-	di << "Point, radius, radius ???"<<"\n";
-	return 1;
+        // P-R-R
+        di << "Point, radius, radius ???"<<"\n";
+        return 1;
       }
     }
   }
@@ -322,21 +319,21 @@ static Standard_Integer cirtang (Draw_Interpretor& di,Standard_Integer n, const
     if (!C2.IsNull()) {
       // R-C-...
       if (!C3.IsNull()) {
-	// R-C-C
-	Geom2dGcc_Circ2d2TanRad ct3(Geom2dGcc::Unqualified(C2),
-				    Geom2dGcc::Unqualified(C3),
-				    Draw::Atof(a[2]),
-				    tol);
-	return solutions(di,ct3,a[1]);
+        // R-C-C
+        Geom2dGcc_Circ2d2TanRad ct3(Geom2dGcc::Unqualified(C2),
+          Geom2dGcc::Unqualified(C3),
+          Draw::Atof(a[2]),
+          tol);
+        return solutions(di,ct3,a[1]);
       }
 
       else if (ip3) {
-	// R-C-P
-	Geom2dGcc_Circ2d2TanRad ct3(Geom2dGcc::Unqualified(C2),
-				    new Geom2d_CartesianPoint(P3),
-				    Draw::Atof(a[2]),
-				    tol);
-	return solutions(di,ct3,a[1]);
+        // R-C-P
+        Geom2dGcc_Circ2d2TanRad ct3(Geom2dGcc::Unqualified(C2),
+          new Geom2d_CartesianPoint(P3),
+          Draw::Atof(a[2]),
+          tol);
+        return solutions(di,ct3,a[1]);
       }
 
       else {
@@ -350,19 +347,19 @@ static Standard_Integer cirtang (Draw_Interpretor& di,Standard_Integer n, const
       if (!C3.IsNull()) {
         // R-P-C
         Geom2dGcc_Circ2d2TanRad ct3(Geom2dGcc::Unqualified(C3),
-                  new Geom2d_CartesianPoint(P2),
-                  Draw::Atof(a[2]),
-                  tol);
+          new Geom2d_CartesianPoint(P2),
+          Draw::Atof(a[2]),
+          tol);
         return solutions(di,ct3,a[1]);
       }
-      
+
       else if (ip3) 
       {
         // R-P-P
         Geom2dGcc_Circ2d2TanRad ct3(new Geom2d_CartesianPoint(P2),
-                  new Geom2d_CartesianPoint(P3),
-                  Draw::Atof(a[2]),
-                  tol);
+          new Geom2d_CartesianPoint(P3),
+          Draw::Atof(a[2]),
+          tol);
         return solutions(di,ct3,a[1]);
       }      
       else {
@@ -407,17 +404,17 @@ static Standard_Integer lintang (Draw_Interpretor& di,Standard_Integer n, const
     }
     Standard_Real ang = Draw::Atof(a[4]) * (M_PI / 180.0);
     Geom2dGcc_Lin2dTanObl ct3(Geom2dGcc::Unqualified(C1),
-			      L->Lin2d(),
-			      Precision::Angular(),
-			      (C1->FirstParameter()+C1->LastParameter())/2.,
-			      ang);
+      L->Lin2d(),
+      Precision::Angular(),
+      (C1->FirstParameter()+C1->LastParameter())/2.,
+      ang);
     if (ct3.IsDone()) {
       for (Standard_Integer i = 1 ; i <= ct3.NbSolutions() ; i++) {
-	Handle(Geom2d_Line) LS = new Geom2d_Line(ct3.ThisSolution(i));
-	Sprintf(solname,"%s_%d",a[1],i);
-	char* temp = solname; // pour portage WNT
-	DrawTrSurf::Set(temp,LS);
-	di << solname << " ";
+        Handle(Geom2d_Line) LS = new Geom2d_Line(ct3.ThisSolution(i));
+        Sprintf(solname,"%s_%d",a[1],i);
+        char* temp = solname; // pour portage WNT
+        DrawTrSurf::Set(temp,LS);
+        di << solname << " ";
       }
     }
     else
@@ -425,17 +422,17 @@ static Standard_Integer lintang (Draw_Interpretor& di,Standard_Integer n, const
   }
   else {
     Geom2dGcc_Lin2d2Tan ct3(Geom2dGcc::Unqualified(C1),
-			    Geom2dGcc::Unqualified(C2),
-			    Precision::Angular(),
-			    (C1->FirstParameter()+C1->LastParameter())/2.,
-			    (C2->FirstParameter()+C2->LastParameter())/2.);
+      Geom2dGcc::Unqualified(C2),
+      Precision::Angular(),
+      (C1->FirstParameter()+C1->LastParameter())/2.,
+      (C2->FirstParameter()+C2->LastParameter())/2.);
     if (ct3.IsDone()) {
       for (Standard_Integer i = 1 ; i <= ct3.NbSolutions() ; i++) {
-	Handle(Geom2d_Line) LS = new Geom2d_Line(ct3.ThisSolution(i));
-	Sprintf(solname,"%s_%d",a[1],i);
-	char* temp = solname; // pour portage WNT
-	DrawTrSurf::Set(temp,LS);
-	di << solname << " ";
+        Handle(Geom2d_Line) LS = new Geom2d_Line(ct3.ThisSolution(i));
+        Sprintf(solname,"%s_%d",a[1],i);
+        char* temp = solname; // pour portage WNT
+        DrawTrSurf::Set(temp,LS);
+        di << solname << " ";
       }
     }
     else
@@ -465,7 +462,7 @@ static Standard_Integer interpol (Draw_Interpretor& di,Standard_Integer n, const
     gp_Pnt P;
     gp_Pnt2d P2d;
     Standard_Boolean newcurve;
-    
+
     if (dout.Is3D(id)) {
       Handle(Draw_Marker3D) mark;
       Handle(TColgp_HArray1OfPnt) Points = new TColgp_HArray1OfPnt(1, 1);
@@ -478,50 +475,50 @@ static Standard_Integer interpol (Draw_Interpretor& di,Standard_Integer n, const
       dout.Flush();
       Handle(Geom_BSplineCurve) C;
       i = 1;
-      
+
       while (b != 3) {
-	dout.Select(id,XX,YY,b, Standard_False);
-	P.SetCoord((Standard_Real)XX/zoom,(Standard_Real)YY/zoom, 0.0);
-	ThePoints->SetValue(i+1, P);
-	newcurve = Standard_False;
-	if (!(ThePoints->Value(i)).IsEqual(ThePoints->Value(i+1), 1.e-06)) {
-	  if (b == 1) { 
-	    i++;
-	    mark = new Draw_Marker3D(ThePoints->Value(i), Draw_X, Draw_vert);
-	    dout << mark;
-	    dout.Flush();
-	    Points = 
-	      new TColgp_HArray1OfPnt(ThePoints->Lower(),ThePoints->Upper());
-	    Points->ChangeArray1() = ThePoints->Array1();
-	    newcurve = Standard_True;
-	  }
-	  GeomAPI_Interpolate anInterpolator(ThePoints,
-					     Standard_False,
-					     1.0e-5);
-	  anInterpolator.Perform() ;
-	  if (anInterpolator.IsDone()) {
-	    C = anInterpolator.Curve() ;
-	    Handle(DrawTrSurf_BSplineCurve) 
-	      DC = new DrawTrSurf_BSplineCurve(C);
-	    DC->ClearPoles();
-	    DC->ClearKnots();
-	    Draw::Set(a[1], DC);
-	    dout.RepaintView(id);
-	  }
-	  if (newcurve) {
-	    ThePoints = new TColgp_HArray1OfPnt(1, i+1);
-	    for (j = 1; j <= i; j++) ThePoints->SetValue(j, Points->Value(j));
-	  }
-	}
+        dout.Select(id,XX,YY,b, Standard_False);
+        P.SetCoord((Standard_Real)XX/zoom,(Standard_Real)YY/zoom, 0.0);
+        ThePoints->SetValue(i+1, P);
+        newcurve = Standard_False;
+        if (!(ThePoints->Value(i)).IsEqual(ThePoints->Value(i+1), 1.e-06)) {
+          if (b == 1) { 
+            i++;
+            mark = new Draw_Marker3D(ThePoints->Value(i), Draw_X, Draw_vert);
+            dout << mark;
+            dout.Flush();
+            Points = 
+              new TColgp_HArray1OfPnt(ThePoints->Lower(),ThePoints->Upper());
+            Points->ChangeArray1() = ThePoints->Array1();
+            newcurve = Standard_True;
+          }
+          GeomAPI_Interpolate anInterpolator(ThePoints,
+            Standard_False,
+            1.0e-5);
+          anInterpolator.Perform() ;
+          if (anInterpolator.IsDone()) {
+            C = anInterpolator.Curve() ;
+            Handle(DrawTrSurf_BSplineCurve) 
+              DC = new DrawTrSurf_BSplineCurve(C);
+            DC->ClearPoles();
+            DC->ClearKnots();
+            Draw::Set(a[1], DC);
+            dout.RepaintView(id);
+          }
+          if (newcurve) {
+            ThePoints = new TColgp_HArray1OfPnt(1, i+1);
+            for (j = 1; j <= i; j++) ThePoints->SetValue(j, Points->Value(j));
+          }
+        }
       }
       GeomAPI_Interpolate anInterpolator(ThePoints,
-					     Standard_False,
-					     1.0e-5);
+        Standard_False,
+        1.0e-5);
       anInterpolator.Perform() ;
       if (anInterpolator.IsDone()) {
-	C = anInterpolator.Curve() ;
-	DrawTrSurf::Set(a[1], C);
-	dout.RepaintView(id);
+        C = anInterpolator.Curve() ;
+        DrawTrSurf::Set(a[1], C);
+        dout.RepaintView(id);
       }      
     }
     else {
@@ -536,53 +533,53 @@ static Standard_Integer interpol (Draw_Interpretor& di,Standard_Integer n, const
       dout.Flush();
       Handle(Geom2d_BSplineCurve) C;
       i = 1;
-      
+
       while (b != 3) {
-	dout.Select(id,XX,YY,b, Standard_False);
-	P2d.SetCoord((Standard_Real)XX/zoom,(Standard_Real)YY/zoom);
-	ThePoints->SetValue(i+1, P2d);
-	newcurve = Standard_False;
-	if (!(ThePoints->Value(i)).IsEqual(ThePoints->Value(i+1), 1.e-06)) {
-	  if (b == 1) { 
-	    i++;
-	    mark = new Draw_Marker2D(P2d, Draw_X, Draw_vert);
-	    dout << mark;
-	    dout.Flush();
-	    Points = 
-	      new TColgp_HArray1OfPnt2d(ThePoints->Lower(),ThePoints->Upper());
-	    Points->ChangeArray1() = ThePoints->Array1();
-	    newcurve = Standard_True;
-	  }
+        dout.Select(id,XX,YY,b, Standard_False);
+        P2d.SetCoord((Standard_Real)XX/zoom,(Standard_Real)YY/zoom);
+        ThePoints->SetValue(i+1, P2d);
+        newcurve = Standard_False;
+        if (!(ThePoints->Value(i)).IsEqual(ThePoints->Value(i+1), 1.e-06)) {
+          if (b == 1) { 
+            i++;
+            mark = new Draw_Marker2D(P2d, Draw_X, Draw_vert);
+            dout << mark;
+            dout.Flush();
+            Points = 
+              new TColgp_HArray1OfPnt2d(ThePoints->Lower(),ThePoints->Upper());
+            Points->ChangeArray1() = ThePoints->Array1();
+            newcurve = Standard_True;
+          }
           Geom2dAPI_Interpolate    a2dInterpolator(ThePoints,
-						    Standard_False,
-						    1.0e-5) ;
+            Standard_False,
+            1.0e-5) ;
           a2dInterpolator.Perform() ;
           if (a2dInterpolator.IsDone()) { 
-	    C = a2dInterpolator.Curve() ;
-          
-	    Handle(DrawTrSurf_BSplineCurve2d) 
-	      DC = new DrawTrSurf_BSplineCurve2d(C);
-	    DC->ClearPoles();
-	    DC->ClearKnots();
-	    Draw::Set(a[1], DC);
-	    dout.RepaintView(id);
-	  }
+            C = a2dInterpolator.Curve() ;
 
-	  if (newcurve) {
-	    ThePoints = new TColgp_HArray1OfPnt2d(1, i+1);
-	    for (j = 1; j <= i; j++) ThePoints->SetValue(j, Points->Value(j));
-	  }
-	}
+            Handle(DrawTrSurf_BSplineCurve2d) 
+              DC = new DrawTrSurf_BSplineCurve2d(C);
+            DC->ClearPoles();
+            DC->ClearKnots();
+            Draw::Set(a[1], DC);
+            dout.RepaintView(id);
+          }
+
+          if (newcurve) {
+            ThePoints = new TColgp_HArray1OfPnt2d(1, i+1);
+            for (j = 1; j <= i; j++) ThePoints->SetValue(j, Points->Value(j));
+          }
+        }
       }
       Geom2dAPI_Interpolate    a2dInterpolator(Points,
-					       Standard_False,
-					       1.0e-5) ;
+        Standard_False,
+        1.0e-5) ;
       a2dInterpolator.Perform() ;
       if (a2dInterpolator.IsDone()) { 
-	C = a2dInterpolator.Curve() ;
-	
-	DrawTrSurf::Set(a[1], C);
-	dout.RepaintView(id); 
+        C = a2dInterpolator.Curve() ;
+
+        DrawTrSurf::Set(a[1], C);
+        dout.RepaintView(id); 
       }
 
     }
@@ -599,36 +596,36 @@ static Standard_Integer interpol (Draw_Interpretor& di,Standard_Integer n, const
     char dimen[3];
     iFile >> dimen;
     if (!strcmp(dimen,"3d")) {
-      Handle_TColgp_HArray1OfPnt Point =
-      new TColgp_HArray1OfPnt(1, nbp);
+      Handle(TColgp_HArray1OfPnt) Point =
+        new TColgp_HArray1OfPnt(1, nbp);
       for (i = 1; i <= nbp; i++) {
-	iFile >> x >> y >> z;
-	Point->SetValue(i, gp_Pnt(x, y, z));
+        iFile >> x >> y >> z;
+        Point->SetValue(i, gp_Pnt(x, y, z));
       }
       GeomAPI_Interpolate  anInterpolator(Point,
-					  Standard_False,
-					  1.0e-5) ;
+        Standard_False,
+        1.0e-5) ;
       anInterpolator.Perform() ;
       if (anInterpolator.IsDone()) { 
-	Handle(Geom_BSplineCurve) C = 
-	  anInterpolator.Curve();
-	DrawTrSurf::Set(a[1], C);
+        Handle(Geom_BSplineCurve) C = 
+          anInterpolator.Curve();
+        DrawTrSurf::Set(a[1], C);
       }
     }
     else if (!strcmp(dimen,"2d")) {
       Handle(TColgp_HArray1OfPnt2d)  PointPtr = 
-	new TColgp_HArray1OfPnt2d(1, nbp);
+        new TColgp_HArray1OfPnt2d(1, nbp);
       for (i = 1; i <= nbp; i++) {
-	iFile >> x >> y;
-	PointPtr->SetValue(i, gp_Pnt2d(x, y));
+        iFile >> x >> y;
+        PointPtr->SetValue(i, gp_Pnt2d(x, y));
       }
       Geom2dAPI_Interpolate   a2dInterpolator(PointPtr,
-					       Standard_False,
-					       1.0e-5);
+        Standard_False,
+        1.0e-5);
       a2dInterpolator.Perform() ;
       if (a2dInterpolator.IsDone()) {
-	Handle(Geom2d_BSplineCurve) C = a2dInterpolator.Curve() ;
-	DrawTrSurf::Set(a[1], C);
+        Handle(Geom2d_BSplineCurve) C = a2dInterpolator.Curve() ;
+        DrawTrSurf::Set(a[1], C);
       }
     }
   }
@@ -636,8 +633,8 @@ static Standard_Integer interpol (Draw_Interpretor& di,Standard_Integer n, const
 }
 
 static Standard_Integer tanginterpol (Draw_Interpretor& di,
-				  Standard_Integer n, 
-				  const char** a)
+                                      Standard_Integer n, 
+                                      const char** a)
 {
 
 
@@ -647,23 +644,23 @@ static Standard_Integer tanginterpol (Draw_Interpretor& di,
   Standard_Integer 
     ii,
     jj,
-//    num_knots,
-//    degree,
+    //    num_knots,
+    //    degree,
     num_tangents,
     num_read,
     num_start,
     num_parameters ;
 
-  
-  Standard_Real 
-//    delta,
-    tolerance;
-//    parameter ;
 
- Standard_Boolean periodic_flag = Standard_False ;
- gp_Pnt a_point ;
- gp_Vec a_vector ;
- tolerance = 1.0e-5 ;
+  Standard_Real 
+    //    delta,
+    tolerance;
+  //    parameter ;
+
+  Standard_Boolean periodic_flag = Standard_False ;
+  gp_Pnt a_point ;
+  gp_Vec a_vector ;
+  tolerance = 1.0e-5 ;
 
 
 
@@ -686,9 +683,9 @@ static Standard_Integer tanginterpol (Draw_Interpretor& di,
   if ( n <  num_parameters * 3 + num_read) {
     return 1 ;
   }
-  Handle_TColgp_HArray1OfPnt   PointsArrayPtr=
+  Handle(TColgp_HArray1OfPnt)   PointsArrayPtr=
     new TColgp_HArray1OfPnt(1,num_parameters) ;
-  
+
   num_tangents = ((n - num_read) / 3)  - num_parameters ;
   num_tangents = Max (0,num_tangents) ; 
   num_tangents = Min (num_parameters, num_tangents) ;
@@ -704,15 +701,15 @@ static Standard_Integer tanginterpol (Draw_Interpretor& di,
     ii += 1 ;
   }
   GeomAPI_Interpolate anInterpolator(PointsArrayPtr,
-				     periodic_flag,
-				     tolerance) ; 
+    periodic_flag,
+    tolerance) ; 
 
   if (num_tangents > 0) {
     TColgp_Array1OfVec TangentsArray(1,num_parameters) ;
-    Handle_TColStd_HArray1OfBoolean 
+    Handle(TColStd_HArray1OfBoolean) 
       TangentFlagsPtr =
-	new TColStd_HArray1OfBoolean(1,num_parameters) ;
-  
+      new TColStd_HArray1OfBoolean(1,num_parameters) ;
+
     for (ii = 1 ; ii <= num_tangents ; ii++) {
       TangentFlagsPtr->SetValue(ii,Standard_True) ;
     }
@@ -722,16 +719,16 @@ static Standard_Integer tanginterpol (Draw_Interpretor& di,
     ii = 1 ;
     while (ii <= num_tangents) {
       for (jj = 1 ; jj <= 3 ; jj++) {
-	a_vector.SetCoord(jj,Draw::Atof(a[num_read])) ;
-	num_read += 1 ;
+        a_vector.SetCoord(jj,Draw::Atof(a[num_read])) ;
+        num_read += 1 ;
       }
       TangentsArray.SetValue(ii,a_vector) ;
       ii += 1 ;
     }
-    
-    
+
+
     anInterpolator.Load(TangentsArray,
-			TangentFlagsPtr) ;
+      TangentFlagsPtr) ;
   }
   anInterpolator.Perform() ;
   if (anInterpolator.IsDone()) {
@@ -739,7 +736,7 @@ static Standard_Integer tanginterpol (Draw_Interpretor& di,
       anInterpolator.Curve() ;
 
     DrawTrSurf::Set(a[1],
-		  NewCurvePtr) ;
+      NewCurvePtr) ;
     di << a[2] << " " ;
 
   }
@@ -754,32 +751,32 @@ static Standard_Integer gcarc (Draw_Interpretor& di,Standard_Integer n, const ch
     gp_Pnt P1,P2,P3,P4;
     if (!strcmp(a[2], "seg")) {
       if (DrawTrSurf::GetPoint(a[3], P1)) {
-	if (DrawTrSurf::GetPoint(a[4], P2)) {
-	  Handle(Geom_Curve) theline = GC_MakeSegment(P1,P2).Value();
-	  DrawTrSurf::Set(a[1], theline);
-	  return 1;
-	}
+        if (DrawTrSurf::GetPoint(a[4], P2)) {
+          Handle(Geom_Curve) theline = GC_MakeSegment(P1,P2).Value();
+          DrawTrSurf::Set(a[1], theline);
+          return 1;
+        }
       }
     }
     else if (!strcmp(a[2], "cir")) {
       if (DrawTrSurf::GetPoint(a[3], P1)) {
-	if (DrawTrSurf::GetPoint(a[4], P2)) {
-	  if (DrawTrSurf::GetPoint(a[5], P3)) {
-//	    if (DrawTrSurf::GetPoint(a[6], P4)) {
-	    if (n>6) {
-        DrawTrSurf::GetPoint(a[6], P4);
-	      gp_Vec V1 = gp_Vec(P2,P3);                                                    
-	      Handle(Geom_Curve)thearc = GC_MakeArcOfCircle(P1,V1,P4).Value();
-	      DrawTrSurf::Set(a[1], thearc);
-	      return 1;
-	    }
-	    else {
-	      Handle(Geom_Curve)thearc = GC_MakeArcOfCircle(P1,P2,P3).Value();
-	      DrawTrSurf::Set(a[1], thearc);
-	      return 1;
-	    }
-	  }
-	}
+        if (DrawTrSurf::GetPoint(a[4], P2)) {
+          if (DrawTrSurf::GetPoint(a[5], P3)) {
+            //	    if (DrawTrSurf::GetPoint(a[6], P4)) {
+            if (n>6) {
+              DrawTrSurf::GetPoint(a[6], P4);
+              gp_Vec V1 = gp_Vec(P2,P3);                                                    
+              Handle(Geom_Curve)thearc = GC_MakeArcOfCircle(P1,V1,P4).Value();
+              DrawTrSurf::Set(a[1], thearc);
+              return 1;
+            }
+            else {
+              Handle(Geom_Curve)thearc = GC_MakeArcOfCircle(P1,P2,P3).Value();
+              DrawTrSurf::Set(a[1], thearc);
+              return 1;
+            }
+          }
+        }
       }
     }
   }
@@ -807,28 +804,28 @@ void  GeometryTest::ConstraintCommands(Draw_Interpretor& theCommands)
   // constrained constructs
   g = "GEOMETRY Constraints";
 
-    theCommands.Add("cirtang",
-		    "cirtang cname curve/point/radius curve/point/radius curve/point/radius",
-		    __FILE__,
-		    cirtang,g);
+  theCommands.Add("cirtang",
+    "cirtang cname curve/point/radius curve/point/radius curve/point/radius",
+    __FILE__,
+    cirtang,g);
 
-    theCommands.Add("lintan",
-		    "lintan lname curve1 curve2 [angle]",
-		    __FILE__,
-		    lintang,g);
+  theCommands.Add("lintan",
+    "lintan lname curve1 curve2 [angle]",
+    __FILE__,
+    lintang,g);
 
 
-    theCommands.Add("interpol",
-		    "interpol cname [fic]", 
-		    __FILE__,
-		    interpol, g);
-     theCommands.Add("tanginterpol",
-		     "tanginterpol curve [p] num_points points [tangents] modifier  p = periodic",
-		     __FILE__,
-		     tanginterpol,g);
+  theCommands.Add("interpol",
+    "interpol cname [fic]", 
+    __FILE__,
+    interpol, g);
+  theCommands.Add("tanginterpol",
+    "tanginterpol curve [p] num_points points [tangents] modifier  p = periodic",
+    __FILE__,
+    tanginterpol,g);
 
-     theCommands.Add("gcarc",
-		     "gcarc name seg/cir p1 p2 p3 p4",
-		     __FILE__,
-		     gcarc,g);
+  theCommands.Add("gcarc",
+    "gcarc name seg/cir p1 p2 p3 p4",
+    __FILE__,
+    gcarc,g);
 }
