@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -14,9 +14,6 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-#ifdef HAVE_CONFIG_H
-# include <oce-config.h>
-#endif
 #include <GeomliteTest.hxx>
 #include <DrawTrSurf.hxx>
 #include <Draw.hxx>
@@ -86,13 +83,10 @@
 
 //#ifdef WNT
 #include <stdio.h>
-#ifdef WNT
+#ifdef _WIN32
 //#define strcasecmp strcmp Already defined
 Standard_IMPORT Draw_Viewer dout;
 #endif
-#ifdef HAVE_STRINGS_H
-# include <strings.h>
-#endif
 
 
 
