@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -83,7 +83,7 @@
 #define MinSeg      ((Standard_Integer*)Indices)[7]
 #define MaxSeg      ((Standard_Integer*)Indices)[8]
 #define SegFlags    ((Standard_Integer*)Indices)[9]
-#ifdef DEB
+#ifdef OCCT_DEBUG
 static Standard_Integer ERROR = Standard_False;
 #endif
 //=======================================================================
@@ -461,7 +461,7 @@ HideByOneTriangle (const Standard_Address Coordinates,
 	o[npi] = n1 == -1;
 	m[npi] = Multiple;
       }
-#ifdef DEB
+#ifdef OCCT_DEBUG
       else if (ERROR) {
 	cout << " error : HLRAlgo_PolyData::HideByOneTriangle " << endl;
 	cout << " ( more than 2 points )." << endl;
@@ -606,7 +606,7 @@ HideByOneTriangle (const Standard_Address Coordinates,
 	o[npi] = n1 == -1;
 	m[npi] = Multiple;
       }
-#ifdef DEB
+#ifdef OCCT_DEBUG
       else if (ERROR) {
 	cout << " error : HLRAlgo_PolyData::HideByOneTriangle " << endl;
 	cout << " ( more than 2 points )." << endl;
@@ -751,7 +751,7 @@ HideByOneTriangle (const Standard_Address Coordinates,
 	o[npi] = n1 == -1;
 	m[npi] = Multiple;
       }
-#ifdef DEB
+#ifdef OCCT_DEBUG
       else if (ERROR) {
 	cout << " error : HLRAlgo_PolyData::HideByOneTriangle " << endl;
 	cout << " ( more than 2 points )." << endl;
