@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -48,7 +48,7 @@ AddInterference(HLRAlgo_InterferenceList& IL,
 //function : ProcessComplex
 //purpose  : 
 //=======================================================================
-#ifdef DEB_SI
+#ifdef OCCT_DEBUG_SI
 static Standard_Boolean SimilarInterference(const HLRAlgo_Interference& I1,
 					    const HLRAlgo_Interference& I2)
 {
@@ -85,7 +85,7 @@ ProcessComplex(HLRAlgo_InterferenceList& IL,
     It2.Next();
     if (It2.More()) {
       if (T.SameInterferences(It1.Value(),It2.Value())
-#ifdef DEB_SI
+#ifdef OCCT_DEBUG_SI
           || SimilarInterference(It1.Value(),It2.Value())
 #endif
           )
@@ -102,7 +102,7 @@ ProcessComplex(HLRAlgo_InterferenceList& IL,
 
 	while (It2.More()) {
 	  if (!(T.SameInterferences(It1.Value(),It2.Value())
-#ifdef DEB_SI
+#ifdef OCCT_DEBUG_SI
           || SimilarInterference(It1.Value(),It2.Value())
 #endif
      )) break;
