@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -137,10 +137,13 @@ void HLRBRep_InternalAlgo::Update ()
 	df = DS[i-1]->NbFaces   ();
       }
       catch(Standard_Failure) {
-	cout << "An exception was catched when preparing the Shape " << i;
-	cout << " and computing its OutLines " << endl;
-	Handle(Standard_Failure) fail = Standard_Failure::Caught();
-	cout << fail << endl;
+        if (myDebug)
+        {
+          cout << "An exception was catched when preparing the Shape " << i;
+          cout << " and computing its OutLines " << endl;
+          Handle(Standard_Failure) fail = Standard_Failure::Caught();
+          cout << fail << endl;
+        }
 	DS[i-1] = new HLRBRep_Data(0,0,0);
 	dv = 0;
 	de = 0;
@@ -710,7 +713,7 @@ void HLRBRep_InternalAlgo::HideSelected (const Standard_Integer I,
   Standard_Integer e,f,j,nbVisEdges,nbSelEdges,nbSelFaces,nbCache;
   Standard_Integer nbFSide,nbFSimp;
 
-#ifdef DEB
+#ifdef OCCT_DEBUG
   if (myDebug) {
     nbPtIntersection = 0;
     nbSegIntersection = 0;
@@ -760,17 +763,20 @@ void HLRBRep_InternalAlgo::HideSelected (const Standard_Integer I,
 	fd++;
       }
       
-      cout << endl;
-      cout << "Vertices  : " << setw(5) << myDS->NbVertices() << endl;
-      cout << "Edges     : " << setw(5) << myDS->NbEdges()    << " , ";
-      cout << "Selected  : " << setw(5) << nbSelEdges         << " , ";
-      cout << "Visibles  : " << setw(5) << nbVisEdges         << endl;
-      cout << "Faces     : " << setw(5) << myDS->NbFaces()    << " , ";
-      cout << "Selected  : " << setw(5) << nbSelFaces         << " , ";
-      cout << "Simple    : " << setw(5) << nbFSimp            << endl;
-      if (SideFace)
-	cout << "Side      : " << setw(5) << nbFSide            << " , ";
-      cout << "Cachantes : " << setw(5) << nbCache            << endl << endl;
+      if (myDebug)
+      {
+        cout << endl;
+        cout << "Vertices  : " << setw(5) << myDS->NbVertices() << endl;
+        cout << "Edges     : " << setw(5) << myDS->NbEdges()    << " , ";
+        cout << "Selected  : " << setw(5) << nbSelEdges         << " , ";
+        cout << "Visibles  : " << setw(5) << nbVisEdges         << endl;
+        cout << "Faces     : " << setw(5) << myDS->NbFaces()    << " , ";
+        cout << "Selected  : " << setw(5) << nbSelFaces         << " , ";
+        cout << "Simple    : " << setw(5) << nbFSimp            << endl;
+        if (SideFace)
+          cout << "Side      : " << setw(5) << nbFSide            << " , ";
+        cout << "Cachantes : " << setw(5) << nbCache            << endl << endl;
+      }
     }
 
     Standard_Integer QWE=0,QWEQWE;
@@ -786,7 +792,8 @@ void HLRBRep_InternalAlgo::HideSelected (const Standard_Integer I,
 	    if(TRACE10) { 
 	      if(++QWE>QWEQWE) { 
 		QWE=0; 
-		cout<<"*";
+                if (myDebug)
+                  cout<<"*";
 	      } 
 	    }
 	    else {  
@@ -907,7 +914,8 @@ void HLRBRep_InternalAlgo::HideSelected (const Standard_Integer I,
 	if (fd->Hiding()) {
 	  if(TRACE10 && TRACE==Standard_False) { 
 	    if(++QWE>QWEQWE) { 
-	      cout<<".";
+	      if (myDebug)
+                cout<<".";
 	      QWE=0;
 	    }
 	  }
@@ -922,7 +930,7 @@ void HLRBRep_InternalAlgo::HideSelected (const Standard_Integer I,
       }
     }
     
-#ifdef DEB
+#ifdef OCCT_DEBUG
     if (myDebug) {
       fd = &(myDS->FDataArray().ChangeValue(1));
       nbFSimp = 0;
