@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -188,7 +188,7 @@ HLRTest_DrawableEdgeTool::DrawEdge (Draw_Display& D,
 	   It.NextVisible()) {
 	It.Visible(sta,tolsta,end,tolend);
 	D.MoveTo(ec.Value3D(sta));
-	if (!ec.GetType() == GeomAbs_Line) {
+	if (ec.GetType() != GeomAbs_Line) {
 	  Standard_Integer nbPnt = 100;
 	  Standard_Real step = (end-sta)/(nbPnt+1);
 	  
@@ -221,7 +221,7 @@ HLRTest_DrawableEdgeTool::DrawEdge (Draw_Display& D,
 	   It.NextHidden()) {
 	It.Hidden(sta,tolsta,end,tolend);
 	D.MoveTo(ec.Value3D(sta));
-	if (!ec.GetType() == GeomAbs_Line) {
+	if (ec.GetType() != GeomAbs_Line) {
 	  Standard_Integer nbPnt = 100;
 	  Standard_Real step = (end-sta)/(nbPnt+1);
 	  
