@@ -2,8 +2,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -42,7 +42,7 @@ static Handle(IFSelect_Profile) thealiases;
   if (thedico.IsNull()) thedico = new Dico_DictionaryOfInteger;
   Standard_Integer& num = thedico->NewItem(command,deja,Standard_True);
   if (deja) {
-#ifdef DEB
+#ifdef OCCT_DEBUG
     cout<<"****  XSTEP commands, name conflict on "<<command<<" first defined remains  ****"<<endl;
 //    Standard_DomainError::Raise("IFSelect_Activator : Add");
 #endif
