@@ -2,8 +2,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -23,6 +23,7 @@
 #include <Interface_Macros.hxx>
 #include <Message_Messenger.hxx>
 #include <Message.hxx>
+#include <OSD_OpenFile.hxx>
 
 #include <stdio.h>
 
@@ -225,7 +226,7 @@ static TCollection_AsciiString nulword;
 {
   FILE* fic; int lefic = 0;
   if (file != NULL && file[0] != '\0') {
-    fic = fopen (file,"r");
+    fic = OSD_OpenFile (file,"r");
     if (fic) lefic = 1;
     else { cout<<" ...   Script File "<<file<<" not found"<<endl; return IFSelect_RetFail; }
     cout << " ...   Reading Script File " << file << endl;
