@@ -4,8 +4,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -183,7 +183,7 @@ IGESData_DirChecker  IGESSolid_ToolManifoldSolid::DirChecker
   DC.Structure  (IGESData_DefVoid);
   DC.LineFont   (IGESData_DefVoid);
   DC.LineWeight (IGESData_DefVoid);
-  DC.Color      (IGESData_DefVoid);
+  DC.Color      (IGESData_DefAny);
 
   return DC;
 }
