@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -47,8 +47,8 @@ static
 		  const Standard_Real AngDef);
 
 static 
-  Standard_Boolean SameCurve(const Handle_Adaptor2d_HCurve2d& C1,
-			     const Handle_Adaptor2d_HCurve2d& C2);
+  Standard_Boolean SameCurve(const Handle(Adaptor2d_HCurve2d)& C1,
+			     const Handle(Adaptor2d_HCurve2d)& C2);
 
 static 
   void RecadreMemePeriode(Standard_Real& u1,
@@ -851,6 +851,9 @@ static
   case GeomAbs_Sphere:
     pu1=M_PI+M_PI;
     break;
+  case GeomAbs_Torus:
+    pu1=pv1=M_PI+M_PI;
+    break;
   default:
     break;
   }
@@ -860,6 +863,9 @@ static
   case GeomAbs_Sphere:
     pu2=M_PI+M_PI;
     break;
+  case GeomAbs_Torus:
+    pu2=pv2=M_PI+M_PI;
+    break;
   default:
     break;
   }
@@ -898,7 +904,7 @@ gp_Pnt DefineDU(const Handle(IntPatch_ALine)& aline,
 //function : SameCurve
 //purpose  : 
 //=======================================================================
-Standard_Boolean SameCurve(const Handle_Adaptor2d_HCurve2d& C1,const Handle_Adaptor2d_HCurve2d& C2) 
+Standard_Boolean SameCurve(const Handle(Adaptor2d_HCurve2d)& C1,const Handle(Adaptor2d_HCurve2d)& C2) 
 { 
   Standard_Real C1f = C1->FirstParameter();
   Standard_Real C2f = C2->FirstParameter();
