@@ -2,8 +2,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -301,7 +301,7 @@ Standard_CString  Interface_Static::CVal  (const Standard_CString name)
 {
   Handle(Interface_Static) item = Interface_Static::Static(name);
   if (item.IsNull()) {
-#ifdef DEB
+#ifdef OCCT_DEBUG
     cout << "Warning: Interface_Static::CVal: incorrect parameter " << name << endl;
 #endif
     return "";
@@ -314,7 +314,7 @@ Standard_Integer  Interface_Static::IVal  (const Standard_CString name)
 {
   Handle(Interface_Static) item = Interface_Static::Static(name);
   if (item.IsNull()) {
-#ifdef DEB
+#ifdef OCCT_DEBUG
     cout << "Warning: Interface_Static::IVal: incorrect parameter " << name << endl;
 #endif
     return 0;
@@ -327,7 +327,7 @@ Standard_Real Interface_Static::RVal (const Standard_CString name)
 {
   Handle(Interface_Static) item = Interface_Static::Static(name);
   if (item.IsNull()) {
-#ifdef DEB
+#ifdef OCCT_DEBUG
     cout << "Warning: Interface_Static::RVal: incorrect parameter " << name << endl;
 #endif
     return 0.0;
