@@ -4,8 +4,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -137,8 +137,10 @@ LDOMBasicString& LDOMBasicString::operator = (const LDOM_NullPtr *)
 
 LDOMBasicString& LDOMBasicString::operator = (const LDOMBasicString& anOther)
 {
-  if (myType == LDOM_AsciiFree && myVal.ptr)
+  if (myType == LDOM_AsciiFree && myVal.ptr) {
+    if (myVal.ptr == anOther.myVal.ptr && myType == anOther.Type()) return * this;
     delete [] (char *) myVal.ptr;
+  }
   myType    = anOther.Type();
   switch (myType) {
   case LDOM_AsciiFree:
@@ -316,7 +318,7 @@ Standard_Boolean LDOMBasicString::GetInteger (Standard_Integer& aResult) const
   return Standard_True;
 }
 
-#ifdef DEB
+#ifdef OCCT_DEBUG
 #ifndef WNT
 //=======================================================================
 // Debug Function for DBX: use "print -p <Variable> or pp <Variable>"
