@@ -3,8 +3,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -21,7 +21,7 @@
 #include <gp_Vec2d.hxx>
 #include <Law_Interpolate.hxx>
 
-#ifdef DEB
+#ifdef OCCT_DEBUG
 #ifdef DRAW
 
 // Pour le dessin.
@@ -121,7 +121,7 @@ void Law_Interpol::Set(const TColgp_Array1OfPnt2d& ParAndRad,
   Law_Interpolate inter(rad,par,Periodic,Precision::Confusion());
   inter.Perform();
   SetCurve(inter.Curve()); 
-#ifdef DEB
+#ifdef OCCT_DEBUG
 #ifdef DRAW
   if (Affich) {
     gp_Vec2d veve(0.,0.);
@@ -158,7 +158,7 @@ void Law_Interpol::SetInRelative(const TColgp_Array1OfPnt2d& ParAndRad,
   Law_Interpolate inter(rad,par,Periodic,Precision::Confusion());
   inter.Perform();
   SetCurve(inter.Curve()); 
-#ifdef DEB
+#ifdef OCCT_DEBUG
 #ifdef DRAW
   if (Affich) {
     gp_Vec2d veve(0.,0.);
