@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -70,7 +70,7 @@ Standard_Integer  MAT_BasicElt::GeomIndex() const
 // function: SetStartArc
 // purpose :
 //========================================================================
-void  MAT_BasicElt::SetStartArc(const Handle_MAT_Arc& anArc)
+void  MAT_BasicElt::SetStartArc(const Handle(MAT_Arc)& anArc)
 {
   startLeftArc = anArc.operator->();
 }
@@ -80,7 +80,7 @@ void  MAT_BasicElt::SetStartArc(const Handle_MAT_Arc& anArc)
 // function: SetEndArc
 // purpose :
 //========================================================================
-void  MAT_BasicElt::SetEndArc(const Handle_MAT_Arc& anArc)
+void  MAT_BasicElt::SetEndArc(const Handle(MAT_Arc)& anArc)
 {
   endLeftArc = anArc.operator->();
 }
