@@ -4,8 +4,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -132,39 +132,82 @@ void Message_Algorithm::SetStatus (const Message_Status& theStat,
   aReportSeq->Append ( theStr );
 }
 
+//=======================================================================
+//function : SetStatus
+//purpose  :
+//=======================================================================
+
+void Message_Algorithm::SetStatus (const Message_Status& theStat,
+                                   const Message_Msg&    theMsg)
+{
+  // Set status flag
+  SetStatus (theStat);
+
+  // Find index of bit corresponding to that flag
+  Standard_Integer aFlagIndex = Message_ExecStatus::StatusIndex (theStat);
+  if (aFlagIndex == 0)
+  {
+    return;
+  }
+
+  // Create sequence of messages for a given flag, if not yet done
+  if (myReportMessages.IsNull())
+  {
+    myReportMessages = new Message_ArrayOfMsg (Message_ExecStatus::FirstStatus, Message_ExecStatus::LastStatus);
+  }
+
+  myReportMessages->ChangeValue (aFlagIndex) = new Message_Msg (theMsg);
+}
+
 //=======================================================================
 //function : ClearStatus
 //purpose  :
 //=======================================================================
 
-void Message_Algorithm::ClearStatus() 
-{ 
+void Message_Algorithm::ClearStatus()
+{
   myStatus.Clear(); 
   myReportIntegers.Nullify();
   myReportStrings.Nullify();
+  myReportMessages.Nullify();
 }
 
 //=======================================================================
 //function : SendStatusMessages
-//purpose  : 
+//purpose  :
 //=======================================================================
 
 void Message_Algorithm::SendStatusMessages (const Message_ExecStatus& theStatus,
-					    const Message_Gravity theTraceLevel,
-					    const Standard_Integer theMaxCount) const
+                                            const Message_Gravity     theTraceLevel,
+                                            const Standard_Integer    theMaxCount) const
 {
   Handle(Message_Messenger) aMsgr = GetMessenger();
-  if (aMsgr.IsNull()) return;
+  if (aMsgr.IsNull())
+  {
+    return;
+  }
 
-  TCollection_AsciiString aClassName ( DynamicType()->Name() );
+  const TCollection_AsciiString aClassName (DynamicType()->Name());
 
   // Iterate on all set flags in the specified range
   for ( Standard_Integer i  = Message_ExecStatus::FirstStatus; 
                          i <= Message_ExecStatus::LastStatus; i++ )
   {
     Message_Status stat = Message_ExecStatus::StatusByIndex( i );
-    if ( !theStatus.IsSet( stat ) || !myStatus.IsSet( stat ) )
+    if (!theStatus.IsSet (stat) || !myStatus.IsSet (stat))
+    {
       continue;
+    }
+
+    Handle(Message_Msg) aMsgCustom = !myReportMessages.IsNull()
+                                    ? myReportMessages->Value (i)
+                                    : Handle(Message_Msg)();
+    if (!aMsgCustom.IsNull())
+    {
+      // print custom message
+      aMsgr->Send (*aMsgCustom, theTraceLevel);
+      continue;
+    }
 
     // construct message suffix
     TCollection_AsciiString aSuffix;
@@ -181,7 +224,7 @@ void Message_Algorithm::SendStatusMessages (const Message_ExecStatus& theStatus,
     // find message, iterating by base classes if necessary
     TCollection_AsciiString aMsgName = aClassName + aSuffix;
     Handle(Standard_Type) aType = DynamicType();
-    while (Message_MsgFile::Msg(aMsgName).Length() == 0 && !aType.IsNull())
+    while (! Message_MsgFile::HasMsg(aMsgName) && !aType.IsNull())
     {
       Standard_AncestorIterator it(aType);
       aType.Nullify();
@@ -190,7 +233,7 @@ void Message_Algorithm::SendStatusMessages (const Message_ExecStatus& theStatus,
         aType = it.Value();
         TCollection_AsciiString aClassName1 (aType->Name());
         TCollection_AsciiString aMsgName1 = aClassName1 + aSuffix;
-        if (Message_MsgFile::Msg(aMsgName1).Length() != 0)
+        if (Message_MsgFile::HasMsg(aMsgName1))
         {
           aMsgName = aMsgName1;
           break;
@@ -203,19 +246,24 @@ void Message_Algorithm::SendStatusMessages (const Message_ExecStatus& theStatus,
 
     // if additional parameters are defined for a given status flag,
     // try to feed them into the message
-    if ( ! myReportIntegers.IsNull() ) 
+    if (!myReportIntegers.IsNull())
     {
       Handle(TColStd_HPackedMapOfInteger) aMapErrors =
-	Handle(TColStd_HPackedMapOfInteger)::DownCast(myReportIntegers->Value(i));
-      if (!aMapErrors.IsNull() ) 
-        aMsg << PrepareReport ( aMapErrors, theMaxCount );
+        Handle(TColStd_HPackedMapOfInteger)::DownCast(myReportIntegers->Value(i));
+      if (!aMapErrors.IsNull())
+      {
+        aMsg << PrepareReport (aMapErrors, theMaxCount);
+      }
     }
-    if ( ! myReportStrings.IsNull() && ! myReportStrings->Value(i).IsNull() ) 
+    if (!myReportStrings.IsNull()
+     && !myReportStrings->Value (i).IsNull())
     {
-      Handle(TColStd_HSequenceOfHExtendedString) aReportSeq = 
-        Handle(TColStd_HSequenceOfHExtendedString)::DownCast ( myReportStrings->Value(i) );
-      if ( ! aReportSeq.IsNull() ) 
-        aMsg << PrepareReport ( aReportSeq->Sequence(), theMaxCount );
+      Handle(TColStd_HSequenceOfHExtendedString) aReportSeq =
+        Handle(TColStd_HSequenceOfHExtendedString)::DownCast (myReportStrings->Value(i));
+      if (!aReportSeq.IsNull())
+      {
+        aMsg << PrepareReport (aReportSeq->Sequence(), theMaxCount);
+      }
     }
 
     // output the message
