@@ -4,8 +4,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -18,26 +18,42 @@
 #include <TCollection_AsciiString.hxx>
 #include <TCollection_ExtendedString.hxx>
 
+//=======================================================================
+//function : Constructor
+//purpose  :
+//=======================================================================
+
+Message_Printer::Message_Printer()
+: myTraceLevel (Message_Info)
+{
+}
+
 //=======================================================================
 //function : Send
-//purpose  : 
+//purpose  :
 //=======================================================================
 
 void Message_Printer::Send (const Standard_CString theString,
-			    const Message_Gravity theGravity,
-			    const Standard_Boolean putEndl) const
+                            const Message_Gravity  theGravity,
+                            const Standard_Boolean theToOutEol) const
 {
-  Send ( TCollection_ExtendedString(theString), theGravity, putEndl );
+  if (theGravity >= myTraceLevel)
+  {
+    Send (TCollection_ExtendedString (theString), theGravity, theToOutEol);
+  }
 }
 
 //=======================================================================
 //function : Send
-//purpose  : 
+//purpose  :
 //=======================================================================
 
 void Message_Printer::Send (const TCollection_AsciiString& theString,
-			    const Message_Gravity theGravity,
-			    const Standard_Boolean putEndl) const
+                            const Message_Gravity          theGravity,
+                            const Standard_Boolean         theToOutEol) const
 {
-  Send ( TCollection_ExtendedString(theString), theGravity, putEndl );
+  if (theGravity >= myTraceLevel)
+  {
+    Send (TCollection_ExtendedString (theString), theGravity, theToOutEol);
+  }
 }
