@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -791,7 +791,9 @@ Handle(Geom_Curve)  MgtGeom::Translate(const Handle(PGeom_Curve)& PObj)
     return MgtGeom::Translate(TOffsetCurve);
   }
   else {
+#ifdef OCCT_DEBUG
     cout << "MgtGeom : Unknown curve type ???? : " << endl;
+#endif
     Standard_NullObject::Raise("No mapping for the current Persistent Curve");
   }
 // POP pour NT
@@ -855,7 +857,9 @@ Handle(PGeom_Curve)  MgtGeom::Translate(const Handle(Geom_Curve)& TObj)
     return MgtGeom::Translate(POffsetCurve);
   }
   else {
+#ifdef OCCT_DEBUG
     cout << "MgtGeom : Unknown curve type ????"<<endl;
+#endif
     Standard_NullObject::Raise("No mapping for the current Transient Curve");
 
   }
@@ -1270,7 +1274,9 @@ Handle(Geom_Surface)  MgtGeom::Translate(const Handle(PGeom_Surface)& PObj)
     return MgtGeom::Translate(TOffsetSurface);
   }
   else {
+#ifdef OCCT_DEBUG
     cout << "MgtGeom : Unknown surface type ????"<<endl;
+#endif
     Standard_NullObject::Raise("No mapping for the current Persistent Surface");
 
   }
@@ -1345,7 +1351,9 @@ Handle(PGeom_Surface)  MgtGeom::Translate(const Handle(Geom_Surface)& TObj)
     return MgtGeom::Translate(POffsetSurface);
   }
   else {
+#ifdef OCCT_DEBUG
     cout << "MgtGeom : Unknown surface type ????"<<endl;
+#endif
     Standard_NullObject::Raise("No mapping for the current Transient Surface");
   }
 // POP pour NT
