@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -462,7 +462,9 @@ Handle(Geom2d_Curve)  MgtGeom2d::Translate(const Handle(PGeom2d_Curve)& PObj)
     return MgtGeom2d::Translate(TOffsetCurve);
   }
   else {
+#ifdef OCCT_DEBUG
     cout << "Unknown Geom2d curve type ???? " << endl;
+#endif
     Standard_NullObject::Raise("No mapping for the current Persistent Curve");
   }
 // POP pour NT
@@ -526,7 +528,9 @@ Handle(PGeom2d_Curve)  MgtGeom2d::Translate(const Handle(Geom2d_Curve)& TObj)
     return MgtGeom2d::Translate(POffsetCurve);
   }
   else {
+#ifdef OCCT_DEBUG
     cout << "Unknown Geom2d curve type ???? " << endl;
+#endif
     Standard_NullObject::Raise("No mapping for the current Transient Curve");
   }
 // POP pour NT
