@@ -4,8 +4,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -16,6 +16,7 @@
 // Purpose:     Implementation of the BaseAllocator class
 
 #include <NCollection_BaseAllocator.hxx>
+#include <NCollection_IncAllocator.hxx>
 #include <NCollection_DataMap.hxx>
 #include <NCollection_Map.hxx>
 #include <NCollection_List.hxx>
@@ -43,7 +44,7 @@ void* NCollection_BaseAllocator::Allocate(const size_t size)
 
 void  NCollection_BaseAllocator::Free(void *anAddress)
 { 
-  if (anAddress) Standard::Free((Standard_Address&)anAddress); 
+  if (anAddress) Standard::Free(anAddress); 
 }
 
 //=======================================================================
@@ -172,7 +173,7 @@ Standard_EXPORT void StandardCallBack_Reset()
 namespace {
   // dummy function for break point
   inline void place_for_break_point () {}
-};
+}
 
 //=======================================================================
 //function : StandardCallBack
