@@ -4,8 +4,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -25,7 +25,7 @@ void NIS_ObjectsIterator::Initialize
                         (const Handle(NIS_InteractiveContext)& theCtx)
 {
   if (theCtx.IsNull())
-    myIter = NCollection_SparseArray <Handle_NIS_InteractiveObject>::Iterator();
+    myIter = NCollection_SparseArray <Handle(NIS_InteractiveObject)>::Iterator();
   else
     for (myIter.Init (theCtx->myObjects); myIter.More(); myIter.Next())
       if (myIter.Value().IsNull() == Standard_False)
