@@ -4,8 +4,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -23,7 +23,7 @@ IMPLEMENT_STANDARD_RTTIEXT (NIS_SelectFilter, Standard_Transient)
 //purpose  : 
 //=======================================================================
 
-Standard_Boolean NIS_SelectFilter::ActsOn (const Handle_Standard_Type&) const
+Standard_Boolean NIS_SelectFilter::ActsOn (const Handle(Standard_Type)&) const
 {
   return Standard_True;
 }
