@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -27,7 +27,7 @@
 #include <Plate_PinpointConstraint.hxx>
 #include <Plate_FreeGtoCConstraint.hxx>
 
-#include <NLPlate_StackIteratorOfStackOfPlate.hxx>
+#include <NLPlate_ListIteratorOfStackOfPlate.hxx>
 
 #include <NLPlate_NLPlate.ixx>
 
@@ -73,7 +73,7 @@ NLPlate_NLPlate::NLPlate_NLPlate(const Handle(Geom_Surface)& InitialSurface) :
   if(ordre<maxOrder+2) ordre = maxOrder+2;
   if(Iterate(0,ord)) 
     {
-      mySOP.ChangeTop().SetPolynomialPartOnly(Standard_True);
+      mySOP.First().SetPolynomialPartOnly(Standard_True);
       ConstraintsSliding();
     }
       
@@ -152,7 +152,7 @@ NLPlate_NLPlate::NLPlate_NLPlate(const Handle(Geom_Surface)& InitialSurface) :
   else
     Value = myInitialSurface->DN(point2d.X(),point2d.Y(),iu,iv).XYZ();
 
-  for(NLPlate_StackIteratorOfStackOfPlate SI(mySOP);SI.More();SI.Next())
+  for(NLPlate_ListIteratorOfStackOfPlate SI(mySOP);SI.More();SI.Next())
     {
       if(SI.Value().IsDone())
 	Value += SI.Value().EvaluateDerivative(point2d,iu,iv);
@@ -168,7 +168,7 @@ NLPlate_NLPlate::NLPlate_NLPlate(const Handle(Geom_Surface)& InitialSurface) :
     {
       if(!(myInitialSurface->IsCNu(cont+1)&&myInitialSurface->IsCNv(cont+1)))break;
     }
-  for(NLPlate_StackIteratorOfStackOfPlate SI(mySOP);SI.More();SI.Next())
+  for(NLPlate_ListIteratorOfStackOfPlate SI(mySOP);SI.More();SI.Next())
     {
       if((SI.Value().IsDone())&&(cont > SI.Value().Continuity())) cont = SI.Value().Continuity();
     }
@@ -181,8 +181,8 @@ const Standard_Integer ResolutionOrder,
 const Standard_Real IncrementalLoading) 
 {
   Plate_Plate EmptyPlate;
-  mySOP.Push(EmptyPlate);
-  Plate_Plate &TopP = mySOP.ChangeTop();
+  mySOP.Prepend(EmptyPlate);
+  Plate_Plate &TopP = mySOP.First();
   for(Standard_Integer index =1; index <= myHGPPConstraints.Length(); index++)
     {
       const Handle(NLPlate_HGPPConstraint) &HGPP = myHGPPConstraints(index);
@@ -265,7 +265,7 @@ const Standard_Real IncrementalLoading)
   TopP.SolveTI(ResolutionOrder);
   if(!TopP.IsDone())
     {
-      mySOP.Pop();
+      mySOP.RemoveFirst();
       return Standard_False;
     }
   else
