@@ -2,8 +2,8 @@
 #
 # This file is part of Open CASCADE Technology software library.
 #
-# This library is free software; you can redistribute it and / or modify it
-# under the terms of the GNU Lesser General Public version 2.1 as published
+# This library is free software; you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License version 2.1 as published
 # by the Free Software Foundation, with special exception defined in the file
 # OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 # distribution for complete text of the license and disclaimer of any warranty.
@@ -15,8 +15,15 @@
 ;# Liste des toolkits WOK sous forme de full path
 ;# 
 proc Draw:toolkits { } {
-    return [list TKDraw TKTopTest TKViewerTest TKXSDRAW TKDCAF TKXDEDRAW TKTObjDRAW TKQADraw]
+    set aResult [list TKDraw TKTopTest TKViewerTest TKXSDRAW TKDCAF TKXDEDRAW TKTObjDRAW TKQADraw]
+
+    if { [info exists ::env(HAVE_VTK)] && $::env(HAVE_VTK) == "true" } {
+      lappend aResult "TKIVtkDraw"
+    }
+
+    return $aResult
 }
+
 ;#
 ;# Autres UDs a prendre. Listes de triplets
 ;# { ar typ UD str } Tous les types de UD vont dans un sous directory nomme root/str
