@@ -4,8 +4,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -61,28 +61,3 @@ Standard_Boolean OpenGl_GraphicDriver::IsGLLightEnabled( const Graphic3d_CView&
     return aCView->WS->UseGLLight();
   return Standard_False;
 }
-
-void OpenGl_GraphicDriver::PrimitiveArray( const Graphic3d_CGroup& ACGroup,
-                                          const Graphic3d_PrimitiveArray& parray,
-                                          const Standard_Boolean /*EvalMinMax*/ )
-{
-  if ( ACGroup.ptrGroup && parray )
-  {
-    OpenGl_PrimitiveArray *aparray = new OpenGl_PrimitiveArray( (CALL_DEF_PARRAY *) parray );
-    ((OpenGl_Group *)ACGroup.ptrGroup)->AddElement( TelParray, aparray );
-  }
-}
-
-void OpenGl_GraphicDriver::UserDraw (const Graphic3d_CGroup&    theCGroup,
-                                     const Graphic3d_CUserDraw& theUserDraw)
-{
-  if (theCGroup.ptrGroup != NULL
-   && myUserDrawCallback != NULL)
-  {
-    OpenGl_Element* aUserDraw = myUserDrawCallback(&theUserDraw);
-    if (aUserDraw != NULL)
-    {
-      ((OpenGl_Group* )theCGroup.ptrGroup)->AddElement (TelUserdraw, aUserDraw);
-    }
-  }
-}
