@@ -4,8 +4,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -29,7 +29,7 @@ OpenGl_PrinterContext::OpenGl_PrinterContext()
   myScaleY (1.0f),
   myLayerViewportX (0),
   myLayerViewportY (0)
-  
+
 {
   // identity projection matrix
   Standard_Real anInitValue = 0.0;
@@ -51,12 +51,12 @@ OpenGl_PrinterContext::~OpenGl_PrinterContext()
 }
 
 // =======================================================================
-// function : LoadProjTransformation
+// function : ProjTransformation
 // purpose  :
 // =======================================================================
-void OpenGl_PrinterContext::LoadProjTransformation()
+OpenGl_Mat4 OpenGl_PrinterContext::ProjTransformation()
 {
-  glLoadMatrixf ((GLfloat* )myProjMatrixGl);
+  return OpenGl_Mat4::Map (myProjMatrixGl);
 }
 
 // =======================================================================
