@@ -3,8 +3,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -100,7 +100,7 @@ Tint TelGetPolygonNormal(tel_point pnts, Tint* indexs, Tint npnt, Tfloat *norm )
       }
     }
   }
-#ifdef DEB
+#ifdef OCCT_DEBUG
   if( !status )
     printf(" *** OpenGl_TelGetPolygonNormal.has found confused or aligned points\n");
 #endif
@@ -121,7 +121,7 @@ Tint TelGetNormal(Tfloat *data1, Tfloat *data2, Tfloat *data3, Tfloat *norm ) {
     d = vecnrmd( norm, d );
     status = (d > 0.) ? 1 : 0;
   }
-#ifdef DEB
+#ifdef OCCT_DEBUG
   if( !status )
     printf(" *** OpenGl_TelGetNormal.has found confused or aligned points\n");
 #endif
