@@ -3,8 +3,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -19,19 +19,7 @@
 #include <Standard_NegativeValue.hxx>
 #include <Standard_OutOfRange.hxx>
 
-#ifdef HAVE_CONFIG_H
-# include <oce-config.h>
-#endif
-#if defined(HAVE_STRING_H)
-# include <string.h>
-#endif
 #include <stdio.h>
-#if defined(HAVE_STDLIB_H)
-#include <stdlib.h>
-#endif
-#if defined(HAVE_LIBC_H)
-# include <libc.h>
-#endif
 
 //------------------------------------------------------------------------
 //  Create from an ExtendedString of TCollection
@@ -567,17 +555,6 @@ Standard_ExtCharacter PCollection_HExtendedString::Value
    return Data(Index-1);
 }
 
-//------------------------------------------------------------------------
-//  ShallowDump
-//------------------------------------------------------------------------
-void PCollection_HExtendedString::ShallowDump(Standard_OStream& S) const
-{
-   S << "begin class HExtendedString " << endl;
-   ::ShallowDump(Data, S);
-   S << "end class HExtendedString" << endl;
-}
-
-
 //------------------------------------------------------------------------
 //  Assign
 //------------------------------------------------------------------------
