@@ -3,8 +3,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -15,14 +15,6 @@
 #include <PMMgt_PManaged.ixx>
 #include <Standard_TypeMismatch.hxx>
 
-#ifdef TRACE
-#define  PRINT(X) cout X
-#define  SHALLOWDUMP(X) X.ShallowDump(cout)
-#else
-#define  PRINT(X) 
-#define  SHALLOWDUMP(X)
-#endif
-
 PMMgt_PManaged::PMMgt_PManaged()
 {
 }
@@ -30,10 +22,10 @@ PMMgt_PManaged::PMMgt_PManaged()
 //============================================================================
 #ifndef CSFDB
 class _Oid_PMMgt_PManaged : public Oid_PMMgt_PManaged {
-    friend class Handle_PMMgt_PManaged;
+    friend class Handle(PMMgt_PManaged);
 };
 
-void Handle_PMMgt_PManaged::Delete()
+void Handle(PMMgt_PManaged)::Delete()
 {
 //  PMMgt_PManaged* aMng;
   _Oid_PMMgt_PManaged *aOid;
