@@ -3,8 +3,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -14,8 +14,6 @@
 
 // Modified:     22/03/04 ; SAN : OCC4895 High-level interface for controlling polygon offsets
 
-#define IMP020200       //GG Add Transformation() method
-
 #include <Prs3d_Presentation.ixx>
 #include <TColStd_Array2OfReal.hxx>
 #include <Graphic3d_Structure.hxx>
@@ -50,73 +48,55 @@ static void MakeGraphicTrsf (const Handle(Geom_Transformation)& aGeomTrsf,
 
 //=======================================================================
 //function : Prs3d_Presentation
-//purpose  : 
+//purpose  :
 //=======================================================================
-Prs3d_Presentation::Prs3d_Presentation 
-  (const Handle(Graphic3d_StructureManager)& aViewer,
-   const Standard_Boolean                    Init):
-  Graphic3d_Structure(aViewer) 
+Prs3d_Presentation::Prs3d_Presentation (const Handle(Graphic3d_StructureManager)& theViewer,
+                                        const Standard_Boolean                    theToInit)
+: Graphic3d_Structure (theViewer)
 {
-  if (Init) {
-    Graphic3d_MaterialAspect aMat (Graphic3d_NOM_BRASS);
-    Quantity_Color Col;
-    // Ceci permet de recuperer la couleur associee
-    // au materiau defini par defaut.
-//POP pour K4L
-    Col = aMat.AmbientColor ();
-//    Col = aMat.Color ();
-
-    // OCC4895 SAN 22/03/04 High-level interface for controlling polygon offsets 
-    // It is necessary to set default polygon offsets for a new presentation
-    Handle(Graphic3d_AspectFillArea3d) aDefAspect = 
-      new Graphic3d_AspectFillArea3d (Aspect_IS_SOLID,
-                                      Col,
-                                      Col,
-                                      Aspect_TOL_SOLID,
-                                      1.0,
-                                      Graphic3d_NOM_BRASS,
-                                      Graphic3d_NOM_BRASS);
-    aDefAspect->SetPolygonOffsets( Aspect_POM_Fill, 1., 0. );
-    SetPrimitivesAspect( aDefAspect );
-    // OCC4895 SAN 22/03/04 High-level interface for controlling polygon offsets 
+  if (!theToInit)
+  {
+    return;
   }
 
-//  myStruct = Handle(Graphic3d_Structure)::DownCast(This ());
-//  myCurrentGroup = new Graphic3d_Group(myStruct);
+  Graphic3d_MaterialAspect aMat (Graphic3d_NOM_BRASS);
+  Quantity_Color aColor = aMat.AmbientColor();
+  // It is necessary to set default polygon offsets for a new presentation
+  Handle(Graphic3d_AspectFillArea3d) aDefAspect =
+    new Graphic3d_AspectFillArea3d (Aspect_IS_SOLID,
+                                    aColor,
+                                    aColor,
+                                    Aspect_TOL_SOLID,
+                                    1.0,
+                                    Graphic3d_NOM_BRASS,
+                                    Graphic3d_NOM_BRASS);
+  aDefAspect->SetPolygonOffsets (Aspect_POM_Fill, 1.0f, 0.0f);
+  SetPrimitivesAspect (aDefAspect);
 }
 
 //=======================================================================
-//function : Highlight
-//purpose  : 
+//function : Prs3d_Presentation
+//purpose  :
 //=======================================================================
-void Prs3d_Presentation::Highlight()
+Prs3d_Presentation::Prs3d_Presentation (const Handle(Graphic3d_StructureManager)& theViewer,
+                                        const Handle(Prs3d_Presentation)&         thePrs)
+: Graphic3d_Structure (theViewer, thePrs)
 {
-  SetHighlightColor(Quantity_Color(Quantity_NOC_GRAY99));
-  Aspect_TypeOfHighlightMethod Method = Aspect_TOHM_COLOR;
-  Graphic3d_Structure::Highlight(Method);
+  Graphic3d_MaterialAspect aMat (Graphic3d_NOM_BRASS);
+  Quantity_Color aColor = aMat.AmbientColor();
+  // It is necessary to set default polygon offsets for a new presentation
+  Handle(Graphic3d_AspectFillArea3d) aDefAspect =
+    new Graphic3d_AspectFillArea3d (Aspect_IS_SOLID,
+                                    aColor,
+                                    aColor,
+                                    Aspect_TOL_SOLID,
+                                    1.0,
+                                    Graphic3d_NOM_BRASS,
+                                    Graphic3d_NOM_BRASS);
+  aDefAspect->SetPolygonOffsets (Aspect_POM_Fill, 1.0f, 0.0f);
+  SetPrimitivesAspect (aDefAspect);
 }
 
-//=======================================================================
-//function : Color
-//purpose  : 
-//=======================================================================
-void Prs3d_Presentation::Color(const Quantity_NameOfColor aColor) 
-{
-  SetHighlightColor(Quantity_Color(aColor));
-  Graphic3d_Structure::Highlight(Aspect_TOHM_COLOR);
-}
-
-//=======================================================================
-//function : BoundBox
-//purpose  : 
-//=======================================================================
-void Prs3d_Presentation::BoundBox()
-{ 
-  SetHighlightColor(Quantity_Color(Quantity_NOC_GRAY99));
-  Graphic3d_Structure::Highlight(Aspect_TOHM_BOUNDBOX);
-}
-
-
 //=======================================================================
 //function : SetShadingAspect
 //purpose  : 
@@ -126,34 +106,6 @@ void Prs3d_Presentation::SetShadingAspect(const Handle(Prs3d_ShadingAspect)& aSh
   SetPrimitivesAspect(aShadingAspect->Aspect());
 }
 
-//=======================================================================
-//function : IsPickable
-//purpose  : 
-//=======================================================================
-Standard_Boolean Prs3d_Presentation::IsPickable () const 
-{
-  return Graphic3d_Structure::IsSelectable();
-}
-
-//=======================================================================
-//function : SetPickable
-//purpose  : 
-//=======================================================================
-
-void Prs3d_Presentation::SetPickable() 
-{
-  SetPick(Standard_True);
-}
-
-//=======================================================================
-//function : SetUnPickable
-//purpose  : 
-//=======================================================================
-void Prs3d_Presentation::SetUnPickable() 
-{
-  SetPick(Standard_False);
-}
-
 //=======================================================================
 //function : Transform
 //purpose  : 
@@ -166,7 +118,6 @@ void Prs3d_Presentation::Transform(const Handle(Geom_Transformation)& aTransform
   SetTransform(Array, Graphic3d_TOC_REPLACE);
 }
 
-#ifdef IMP020200
 //=======================================================================
 //function : Transformation
 //purpose  : 
@@ -181,13 +132,11 @@ TColStd_Array2OfReal matrix(1,4,1,4);
   trsf.SetValues(
         matrix.Value(1,1),matrix.Value(1,2),matrix.Value(1,3),matrix.Value(1,4),
         matrix.Value(2,1),matrix.Value(2,2),matrix.Value(2,3),matrix.Value(2,4),
-        matrix.Value(3,1),matrix.Value(3,2),matrix.Value(3,3),matrix.Value(3,4),
-        0.001,0.0001);  
+        matrix.Value(3,1),matrix.Value(3,2),matrix.Value(3,3),matrix.Value(3,4));  
   Handle(Geom_Transformation) gtrsf = new Geom_Transformation(trsf); 
 
   return gtrsf;
 }
-#endif
 
 //=======================================================================
 //function : Place
@@ -230,20 +179,6 @@ void Prs3d_Presentation::Move  (const Quantity_Length X,
   SetTransform(Array, Graphic3d_TOC_POSTCONCATENATE);
 }
 
-
-//=======================================================================
-//function : Clear
-//purpose  : 
-//=======================================================================
-void Prs3d_Presentation::Clear(const Standard_Boolean WithDestruction)
-{
-  Graphic3d_Structure::Clear(WithDestruction);
-  // myCurrentGroup.Nullify();
-  myCurrentGroup = NULL;
-
-}
-
-
 //=======================================================================
 //function : Connect
 //purpose  : 
@@ -280,35 +215,13 @@ void Prs3d_Presentation::RemoveAll ()
 //=======================================================================
 Handle(Graphic3d_Group) Prs3d_Presentation::CurrentGroup () const 
 {
-  if(myCurrentGroup.IsNull()){
-    void *ptr = (void*) this;
-    Prs3d_Presentation* p = (Prs3d_Presentation *)ptr;
-    p->NewGroup();
+  if (Groups().IsEmpty())
+  {
+    return const_cast<Prs3d_Presentation* >(this)->NewGroup();
   }
-  return myCurrentGroup;
+  return Groups().Last();
 }
 
-
-//=======================================================================
-//function : NewGroup
-//purpose  : 
-//=======================================================================
-Handle(Graphic3d_Group) Prs3d_Presentation::NewGroup ()
-{
-  myCurrentGroup = new Graphic3d_Group(this);
-  return myCurrentGroup;
-}
-
-//=======================================================================
-//function : Display
-//purpose  : 
-//=======================================================================
-void Prs3d_Presentation::Display ()
-{
-  Graphic3d_Structure::Display();
-}
-
-
 //=======================================================================
 //function : Compute
 //purpose  : 
@@ -325,8 +238,8 @@ Handle(Graphic3d_Structure) Prs3d_Presentation::
 //purpose  : 
 //=======================================================================
 
-void Prs3d_Presentation::Compute(const Handle_Graphic3d_DataStructureManager& aDataStruct, 
-                                 Handle_Graphic3d_Structure& aStruct)
+void Prs3d_Presentation::Compute(const Handle(Graphic3d_DataStructureManager)& aDataStruct, 
+                                 Handle(Graphic3d_Structure)& aStruct)
 {
  Graphic3d_Structure::Compute(aDataStruct,aStruct );
 }
@@ -336,7 +249,7 @@ void Prs3d_Presentation::Compute(const Handle_Graphic3d_DataStructureManager& aD
 //purpose  : 
 //=======================================================================
 
-Handle_Graphic3d_Structure Prs3d_Presentation::Compute(const Handle_Graphic3d_DataStructureManager& aDataStruc, 
+Handle(Graphic3d_Structure) Prs3d_Presentation::Compute(const Handle(Graphic3d_DataStructureManager)& aDataStruc, 
                                                        const TColStd_Array2OfReal& anArray)
 {
  return Graphic3d_Structure::Compute(aDataStruc,anArray);
@@ -347,9 +260,9 @@ Handle_Graphic3d_Structure Prs3d_Presentation::Compute(const Handle_Graphic3d_Da
 //purpose  : 
 //=======================================================================
 
-void Prs3d_Presentation::Compute(const Handle_Graphic3d_DataStructureManager& aDataStruc,
+void Prs3d_Presentation::Compute(const Handle(Graphic3d_DataStructureManager)& aDataStruc,
                                  const TColStd_Array2OfReal& anArray,
-                                 Handle_Graphic3d_Structure& aStruc)
+                                 Handle(Graphic3d_Structure)& aStruc)
 {
  Graphic3d_Structure::Compute(aDataStruc,anArray,aStruc);
 }
