@@ -4,8 +4,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -55,7 +55,7 @@ void QANewBRepNaming_Cut::Load(BRepAlgoAPI_BooleanOperation& MS) const {
   const TopAbs_ShapeEnum& TypeSh = ShapeType(ObjSh);
 
   if (ResSh.IsNull()) {
-#ifdef DEB
+#ifdef OCCT_DEBUG
     cout<<"QANewBRepNaming_Cut::Load(): The result of the boolean operation is null"<<endl;
 #endif
     return;
@@ -63,7 +63,7 @@ void QANewBRepNaming_Cut::Load(BRepAlgoAPI_BooleanOperation& MS) const {
 
   // If the shapes are the same - select the result and exit:
   if (IsResultChanged(MS)) {
-#ifdef DEB
+#ifdef OCCT_DEBUG
     cout<<"QANewBRepNaming_Cut::Load(): The object and the result of CUT operation are the same"<<endl;
 #endif
     if (MS.Shape().ShapeType() == TopAbs_COMPOUND) {
