@@ -5,8 +5,8 @@
 //
 // This file is part of Open CASCADE Technology software library.
 //
-// This library is free software; you can redistribute it and / or modify it
-// under the terms of the GNU Lesser General Public version 2.1 as published
+// This library is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License version 2.1 as published
 // by the Free Software Foundation, with special exception defined in the file
 // OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
 // distribution for complete text of the license and disclaimer of any warranty.
@@ -416,7 +416,7 @@ void QANewBRepNaming_Loader::LoadDangleShapes(const TopoDS_Shape& theShape,
     const TopoDS_Shape& aDangle = itr.Key();
     if (ignored.Contains(aDangle)) continue;
     TNaming_Builder aBuilder(theLabelGenerator.NewChild());
-#ifdef MDTV_DEB
+#ifdef OCCT_DEBUG
     TDataStd_Name::Set(aBuilder.NamedShape()->Label(), "NewShapes");
 #endif
     aBuilder.Generated(aDangle);
